<>

# Adding a new Natural Language to GNUstep

### From GNUstepWiki	{#siteSub}

These instructions are loosely based on a mail from Fred Kiefer.

<table>
<tr>
<td>
## Contents
* [1 General approach][1]
* [2 Localizable.strings][2]
* [3 GNUmakefile][3]
* [4 Gorm files][4]
* [5 See also][5]
</td>
</tr>
</table>

[[edit][6]]

<>

## General approach

To have a localized application, not only will the application have to be translated, but also GNUstep-base and GNUstep-gui if they've not already been done.

Check to see if base and gui support your language. Language support bundles are present in the Resources directory in the source distributions with an extension .lproj.

**Note:** By convention, these localization bundles are named in English.

If your language is not supported yet, copy the English.lproj bundle and name it to the language you wish to support.

At a minimum, you will need to translate the bundle's Localizable.strings file and the package's (or subproject's) GNUmakefile to include the new language name in the xxx\_LANGUAGES variable. If the resource (such as a GUI application, or GNUstep-gui) uses .gorm files for GUI elements such as menus and panels, these will also need to be translated using Gorm.

[[edit][7]]

<>

## Localizable.strings

Localizable.strings is a file containing strings in a base language (often English) which correspond to strings embedded in the source code and the translated string.

You will need to put strings that correspond to the language you are targetting in the right hand column. Missing quotation marks, equal signs or terminating semicolons will cause problems.

**Note:** Applications need to use the \_() syntax in source code to support automatic use of Localizable.strings.

[[edit][8]]

<>

## GNUmakefile

Add the name of the language to the project's _projectname_\_LANGUAGES variable.

[[edit][9]]

<>

## Gorm files

Find all files ending in .gorm that were copied from the orginal language bundle and load them one by one. Change all the text that is displayed to the user in menus, panels, windows, buttons and so on, and if necessary, also change the layout (average string length and height tend to differ between even closely-related languages, right-to-left languages may conventionally place default buttons in different locations on panels, as examples).

[[edit][10]]

<>

## See also

[[Dennis Leeuw's tutorial][11]]

 Retrieved from "[http://wiki.gnustep.org/index.php/Adding\_a\_new\_Natural\_Language\_to\_GNUstep][12]"

##### Views

* [Article][13]
* [Discussion][14]
* [Edit][15]
* [History][16]

##### Personal tools

* [Create an account or log in][17]

[][18]

##### users

* [Applications][19]
* [Guides][20]
* [FAQ][21]
* [Get Help][22]
* [Report Bugs][23]
* [Donations][24]
* [Screenshots][25]

##### developers

* [Guides][26]
* [FAQ][27]
* [Base API (Foundation)][28]
* [GUI API (AppKit)][29]
* [Frameworks][30]

##### Navigation

* [Main Page][31]
* [Community portal][32]
* [Current events][33]
* [Recent changes][34]
* [Random page][35]
* [Help][36]

##### Search

##### Toolbox

* [What links here][37]
* [Related changes][38]
* [Upload file][39]
* [Special pages][40]
* [Printable version][41]

[![MediaWiki][42]][43]

* This page was last modified 11:41, 13 July 2009.
* This page has been accessed 7,912 times.
* Content is available under [GNU General Public License][44].
* [About GNUstepWiki][45]
* [Disclaimers][46]

  [1]: #General_approach
  [2]: #Localizable.strings
  [3]: #GNUmakefile
  [4]: #Gorm_files
  [5]: #See_also
  [6]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=edit&section=1 "Adding a new Natural Language to GNUstep"
  [7]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=edit&section=2 "Adding a new Natural Language to GNUstep"
  [8]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=edit&section=3 "Adding a new Natural Language to GNUstep"
  [9]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=edit&section=4 "Adding a new Natural Language to GNUstep"
  [10]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=edit&section=5 "Adding a new Natural Language to GNUstep"
  [11]: http://gnustep.made-it.com/GSPT/xml/Tutorial_en.html#AEN1516 "http://gnustep.made-it.com/GSPT/xml/Tutorial en.html#AEN1516"
  [12]: http://wiki.gnustep.org/index.php/Adding_a_new_Natural_Language_to_GNUstep
  [13]: /index.php/Adding_a_new_Natural_Language_to_GNUstep
  [14]: /index.php?title=Talk:Adding_a_new_Natural_Language_to_GNUstep&action=edit
  [15]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=edit
  [16]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&action=history
  [17]: /index.php?title=Special:Userlogin&returnto=Adding_a_new_Natural_Language_to_GNUstep
  [18]: /index.php/Main_Page "Main Page"
  [19]: /index.php/Category:Applications
  [20]: /index.php/User_Guides
  [21]: /index.php/User_FAQ
  [22]: /index.php/Get_Help
  [23]: /index.php/Report_Bugs
  [24]: /index.php/GNUstepWiki:Site_support
  [25]: /index.php/Screenshots
  [26]: /index.php/Developer_Guides
  [27]: /index.php/Developer_FAQ
  [28]: /index.php/Foundation
  [29]: /index.php/AppKit
  [30]: /index.php/Category:Frameworks
  [31]: /index.php/Main_Page
  [32]: /index.php/GNUstepWiki:Community_Portal
  [33]: /index.php/Current_events
  [34]: /index.php/Special:Recentchanges
  [35]: /index.php/Special:Random
  [36]: /index.php/Help:Contents
  [37]: /index.php/Special:Whatlinkshere/Adding_a_new_Natural_Language_to_GNUstep
  [38]: /index.php/Special:Recentchangeslinked/Adding_a_new_Natural_Language_to_GNUstep
  [39]: /index.php/Special:Upload
  [40]: /index.php/Special:Specialpages
  [41]: /index.php?title=Adding_a_new_Natural_Language_to_GNUstep&printable=yes&printable=yes
  [42]: /skins/common/images/poweredby_mediawiki_88x31.png
  [43]: http://www.mediawiki.org/
  [44]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [45]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [46]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"