<>

# Creating A Simple GSWeb Application

### From GNUstepWiki	{#siteSub}

<table>
<tr>
<td>
## Contents
* [1 Introduction][1]
* [2 File Components][2]
  * [2\.1 The Makefile][3]
  * [2\.2 Mandatory code][4]
  * [2\.3 Components][5]
    * [2\.3.1 Main.wo][6]
    * [2\.3.2 Details.wo][7]
    * [2\.3.3 Want to know more?][8]
  * [2\.4 The application dictionary][9]
  * [2\.5 Interface files][10]
</td>
</tr>
</table>

[[edit][11]]

<>

## Introduction

[GNUstepWeb][12] is a framework for creating web-based applications using Objective-C. This guide aims to provide an overview of what is required in the creation and design of a very simple web application.

It is assumed you are familiar with GNUstep, and have a working GNUstep installation, including the [GDL2][13] and [GSWeb][14] frameworks. Pre-requisites for [GSWeb application deployment][15] should also be in place.

[[edit][16]]

<>

## File Components

In building your web application you will need to create a number of files. From scratch, the following should be a rough guide to getting it working. These include the Makefile, some mandatory "plumbing" code in Objective-C, [GSWComponents][17] to provide the pages and subpage elements of the web application, and run-time resources.

[[edit][18]]

<>

### The Makefile

For a web application, a special makefile is needed: luckily it's very similar to makefiles you may have used for other kinds of project. There is currently no out-of-the-box way to have these files built for you, so you'll have to do it manually.

**GNUmakefile**

Initial makefile includes needed to set up the make environment should be:

	include $(GNUSTEP_MAKEFILES)/common.make
	include $(GNUSTEP_MAKEFILES)/Auxiliary/gsweb_wo.make

Note that the second include forces GNUstepWeb to use Apple's WebObjects naming conventions. Dropping the **\_wo** in the included filename will enable GSW naming conventions. It is useful to decide which convention you plan to use in the application early on because changing later will involve changing the naming convention of class names in many files in your project.

The key variables used in a web application's makefile are:

GSWAPP\_NAMEused to define the project's name in the makefile, replace the **_\{PROJECTNAME\}_** with the name in the variables listed below _\{PROJECTNAME\}_\_HAS\_GSW\_COMPONENTSused to indicate that [GSWComponents][19] are present in the project. Normally, this is set to YES_\{PROJECTNAME\}_\_PRINCIPAL\_CLASSused to identify the main class of the web application _\{PROJECTNAME\}_\_RESOURCE\_FILESused to indicate the list of files that are needed in the runtime bundle _\{PROJECTNAME\}_\_OBJC\_FILEScontains the list of Objective-C files needed to compile the web application _\{PROJECTNAME\}_\_COMPONENTSlists the names of the components that will be used to create pages and other elements in the web application

The final makefile includes needed to set up the make environment should be:

	-include GNUmakefile.preamble
	include $(GNUSTEP_MAKEFILES)/gswapp.make
	-include GNUmakefile.postamble

The preamble and postamble files are optional includes and will not error if they don't exist. It's good practice to have these in place to allow compile-time modifications during the development process and also for others if you distribute the code.

A worked-out example of a simple GNUmakefile for a GSWeb application is:

	include $(GNUSTEP_MAKEFILES)/common.make
	include $(GNUSTEP_MAKEFILES)/Auxiliary/gsweb_wo.make

	GSWAPP_NAME = SimpleDemo
	SimpleDemo_HAS_GSW_COMPONENTS = YES
	SimpleDemo_PRINCIPAL_CLASS = SimpleDemo
	#SimpleDemo_RESOURCE_FILES = Resources/SimpleDemo.eomodeld
	SimpleDemo_OBJC_FILES = \
	    SimpleDemo.m \
	    Session.m \
	    SimpleDemo_main.m \
	    Main.m \
	    Details.m

	SimpleDemo_COMPONENTS = \
	    Main.wo Details.wo

	-include GNUmakefile.preamble
	include $(GNUSTEP_MAKEFILES)/gswapp.make
	-include GNUmakefile.postamble

The name of the project is **SimpleDemo**, and it contains GSWComponents (the basic building blocks of GSWeb), its principal class is SimpleDemo, there are no resource files for the runtime (there is an entry, but it's hashed-out), there are five Objective-C source files, and two components. You can see that the syntax allows you to break lines using the backslash **\\** character as the last on the line to assist readability, especially for long lists of values, like the OBJC\_FILES.

For more information as to customising this file, as well as setting up compiler options for third party libraries and includes, see the GNUstep makefile manual.

[[edit][20]]

<>

### Mandatory code

GNUstepWeb expects a small amount of glue code and several classes to be present at runtime. Initial implementation of a web application may leave these in boiler-plate form, but most real-world projects end up adding significant extra functionality through the extension mechanisms they offer.

The mandatory code is as follows:

**main** functionthe runtime jumps to the beginning of the main function, which is used for initialisation of the the web application and can be used for initialisation of other resources such as C libraries etc **Session** class definitionused for per-session initialisation in the web application, in addition to holding instance variables and methods for each session. This class should be literally named Session. **GSWApplication** or WOApplication-derived class definitionused for web application instance-wide initialisation, and it may hold instance variables and methods across the entire instance.

Some worked out examples for the SimpleDemo web application follow. First **SimpleDemo\_main.m**

	// SimpleDemo_main.m

	#import &lt;WebObjects/WebObjects.h&gt;

	int main (int argc, const char *argv[])
	{
	    int rc;
	    NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
	    rc = WOApplicationMain(@"SimpleDemo", argc, argv);
	    [pool release];
	    return rc;
	}

This creates an autorelease pool and begins the web application by invoking the application object.

Next **Session.h**:

	// Session.h from SimpleDemo

	#import &lt;WebObjects/WebObjects.h&gt;

	@interface Session: WOSession

	// fill me with session instance variables

	@end

And **Session.m**:

	// Session.m from SimpleDemo
	#import "Session.h"

	@implementation Session

	- (id) init
	{
	    [super init];
	    [self setStoresIDsInCookies: YES];
	    [self setStoresIDsInURLs: NO];
	    return self;
	}

	@end

The Session.m code above implements a small change in the normal behaviour of GNUstepWeb, forcing it to store session identifiers in cookies and not in the URL. There are good reasons not to do this in practice for some real web applications, but it does show the Session object may be used to change behaviour on a per-session basis.

Now for the application object, in two parts, **SimpleDemo.h**:

	// SimpleDemo.h

	#import &lt;WebObjects/WebObjects.h&gt;

	@interface SimpleDemo: WOApplication

	@end

And **SimpleDemo.m**:

	// SimpleDemo.m

	#import "SimpleDemo.h"

	@implementation SimpleDemo

	@end

The application can run quite successfully with very little other than this boilerplate code. Of course, real functionality requirements may mean creating or overriding methods in these classes (especially the -init methods), creation of new instance variables and so on.

[[edit][21]]

<>

### Components

GSWeb uses a directory for every component. A component can represent a whole web page or just a part of it. It is easy to re-use pieces needed multiple times.

A component contains three files containing the HTML, the connections or bindings of your objects and additional information like the text-encoding used in the component. Those files are suffixed .html, .wod and .woo.

Additionally, a component is normally implemented with a corresponding subclass of [GSWComponent or WOComponent][22].

In the SimpleDemo web application there are only two components defined. In a real application it's usual to have custom components providing style sheet information, headers, footers, navigation bars and so on that are reused in the components that correspond to pages.

[[edit][23]]

<>

#### Main.wo

The Main component normally provides the first page when a connection is made to the web application. The name is not arbitrary, and normally every GNUstepWeb application contains a Main component. Our implementation will consist of five files:

1. Main.h the Objective-C class header for the Main component
2. Main.m the Objective-C class implementation for the Main component
3. Main.wo/Main.html containing the HTML markup
4. Main.wo/Main.wod containing the bindings of the dynamic elements that exist in the HTML to the application's objects, and
5. Main.wo/Main.woo which contains the text-encoding information.

<br />

[[edit][24]]

<>

#### Details.wo

The Details component is used to see how multiple page interactions and show additional component capabilities. The name is arbitrary.

Our custom component implementation will consist of five files:

1. Details.h the Objective-C class header for this component
2. Details.m the Objective-C class implementation for this component
3. Details.wo/Details.html containing the HTML markup
4. Details.wo/Details.wod containing the bindings of the dynamic elements that exist in the HTML to the application's objects, and
5. Details.wo/Details.woo which contains the text-encoding information.

[[edit][25]]

<>

#### Want to know more?

The .woo files can seem a little mysterious in that they are only being used here to identify the text-encoding information of the component. In actual fact, they can be used for a number of other, quite powerful purposes including serialised information related to direct database transactions initiated from the .html and .wod files - in other words to avoid writing code!

A more in-depth description of [Components][26] is available.

[[edit][27]]

<>

### The application dictionary

<br />

[[edit][28]]

<>

### Interface files

----

 Retrieved from "[http://wiki.gnustep.org/index.php/Creating\_A\_Simple\_GSWeb\_Application][29]"

[Categories][30]: [GNUstepWeb][31] | [Development][32]

##### Views

* [Article][33]
* [Discussion][34]
* [Edit][35]
* [History][36]

##### Personal tools

* [Create an account or log in][37]

[][38]

##### users

* [Applications][39]
* [Guides][40]
* [FAQ][41]
* [Get Help][42]
* [Report Bugs][43]
* [Donations][44]
* [Screenshots][45]

##### developers

* [Guides][46]
* [FAQ][47]
* [Base API (Foundation)][48]
* [GUI API (AppKit)][49]
* [Frameworks][50]

##### Navigation

* [Main Page][51]
* [Community portal][52]
* [Current events][53]
* [Recent changes][54]
* [Random page][55]
* [Help][56]

##### Search

##### Toolbox

* [What links here][57]
* [Related changes][58]
* [Upload file][59]
* [Special pages][60]
* [Printable version][61]

[![MediaWiki][62]][63]

* This page was last modified 18:34, 19 January 2008.
* This page has been accessed 32,261 times.
* Content is available under [GNU General Public License][64].
* [About GNUstepWiki][65]
* [Disclaimers][66]

  [1]: #Introduction
  [2]: #File_Components
  [3]: #The_Makefile
  [4]: #Mandatory_code
  [5]: #Components
  [6]: #Main.wo
  [7]: #Details.wo
  [8]: #Want_to_know_more.3F
  [9]: #The_application_dictionary
  [10]: #Interface_files
  [11]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=1 "Creating A Simple GSWeb Application"
  [12]: /index.php/GNUstepWeb "GNUstepWeb"
  [13]: /index.php/GDL2 "GDL2"
  [14]: /index.php/GSWeb "GSWeb"
  [15]: /index.php/GSWeb_application_deployment "GSWeb application deployment"
  [16]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=2 "Creating A Simple GSWeb Application"
  [17]: /index.php/GSWComponent "GSWComponent"
  [18]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=3 "Creating A Simple GSWeb Application"
  [19]: /index.php/GSWComponent "GSWComponent"
  [20]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=4 "Creating A Simple GSWeb Application"
  [21]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=5 "Creating A Simple GSWeb Application"
  [22]: /index.php/GSWComponent "GSWComponent"
  [23]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=6 "Creating A Simple GSWeb Application"
  [24]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=7 "Creating A Simple GSWeb Application"
  [25]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=8 "Creating A Simple GSWeb Application"
  [26]: /index.php/GSWComponent "GSWComponent"
  [27]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=9 "Creating A Simple GSWeb Application"
  [28]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit&section=10 "Creating A Simple GSWeb Application"
  [29]: http://wiki.gnustep.org/index.php/Creating_A_Simple_GSWeb_Application
  [30]: /index.php?title=Special:Categories&article=Creating_A_Simple_GSWeb_Application "Special:Categories"
  [31]: /index.php/Category:GNUstepWeb "Category:GNUstepWeb"
  [32]: /index.php/Category:Development "Category:Development"
  [33]: /index.php/Creating_A_Simple_GSWeb_Application
  [34]: /index.php?title=Talk:Creating_A_Simple_GSWeb_Application&action=edit
  [35]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=edit
  [36]: /index.php?title=Creating_A_Simple_GSWeb_Application&action=history
  [37]: /index.php?title=Special:Userlogin&returnto=Creating_A_Simple_GSWeb_Application
  [38]: /index.php/Main_Page "Main Page"
  [39]: /index.php/Category:Applications
  [40]: /index.php/User_Guides
  [41]: /index.php/User_FAQ
  [42]: /index.php/Get_Help
  [43]: /index.php/Report_Bugs
  [44]: /index.php/GNUstepWiki:Site_support
  [45]: /index.php/Screenshots
  [46]: /index.php/Developer_Guides
  [47]: /index.php/Developer_FAQ
  [48]: /index.php/Foundation
  [49]: /index.php/AppKit
  [50]: /index.php/Category:Frameworks
  [51]: /index.php/Main_Page
  [52]: /index.php/GNUstepWiki:Community_Portal
  [53]: /index.php/Current_events
  [54]: /index.php/Special:Recentchanges
  [55]: /index.php/Special:Random
  [56]: /index.php/Help:Contents
  [57]: /index.php/Special:Whatlinkshere/Creating_A_Simple_GSWeb_Application
  [58]: /index.php/Special:Recentchangeslinked/Creating_A_Simple_GSWeb_Application
  [59]: /index.php/Special:Upload
  [60]: /index.php/Special:Specialpages
  [61]: /index.php?title=Creating_A_Simple_GSWeb_Application&printable=yes&printable=yes
  [62]: /skins/common/images/poweredby_mediawiki_88x31.png
  [63]: http://www.mediawiki.org/
  [64]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [65]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [66]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"