<>

# Creating the header

### From GNUstepWiki	{#siteSub}

The core GNUstep libraries implement the OpenStep APIs and the newer Cocoa APIs introduced by Apple. The fact that these APIs have been produced by a litigious company, and the GNUstep project is used all over the world, means that we have to be a careful as possible to avoid the possibility of legal action being taken against GNUstep for copyright infringement in any country.

So ... we clearly can't simply copy Apple header files, but must produce our own header files which are functionally equivalent but as different as reasonably possible from the the Apple ones.

The easiest way to see how to do things is simply to look at a gnustep-base or gnustep-gui header file, but this article aims to point out key facts:

We use a standard header at the top of the file, which identifies the file, the copyright ownership (Free Software foundation), the author(s) etc.

We bracket the entire header in preprocessor conditionals to prevent it being used twice if included using the #include mechanism rather than #import.

We #import &lt;GNUstepBase/GSVersionMacros.h&gt; to get version management macros, and we use them to ensure that the header contents are only seen by applications which want to use the version of the API that Apple introduced the class in.

We include a fragment of code at start and end to ensure that the header can be read properly by a C++ compiler.

We list method names within the file as two groups (class methods, and then instance methods) with alphabetical order within each group ... this differs from Apples' usual practice of putting methods together in functional groups.

We use different formal argument names to those that apple use, since changing these does does not effect function of the API.

We use the GNUstep coding standards for line length, the use of white space and indentation. This means individual method names formatted differently than in Apple headers.

We put documentation in comments before each class and before each method (historically the documentation was often put in the source files, but in the header is better).

We hide instance variables by using a private pointer to the actual instance variables (unless we are certain we will never need to add more instance variables in later releases).

We use #if...#else...#endif to deal with Objective-C language variations ... most people don't use the more recent additions Apple have made to the Objective-C language, and you must assume that the header file will be read by a compiler which doesn't support those features, so you need to have alternatives which will work with other compiler versions.

Have a look at gnustep-base/Headers/Foundation/NSOperation.h as an example.

 Retrieved from "[http://wiki.gnustep.org/index.php/Creating\_the\_header][1]"

##### Views

* [Article][2]
* [Discussion][3]
* [Edit][4]
* [History][5]

##### Personal tools

* [Create an account or log in][6]

[][7]

##### users

* [Applications][8]
* [Guides][9]
* [FAQ][10]
* [Get Help][11]
* [Report Bugs][12]
* [Donations][13]
* [Screenshots][14]

##### developers

* [Guides][15]
* [FAQ][16]
* [Base API (Foundation)][17]
* [GUI API (AppKit)][18]
* [Frameworks][19]

##### Navigation

* [Main Page][20]
* [Community portal][21]
* [Current events][22]
* [Recent changes][23]
* [Random page][24]
* [Help][25]

##### Search

##### Toolbox

* [What links here][26]
* [Related changes][27]
* [Upload file][28]
* [Special pages][29]
* [Printable version][30]

[![MediaWiki][31]][32]

* This page was last modified 13:58, 8 February 2012.
* This page has been accessed 4,678 times.
* Content is available under [GNU General Public License][33].
* [About GNUstepWiki][34]
* [Disclaimers][35]

  [1]: http://wiki.gnustep.org/index.php/Creating_the_header
  [2]: /index.php/Creating_the_header
  [3]: /index.php?title=Talk:Creating_the_header&action=edit
  [4]: /index.php?title=Creating_the_header&action=edit
  [5]: /index.php?title=Creating_the_header&action=history
  [6]: /index.php?title=Special:Userlogin&returnto=Creating_the_header
  [7]: /index.php/Main_Page "Main Page"
  [8]: /index.php/Category:Applications
  [9]: /index.php/User_Guides
  [10]: /index.php/User_FAQ
  [11]: /index.php/Get_Help
  [12]: /index.php/Report_Bugs
  [13]: /index.php/GNUstepWiki:Site_support
  [14]: /index.php/Screenshots
  [15]: /index.php/Developer_Guides
  [16]: /index.php/Developer_FAQ
  [17]: /index.php/Foundation
  [18]: /index.php/AppKit
  [19]: /index.php/Category:Frameworks
  [20]: /index.php/Main_Page
  [21]: /index.php/GNUstepWiki:Community_Portal
  [22]: /index.php/Current_events
  [23]: /index.php/Special:Recentchanges
  [24]: /index.php/Special:Random
  [25]: /index.php/Help:Contents
  [26]: /index.php/Special:Whatlinkshere/Creating_the_header
  [27]: /index.php/Special:Recentchangeslinked/Creating_the_header
  [28]: /index.php/Special:Upload
  [29]: /index.php/Special:Specialpages
  [30]: /index.php?title=Creating_the_header&printable=yes&printable=yes
  [31]: /skins/common/images/poweredby_mediawiki_88x31.png
  [32]: http://www.mediawiki.org/
  [33]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [34]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [35]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"