<>

# Deployment on Linux

### From GNUstepWiki	{#siteSub}

Deploying a GNUstep-using application is easy if it is intended for inclusion in linux distributions or if you are deploying in an controlled environment, e.g. in the enterprise. However, there are a number of reasons why you would need to create end-user deployable packages that already include GNUstep:

* your application depends on features that are not included yet in linux distributions (libobjc2, llvm, /recent/ GNUstep versions) or on a patched GNUstep version or you want to be sure your application is only used with a specific GNUstep theme...
* you want to offer your self-contained binary version of your application for download without having your users need to install GNUstep (e.g. commercial apps)

In this case its best to bundle GNUstep with your application binary. First off you need to decide on the oldest linux distribution you want to support, since compiled binaries often do not run on older linux versions than they were built on. I am using Ubuntu 10.04 LTS for this purpose.

When you have installed this distribution you first need to take care of the dependencies of GNUstep itself, that you do not want your resulting installation to depend on. For example most distributions ship without libffi, so if you want to use a libffi-enabled GNUstep you need to statically link it or ship it in your download. **This guide assumes you've built static versions of libffi, libpng, liftiff and libxml2 and installed them into: ~/build/** (on AMD64 you \*must\* build all libraries --with-pic else they won't work)

Now you need to compile standalone versions of GNUstep. These instructions depend on at least revision 34026 of GNUstep to work - as of October 2011 there have been no releases of GNUstep with the necessary features and fixes therefore you need the SVN version. It is also a good idea to configure GNUstep to use only the bare minimum of the features that you need - e.g getting problems because GNUstep depends on libjpeg although you aren't using it can be avoided.

Optional: Install LLVM &gt;= 2.9 as compiler

Checkout GNUstep SVN:

	 svn co <http://svn.gna.org/svn/gnustep/modules/core>

Install GNUstep make:

	 cd core/make
	 ./configure --with-layout=standalone
	 make &amp;&amp; make install

Source GNUstep envionment:

	 . ~/standalone/Makefiles/GNUstep.sh

Optional: Install libobjc2 if you need a modern runtime e.g. for blocks support. You need to configure and install GNUstep make a second time after installing libobjc2 if you decide on using it, in order for it to get picked up. Note that libobjc2 &gt; 1.5.1 doesn't install itself into the GNUstep environment by default anymore, so you need to take care it gets installed into ~/standalone/: PREFIX=~/standalone/ make install

Build GNUstep base:

	 PATH=$PATH:~/build/bin ./configure --with-config-file=./ --with-default-config=standalone.conf --with-include-dir=${HOME}/build/include/
	     --with-library-dir=${HOME}/build/lib/ --with-ffi-include=${HOME}/build/include/ --with-ffi-library=${HOME}/build/lib/
	 make &amp;&amp; make install

<br />
 Build GNUstep gui:

	 ./configure --with-tiff-include=${HOME}/build/include/ --with-tiff-library=${HOME}/build/lib/ --disable-jpeg
	 make &amp;&amp; make install

Build GNUstep back (you need to install development packages for X11 and libart):

	 ./configure
	 make &amp;&amp; make install

<br />
 Success, now you have a standalone GNUstep environment in ~/standalone/

Next step is installing the [Themes][1] you want your application to use into ~/standalone/Themes/ since the default look will probably anger your users. The best choice for deployment on linux is probably the gnome-theme for nice system integration but this may create problems with library dependencies across distributions so i've settled on the Silver theme for now.

Place a file named GlobalDefaults.plist into ~/standalone/ to change the Theme, make GNUstep use horizontal menus like everyone else and change other options:

<br />

	&lt;?xml version="1.0" encoding="UTF-8"?&gt;
	&lt;!DOCTYPE plist PUBLIC "-//GNUstep//DTD plist 0.9//EN" "http://www.gnustep.org/plist-0_9.xml"&gt;
	&lt;plist version="0.9"&gt;
	  &lt;dict&gt;
		&lt;key&gt;GSTheme&lt;/key&gt;
		&lt;string&gt;Silver&lt;/string&gt;
		&lt;key&gt;NSMenuInterfaceStyle&lt;/key&gt;
		&lt;string&gt;NSWindows95InterfaceStyle&lt;/string&gt;
		&lt;key&gt;NSUseRunningCopy&lt;/key&gt;
		&lt;string&gt;YES&lt;/string&gt;
		&lt;key&gt;GSSuppressAppIcon&lt;/key&gt;
		&lt;string&gt;YES&lt;/string&gt;
	  &lt;/dict&gt;
	&lt;/plist&gt;

Now just build your application (cd AppSource; make), move the standalone folder into your application bundle, place a launcher script next to your application bundle, compress the application bundle and the launcher script and place it somewhere for download. Don't forget to test the result on a variety of distributions.

Sample application launcher script:

	 export LD_LIBRARY_PATH=`pwd`/YourApplicationName.app/standalone:$LD_LIBRARY_PATH
	 exec YourApplicationName.app/YourApplicationName

<br />
 There is one more issue with deployment on linux: 64 / 32 bit compatibility. On Mac OS X and Windows you can just deploy a 32-bit package and it will run fine on 64-bit too. On 64-bit linux you can run 32-bin binaries too, but the 32-bit libraries are not installed by default and its only easily possible to install 32-bit libraries on Fedora but not on Debian/Ubuntu. Therefore your only options are either to:

* build a 32-bit package andÃÂ link \*everything\* statically so it runs fine on 64-bit too where the libraries are missing.
* build gnustep and your app in a 32-bit and a 64-bit version and select the proper version in your launcher script (or host 2 different packages for download).

 Retrieved from "[http://wiki.gnustep.org/index.php/Deployment\_on\_Linux][2]"

[Categories][3]: [Deployment][4] | [Linux][5]

##### Views

* [Article][6]
* [Discussion][7]
* [Edit][8]
* [History][9]

##### Personal tools

* [Create an account or log in][10]

[][11]

##### users

* [Applications][12]
* [Guides][13]
* [FAQ][14]
* [Get Help][15]
* [Report Bugs][16]
* [Donations][17]
* [Screenshots][18]

##### developers

* [Guides][19]
* [FAQ][20]
* [Base API (Foundation)][21]
* [GUI API (AppKit)][22]
* [Frameworks][23]

##### Navigation

* [Main Page][24]
* [Community portal][25]
* [Current events][26]
* [Recent changes][27]
* [Random page][28]
* [Help][29]

##### Search

##### Toolbox

* [What links here][30]
* [Related changes][31]
* [Upload file][32]
* [Special pages][33]
* [Printable version][34]

[![MediaWiki][35]][36]

* This page was last modified 01:31, 25 November 2011.
* This page has been accessed 10,164 times.
* Content is available under [GNU General Public License][37].
* [About GNUstepWiki][38]
* [Disclaimers][39]

  [1]: /index.php/Themes "Themes"
  [2]: http://wiki.gnustep.org/index.php/Deployment_on_Linux
  [3]: /index.php?title=Special:Categories&article=Deployment_on_Linux "Special:Categories"
  [4]: /index.php?title=Category:Deployment&action=edit "Category:Deployment"
  [5]: /index.php?title=Category:Linux&action=edit "Category:Linux"
  [6]: /index.php/Deployment_on_Linux
  [7]: /index.php?title=Talk:Deployment_on_Linux&action=edit
  [8]: /index.php?title=Deployment_on_Linux&action=edit
  [9]: /index.php?title=Deployment_on_Linux&action=history
  [10]: /index.php?title=Special:Userlogin&returnto=Deployment_on_Linux
  [11]: /index.php/Main_Page "Main Page"
  [12]: /index.php/Category:Applications
  [13]: /index.php/User_Guides
  [14]: /index.php/User_FAQ
  [15]: /index.php/Get_Help
  [16]: /index.php/Report_Bugs
  [17]: /index.php/GNUstepWiki:Site_support
  [18]: /index.php/Screenshots
  [19]: /index.php/Developer_Guides
  [20]: /index.php/Developer_FAQ
  [21]: /index.php/Foundation
  [22]: /index.php/AppKit
  [23]: /index.php/Category:Frameworks
  [24]: /index.php/Main_Page
  [25]: /index.php/GNUstepWiki:Community_Portal
  [26]: /index.php/Current_events
  [27]: /index.php/Special:Recentchanges
  [28]: /index.php/Special:Random
  [29]: /index.php/Help:Contents
  [30]: /index.php/Special:Whatlinkshere/Deployment_on_Linux
  [31]: /index.php/Special:Recentchangeslinked/Deployment_on_Linux
  [32]: /index.php/Special:Upload
  [33]: /index.php/Special:Specialpages
  [34]: /index.php?title=Deployment_on_Linux&printable=yes&printable=yes
  [35]: /skins/common/images/poweredby_mediawiki_88x31.png
  [36]: http://www.mediawiki.org/
  [37]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [38]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [39]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"