<>

# Developer Guides

### From GNUstepWiki	{#siteSub}

This page is intended as a collection of guides for developers.

<table>
<tr>
<td>
## Contents
* [1 Introductory Articles on GNUstep Development][1]
  * [1\.1 Installation][2]
  * [1\.2 GNUstep Libraries and Tools][3]
  * [1\.3 GNUstep Base Programming Manual][4]
  * [1\.4 GNUStep Macros][5]
  * [1\.5 (GUI) Programming under GNUstep][6]
  * [1\.6 Writing Makefiles][7]
  * [1\.7 Sample GNUstep Programs][8]
* [2 General][9]
  * [2\.1 Coding for Portability][10]
  * [2\.2 Using Property Lists][11]
  * [2\.3 Deployment on Windows][12]
  * [2\.4 Translating GNUstep][13]
  * [2\.5 Contributing to GNUstep core libraries][14]
* [3 Graphical Applications][15]
  * [3\.1 Simple Graphical Application Design][16]
  * [3\.2 Document-based Application Design][17]
* [4 Web Applications][18]
* [5 Other Information][19]
  * [5\.1 Developer sites][20]
</td>
</tr>
</table>

[[edit][21]]

<>

## Introductory Articles on GNUstep Development

<table>
<tr>
<th> This article or section is a stub (i.e., in need of additional material).<br />
You can help us by [**expanding it**][22]</th>
</tr>
</table>

<br />

[[edit][23]]

<>

### [Installation][24]

How to get started using GNUStep, because it is not immediately obvious, and we appologize for that.

[[edit][25]]

<>

### [GNUstep Libraries and Tools][26]

A general overview of GNUstep.

[[edit][27]]

<>

### [GNUstep Base Programming Manual][28]

The aim of this manual is to introduce you to the Objective-C language and the GNUstep development environment, in particular the Base library. The manual is organised to give you a tutorial introduction to the language and APIs, by using examples whenever possible, rather than providing a lengthy abstract description.

While Objective-C is not a difficult language to learn or use, some of the terms may be unfamiliar, especially to those that have not programmed using an object-oriented programming language before. Whenever possible, concepts will be explained in simple terms rather than in more advanced programming terms, and comparisons to other languages will be used to aid in illustration.

[[edit][29]]

<>

### [GNUStep Macros][30]

See a define, but don't know what it's for, you are not alone. See this article for a reference to various macros, or otherwise unusual language extensions that you may see when reading the GNUStep Code.

[[edit][31]]

<>

### [(GUI) Programming under GNUstep][32]

This tutorial will introduce you to the [AppKit][33] classes and how to use [Gorm][34] to create graphical interfaces.

[[edit][35]]

<>

### [Writing Makefiles][36]

The Makefile package is a system of make commands that is designed to encapsulate all the complex details of building and installing various types of projects from libraries to applications to documentation. This frees the developer to focus on the details of their particular project. Only a fairly simple main makefile need to be written which specifies the type of project and files involved in the project.

[[edit][37]]

<>

### Sample GNUstep Programs

This isn't really an article but rather a collection of small "codified guides" for the pragmatic programmer who wants to explore GNUstep by looking at and messing around with example code. This is best done while reading about basic concepts of OpenStep or Cocoa with the API documentation ([Foundation][38], [AppKit][39]) open in the background. Get the gnustep-examples package from [here][40]

[[edit][41]]

<>

## General

[[edit][42]]

<>

### [Coding for Portability][43]

Writing code that will compile and then run on different platforms can be surprisingly easy. This guide describes some straight-forward steps to take to make your program easy to port to new platforms.

[[edit][44]]

<>

### [Using Property Lists][45]

A regular issue that programmers face is storing structured configuration information, and reading it back. GNUstep has a standard mechanism that can be used for this task, amongst others: Property Lists.

[[edit][46]]

<>

### [Deployment on Windows][47]

This article will tell you how to deploy GNUstep applications on Windows.

[[edit][48]]

<>

### [Translating GNUstep][49]

Translation of GNUstep applications involves a number of steps, including translation of GNUstep Base and GNUstep GUI.

[[edit][50]]

<>

### [Contributing to GNUstep core libraries][51]

Contributing to the core libraries is what everyone loves you for the most ... but it's quite a step to go from simple bug fixes/patches to major new code contributions. Follow the link above to see how.

When you read the information on [Contributing to GNUstep core libraries][52], please keep in mind that while it was written primarily form the point of view of contributing code to the gnustep-base library, the principles all apply to the gnustep-gui library (and other library code too). Also, a lot of the information is also relevant to contributions to application/tool code, not just library code.

[[edit][53]]

<>

## Graphical Applications

[[edit][54]]

<>

### Simple Graphical Application Design

GNUstep includes several sophisticated development tools. GNUstep GUI interfaces are designed using [Gorm][55] (Graphical Object Relationship Modeler), an elegant application developed by Gregory Casamento. (See his [blog][56] for the latest news on GORM.) There are two proto-IDEs, [ProjectCenter][57] and [ProjectManager][58].

There are several introductory tutorials for using these development tools. The first [tutorial][59] by Pierre-Yves Rivaille is a classic demonstrating the process used to create the ubiquitous currency converter application. A second [tutorial][60] by Yen-Ju Chen is somewhat more in-depth and extensive.

Nicolas Roard created a [video][61] demonstrating the process of developing a simple calculator, and another [video][62] here by SaÃÂ¡o Kiselkov if you feel the need to create another currency converter.

[[edit][63]]

<>

### [Document-based Application Design][64]

One of the most common use-patterns of applications on modern platforms is that of document-based applications --- applications which can have several active user-controlled contexts. Some familar examples might be a word processor where the user may have multiple document windows concurrently, or a web browser which allows a user to have a number of different browser windows open at the same time. This guide provides information and tips on how to code this style of application.

<br />

[[edit][65]]

<>

## Web Applications

Please have a look at [Creating A Simple GSWeb Application][66] to learn how to create a [GNUstep Web][67] application.

[[edit][68]]

<>

## Other Information

[[edit][69]]

<>

### Developer sites

* [GNUstep HelpCenter][70]

 Retrieved from "[http://wiki.gnustep.org/index.php/Developer\_Guides][71]"

[Categories][72]: [Stub][73] | [Development][74]

##### Views

* [Article][75]
* [Discussion][76]
* [Edit][77]
* [History][78]

##### Personal tools

* [Create an account or log in][79]

[][80]

##### users

* [Applications][81]
* [Guides][82]
* [FAQ][83]
* [Get Help][84]
* [Report Bugs][85]
* [Donations][86]
* [Screenshots][87]

##### developers

* [Guides][88]
* [FAQ][89]
* [Base API (Foundation)][90]
* [GUI API (AppKit)][91]
* [Frameworks][92]

##### Navigation

* [Main Page][93]
* [Community portal][94]
* [Current events][95]
* [Recent changes][96]
* [Random page][97]
* [Help][98]

##### Search

##### Toolbox

* [What links here][99]
* [Related changes][100]
* [Upload file][101]
* [Special pages][102]
* [Printable version][103]

[![MediaWiki][104]][105]

* This page was last modified 21:29, 9 December 2013.
* This page has been accessed 132,925 times.
* Content is available under [GNU General Public License][106].
* [About GNUstepWiki][107]
* [Disclaimers][108]

  [1]: #Introductory_Articles_on_GNUstep_Development
  [2]: #Installation
  [3]: #GNUstep_Libraries_and_Tools
  [4]: #GNUstep_Base_Programming_Manual
  [5]: #GNUStep_Macros
  [6]: #.28GUI.29_Programming_under_GNUstep
  [7]: #Writing_Makefiles
  [8]: #Sample_GNUstep_Programs
  [9]: #General
  [10]: #Coding_for_Portability
  [11]: #Using_Property_Lists
  [12]: #Deployment_on_Windows
  [13]: #Translating_GNUstep
  [14]: #Contributing_to_GNUstep_core_libraries
  [15]: #Graphical_Applications
  [16]: #Simple_Graphical_Application_Design
  [17]: #Document-based_Application_Design
  [18]: #Web_Applications
  [19]: #Other_Information
  [20]: #Developer_sites
  [21]: /index.php?title=Developer_Guides&action=edit&section=1 "Developer Guides"
  [22]: http://wiki.gnustep.org/index.php?title=Developer_Guides&action=edit "http://wiki.gnustep.org/index.php?title=Developer Guides&action=edit"
  [23]: /index.php?title=Developer_Guides&action=edit&section=2 "Developer Guides"
  [24]: /index.php/Installation "Installation"
  [25]: /index.php?title=Developer_Guides&action=edit&section=3 "Developer Guides"
  [26]: /index.php/GNUstep_Suite "GNUstep Suite"
  [27]: /index.php?title=Developer_Guides&action=edit&section=4 "Developer Guides"
  [28]: http://www.gnustep.org/resources/documentation/Developer/Base/ProgrammingManual/manual_toc.html "http://www.gnustep.org/resources/documentation/Developer/Base/ProgrammingManual/manual toc.html"
  [29]: /index.php?title=Developer_Guides&action=edit&section=5 "Developer Guides"
  [30]: /index.php/GNUStep_Macros "GNUStep Macros"
  [31]: /index.php?title=Developer_Guides&action=edit&section=6 "Developer Guides"
  [32]: http://www.roard.com/docs/lmf2.article/en.html "http://www.roard.com/docs/lmf2.article/en.html"
  [33]: /index.php/AppKit "AppKit"
  [34]: /index.php/Gorm "Gorm"
  [35]: /index.php?title=Developer_Guides&action=edit&section=7 "Developer Guides"
  [36]: /index.php/Writing_Makefiles "Writing Makefiles"
  [37]: /index.php?title=Developer_Guides&action=edit&section=8 "Developer Guides"
  [38]: /index.php/Foundation "Foundation"
  [39]: /index.php/AppKit "AppKit"
  [40]: ftp://ftp.gnustep.org/pub/gnustep/core/ "ftp://ftp.gnustep.org/pub/gnustep/core/"
  [41]: /index.php?title=Developer_Guides&action=edit&section=9 "Developer Guides"
  [42]: /index.php?title=Developer_Guides&action=edit&section=10 "Developer Guides"
  [43]: /index.php/Writing_portable_code "Writing portable code"
  [44]: /index.php?title=Developer_Guides&action=edit&section=11 "Developer Guides"
  [45]: /index.php/Property_Lists "Property Lists"
  [46]: /index.php?title=Developer_Guides&action=edit&section=12 "Developer Guides"
  [47]: /index.php/Deployment_on_Windows "Deployment on Windows"
  [48]: /index.php?title=Developer_Guides&action=edit&section=13 "Developer Guides"
  [49]: /index.php/Adding_a_new_Natural_Language_to_GNUstep "Adding a new Natural Language to GNUstep"
  [50]: /index.php?title=Developer_Guides&action=edit&section=14 "Developer Guides"
  [51]: /index.php/Contributing_to_GNUstep_core_libraries "Contributing to GNUstep core libraries"
  [52]: /index.php/Contributing_to_GNUstep_core_libraries "Contributing to GNUstep core libraries"
  [53]: /index.php?title=Developer_Guides&action=edit&section=15 "Developer Guides"
  [54]: /index.php?title=Developer_Guides&action=edit&section=16 "Developer Guides"
  [55]: /index.php/Gorm "Gorm"
  [56]: http://heronsperch.blogspot.com/ "http://heronsperch.blogspot.com/"
  [57]: /index.php/ProjectCenter "ProjectCenter"
  [58]: /index.php/ProjectManager "ProjectManager"
  [59]: http://www.gnustep.it/pierre-yves/index.html "http://www.gnustep.it/pierre-yves/index.html"
  [60]: http://www.nongnu.org/gstutorial/ "http://www.nongnu.org/gstutorial/"
  [61]: http://gnustep.org/experience/DevelopmentDemonstration.html "http://gnustep.org/experience/DevelopmentDemonstration.html"
  [62]: http://home.gna.org/pmanager/videos.html "http://home.gna.org/pmanager/videos.html"
  [63]: /index.php?title=Developer_Guides&action=edit&section=17 "Developer Guides"
  [64]: /index.php/Document_based_applications "Document based applications"
  [65]: /index.php?title=Developer_Guides&action=edit&section=18 "Developer Guides"
  [66]: /index.php/Creating_A_Simple_GSWeb_Application "Creating A Simple GSWeb Application"
  [67]: /index.php/GNUstepWeb "GNUstepWeb"
  [68]: /index.php?title=Developer_Guides&action=edit&section=19 "Developer Guides"
  [69]: /index.php?title=Developer_Guides&action=edit&section=20 "Developer Guides"
  [70]: http://www.roard.com/docs/ "http://www.roard.com/docs/"
  [71]: http://wiki.gnustep.org/index.php/Developer_Guides
  [72]: /index.php?title=Special:Categories&article=Developer_Guides "Special:Categories"
  [73]: /index.php/Category:Stub "Category:Stub"
  [74]: /index.php/Category:Development "Category:Development"
  [75]: /index.php/Developer_Guides
  [76]: /index.php/Talk:Developer_Guides
  [77]: /index.php?title=Developer_Guides&action=edit
  [78]: /index.php?title=Developer_Guides&action=history
  [79]: /index.php?title=Special:Userlogin&returnto=Developer_Guides
  [80]: /index.php/Main_Page "Main Page"
  [81]: /index.php/Category:Applications
  [82]: /index.php/User_Guides
  [83]: /index.php/User_FAQ
  [84]: /index.php/Get_Help
  [85]: /index.php/Report_Bugs
  [86]: /index.php/GNUstepWiki:Site_support
  [87]: /index.php/Screenshots
  [88]: /index.php/Developer_Guides
  [89]: /index.php/Developer_FAQ
  [90]: /index.php/Foundation
  [91]: /index.php/AppKit
  [92]: /index.php/Category:Frameworks
  [93]: /index.php/Main_Page
  [94]: /index.php/GNUstepWiki:Community_Portal
  [95]: /index.php/Current_events
  [96]: /index.php/Special:Recentchanges
  [97]: /index.php/Special:Random
  [98]: /index.php/Help:Contents
  [99]: /index.php/Special:Whatlinkshere/Developer_Guides
  [100]: /index.php/Special:Recentchangeslinked/Developer_Guides
  [101]: /index.php/Special:Upload
  [102]: /index.php/Special:Specialpages
  [103]: /index.php?title=Developer_Guides&printable=yes&printable=yes
  [104]: /skins/common/images/poweredby_mediawiki_88x31.png
  [105]: http://www.mediawiki.org/
  [106]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [107]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [108]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"