<>

# DevelopmentKit

### From GNUstepWiki	{#siteSub}

Develompent Kit Framework is [Objective-C][1]/[GNUstep][2] framework for generating Objective C code based projects and sources from applications.

Features:

* class compositing
* [Objective-C][3] source parsing and transforming into development objects (classes, methods, variables,...)
* source file generation using templates
* project building

Project Page: <https://savannah.nongnu.org/projects/develkit/>

[Browse CVS Tree][4]

Author: [Stefan Urbanek][5]

[[edit][6]]

<>

## Tools

[[edit][7]]

<>

### dkautogen

Autogenerate [Objective-C][8] Interface and Implementation methods

Usage:

	dkautogen file1.h file2.h ...

Type 'dkautogen help' for more information.

To each .h and corresponding .m file a category DKGenerated is appended. If there is already such category, then it is replaced.

Instance variable keywords

	 hidden         - do not generate accessor methods
	 exposed        - expose accessor methods
	 retained       - object is retained
	 notretained    - object is NOT retained (weak reference)
	 readonly       - instance variable is read only (setter is not generated)
	 mutable        - instance variable is mutable (setter is generated despite "readonly" class default)
	 notarchived    - ignore in archiving
	 object         - instance variable is an object (see below)
	 customaccess   - do not generate implementation of accessor methods, generate interface only

Class keywords (defaults for all instance variables)

	 hidden         - all ivars are hidden
	 exposed        - all ivars are exposed (accessors are generated)
	 retained       - all objects are retained
	 notretained    - objects are NOT retained
	 readonly       - all instance variable are read only
	 objects        - treat all unknown types as objects
	 customarchive  - do not generate archiving methods
	 nosuperarchive - do not call archiving in superclass
	 customdealloc  - do not generate -dealloc method

**Known types**

All standard C types including [NSPoint][9], [NSSize][10], [NSRect][11] and [NSRange][12] are treated as non-objects. By default only id and Class types are treated as objects.

Generated methods by default: accessors (getter and setter), dealloc methon, initWithCoder:, and encodeWithCoder

**How to use**

Attributes are written in same comments used for auto-documentation. They are read from comments after the LAST pipe '|' character in the comment and they should be separated by spaces. Example:

	   NSString *name; /** Object name | object readonly retained */

Class defaults are written immediately before @interface:

	   /** This is my class | nosuperarchive retained objects */
	   @interface MyClassÃÂ : NSObject

Preferences (also usable as switches on commandline with '-' prefix):

	   interfaceTemplate      - path to .h file template
	   implementationTemplate - path to .m file template
	   beginTag               - tag used to mark beginning of generated code
	   endTag                 - tag used to mark end of generated code

Example:

	   dkautogen -implementationTemplate MyTemplate.m SomeClass.h

[[edit][13]]

<>

## Classes

* DKBuildMessage
* DKClass
* DKFramework
* DKFrameworkManager
* DKMethod
* DKObjectiveCParser
* DKProjectBuilder
* DKProject
* DKSourceGenerator
* DKTemplateMerger
* DKVariable

DevelKit reuses class [AGSParser][14] from [autogsdoc][15].

 Retrieved from "<http://wiki.gnustep.org/index.php/DevelopmentKit>"

[Categories][16]: [Development Frameworks][17]

##### Views

* [Article][18]
* [Discussion][19]
* [Edit][20]
* [History][21]

##### Personal tools

* [Create an account or log in][22]

[][23]

##### users

* [Applications][24]
* [Guides][25]
* [FAQ][26]
* [Get Help][27]
* [Report Bugs][28]
* [Donations][29]
* [Screenshots][30]

##### developers

* [Guides][31]
* [FAQ][32]
* [Base API (Foundation)][33]
* [GUI API (AppKit)][34]
* [Frameworks][35]

##### Navigation

* [Main Page][36]
* [Community portal][37]
* [Current events][38]
* [Recent changes][39]
* [Random page][40]
* [Help][41]

##### Search

##### Toolbox

* [What links here][42]
* [Related changes][43]
* [Upload file][44]
* [Special pages][45]
* [Printable version][46]

[![MediaWiki][47]][48]

* This page was last modified 15:27, 23 October 2006.
* This page has been accessed 23,779 times.
* Content is available under [GNU General Public License][49].
* [About GNUstepWiki][50]
* [Disclaimers][51]

  [1]: /index.php/Objective-C "Objective-C"
  [2]: /index.php/GNUstep "GNUstep"
  [3]: /index.php/Objective-C "Objective-C"
  [4]: http://savannah.nongnu.org/cgi-bin/viewcvs/develkit/ "http://savannah.nongnu.org/cgi-bin/viewcvs/develkit/"
  [5]: /index.php/User:Stefan_Urbanek "User:Stefan Urbanek"
  [6]: /index.php?title=DevelopmentKit&action=edit&section=1 "DevelopmentKit"
  [7]: /index.php?title=DevelopmentKit&action=edit&section=2 "DevelopmentKit"
  [8]: /index.php/Objective-C "Objective-C"
  [9]: /index.php?title=NSPoint&action=edit "NSPoint"
  [10]: /index.php?title=NSSize&action=edit "NSSize"
  [11]: /index.php?title=NSRect&action=edit "NSRect"
  [12]: /index.php?title=NSRange&action=edit "NSRange"
  [13]: /index.php?title=DevelopmentKit&action=edit&section=3 "DevelopmentKit"
  [14]: /index.php?title=AGSParser&action=edit "AGSParser"
  [15]: /index.php?title=Autogsdoc&action=edit "Autogsdoc"
  [16]: /index.php?title=Special:Categories&article=DevelopmentKit "Special:Categories"
  [17]: /index.php/Category:Development_Frameworks "Category:Development Frameworks"
  [18]: /index.php/DevelopmentKit
  [19]: /index.php?title=Talk:DevelopmentKit&action=edit
  [20]: /index.php?title=DevelopmentKit&action=edit
  [21]: /index.php?title=DevelopmentKit&action=history
  [22]: /index.php?title=Special:Userlogin&returnto=DevelopmentKit
  [23]: /index.php/Main_Page "Main Page"
  [24]: /index.php/Category:Applications
  [25]: /index.php/User_Guides
  [26]: /index.php/User_FAQ
  [27]: /index.php/Get_Help
  [28]: /index.php/Report_Bugs
  [29]: /index.php/GNUstepWiki:Site_support
  [30]: /index.php/Screenshots
  [31]: /index.php/Developer_Guides
  [32]: /index.php/Developer_FAQ
  [33]: /index.php/Foundation
  [34]: /index.php/AppKit
  [35]: /index.php/Category:Frameworks
  [36]: /index.php/Main_Page
  [37]: /index.php/GNUstepWiki:Community_Portal
  [38]: /index.php/Current_events
  [39]: /index.php/Special:Recentchanges
  [40]: /index.php/Special:Random
  [41]: /index.php/Help:Contents
  [42]: /index.php/Special:Whatlinkshere/DevelopmentKit
  [43]: /index.php/Special:Recentchangeslinked/DevelopmentKit
  [44]: /index.php/Special:Upload
  [45]: /index.php/Special:Specialpages
  [46]: /index.php?title=DevelopmentKit&printable=yes&printable=yes
  [47]: /skins/common/images/poweredby_mediawiki_88x31.png
  [48]: http://www.mediawiki.org/
  [49]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [50]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [51]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"