<>

# GNUstep under Ubuntu Linux

### From GNUstepWiki	{#siteSub}

	Objective-C under Ubuntu Linux

<table>
<tr>
<td>
## Contents
* [1 Compiling Everything from Scratch][1]
  * [1\.1 16\.04 &amp; 16.10][2]
  * [1\.2 14\.04 &amp; 15.04][3]
  * [1\.3 12\.04][4]
* [2 Test Code][5]
</td>
</tr>
</table>

[[edit][6]]

<>

## Compiling Everything from Scratch

The following scripts compiles and installs everything needed for Objective-C 2.0 from scratch. The script uses clang and libobjc2 for all the awesome new features like ARC, blocks, etc.

Reference manuals for GNUStep, including available APIs, etc, are available at <http://www.gnustep.org/developers/documentation.html>

<br />

[[edit][7]]

<>

### 16.04 &amp; 16.10

In addition to building everything, this script also provides the ability to build the most recent version of four apps: Project Center, Gorm, GWorkspace, and System Preferences.

	#!/bin/bash

	# Show prompt function
	function showPrompt()
	{
	  if [ "$PROMPT" = true ]ÃÂ ; then
	    echo -e "\n\n"
	    read -p "${GREEN}Press enter to continue...${NC}"
	  fi
	}

	# Set colors
	GREEN=`tput setaf 2`
	NC=`tput sgr0` # No Color

	# Set to true to also build and install apps
	APPS=true

	# Set to true to pause after each build to verify successful build and installation
	PROMPT=true

	# Install Requirements
	sudo apt update

	echo -e "\n\n${GREEN}Installing dependencies...${NC}"
	sudo apt -y install clang git ninja cmake libffi-dev libxml2-dev \
	libgnutls28-dev libicu-dev libblocksruntime-dev libkqueue-dev libpthread-workqueue-dev autoconf libtool \
	libjpeg-dev libtiff-dev libffi-dev libcairo-dev libx11-dev:i386 libxt-dev libxft-dev

	if [ "$APPS" = true ]ÃÂ ; then
	  sudo apt -y install curl
	fi

	# Create build directory
	mkdir GNUstep-build
	cd GNUstep-build

	# Set clang as compiler
	export CC=clang
	export CXX=clang++

	# Checkout sources
	echo -e "\n\n${GREEN}Checking out sources...${NC}"
	git clone https://github.com/nickhutchinson/libdispatch.git
	git clone https://github.com/gnustep/libobjc2.git
	git clone https://github.com/gnustep/make
	git clone https://github.com/gnustep/base.git
	git clone https://github.com/gnustep/gui.git
	git clone https://github.com/gnustep/back.git

	if [ "$APPS" = true ]ÃÂ ; then
	  git clone https://github.com/gnustep/projectcenter.git
	  git clone https://github.com/gnustep/gorm.git
	  git clone https://github.com/gnustep/gworkspace.git
	 	curl -O ftp://ftp.gnustep.org/pub/gnustep/usr-apps/SystemPreferences-1.2.0.tar.gz
	  tar xvzf SystemPreferences-1.2.0.tar.gz
	fi

	showPrompt

	# Build GNUstep make first time
	echo -e "\n\n"
	echo -e "${GREEN}Building GNUstep-make for the first time...${NC}"
	cd make
	./configure --enable-debug-by-default --with-layout=gnustep --enable-objc-nonfragile-abi --enable-objc-arc
	make -j8
	sudo -E make install

	. /usr/GNUstep/System/Library/Makefiles/GNUstep.sh
	echo ". /usr/GNUstep/System/Library/Makefiles/GNUstep.sh" &gt;&gt; ~/.bashrc

	showPrompt

	# Build libdispatch
	echo -e "\n\n"
	echo -e "${GREEN}Building libdispatch...${NC}"
	cd ../libdispatch
	rm -Rf build
	mkdir build &amp;&amp; cd build
	../configure  --prefix=/usr
	make
	sudo make install
	sudo ldconfig

	showPrompt

	# Build libobjc2
	echo -e "\n\n"
	echo -e "${GREEN}Building libobjc2...${NC}"
	cd ../../libobjc2
	rm -Rf build
	mkdir build &amp;&amp; cd build
	cmake ../ -DCMAKE_C_COMPILER=clang -DCMAKE_CXX_COMPILER=clang -DCMAKE_ASM_COMPILER=clang -DTESTS=OFF
	cmake --build .
	sudo -E make install
	sudo ldconfig

	export LDFLAGS=-ldispatch

	showPrompt

	OBJCFLAGS="-fblocks -fobjc-runtime=gnustep-1.8.1"

	# Build GNUstep make second time
	echo -e "\n\n"
	echo -e "${GREEN}Building GNUstep-make for the second time...${NC}"
	cd ../../make
	./configure --enable-debug-by-default --with-layout=gnustep --enable-objc-nonfragile-abi --enable-objc-arc
	make -j8
	sudo -E make install

	. /usr/GNUstep/System/Library/Makefiles/GNUstep.sh

	showPrompt

	# Build GNUstep base
	echo -e "\n\n"
	echo -e "${GREEN}Building GNUstep-base...${NC}"
	cd ../base/
	./configure
	make -j8
	sudo -E make install

	showPrompt

	# Build GNUstep GUI
	echo -e "\n\n"
	echo -e "${GREEN} Building GNUstep-gui...${NC}"
	cd ../gui
	./configure
	make -j8
	sudo -E make install

	showPrompt

	# Build GNUstep back
	echo -e "\n\n"
	echo -e "${GREEN}Building GNUstep-back...${NC}"
	cd ../back
	./configure
	make -j8
	sudo -E make install

	showPrompt

	. /usr/GNUstep/System/Library/Makefiles/GNUstep.sh

	if [ "$APPS" = true ]ÃÂ ; then
	  echo -e "${GREEN}Building ProjectCenter...${NC}"
	  cd ../projectcenter/
	  make -j8
	  sudo -E make install

	  showPrompt

	  echo -e "${GREEN}Building Gorm...${NC}"
	  cd ../gorm/
	  make -j8
	  sudo -E make install

	  showPrompt

	  echo -e "\n\n"
	  echo -e "${GREEN}Building GWorkspace...${NC}"
	  cd ../gworkspace/
	  ./configure
	  make -j8
	  sudo -E make install

	  showPrompt

	  echo -e "\n\n"
	  echo -e "${GREEN}Building SystemPreferences...${NC}"
	  cd ../SystemPreferences-1.2.0/
	  make -j8
	  sudo -E make install

	fi

	echo -e "\n\n"
	echo -e "${GREEN}Install is done. Open a new terminal to start using.${NC}"

[[edit][8]]

<>

### 14.04 &amp; 15.04

	#!/bin/bash

	sudo dpkg --add-architecture i386
	sudo apt-get update
	sudo apt-get -y install build-essential git subversion ninja cmake libffi-dev libxml2-dev \
	libgnutls-dev libicu-dev libblocksruntime-dev libkqueue-dev libpthread-workqueue-dev autoconf libtool \
	libjpeg-dev libtiff-dev libffi-dev libcairo-dev libx11-dev:i386 libxt-dev libXft-dev

	sudo apt-get -y install python-dev libncurses5-dev doxygen swig libedit-dev

	cd ~
	git clone git://github.com/nickhutchinson/libdispatch.git
	svn co http://svn.gna.org/svn/gnustep/modules/core
	git clone https://github.com/gnustep/libobjc2

	# OBTAIN, COMPILE, INSTALL THE LATEST LLVM/clang. (Doing apt-get install clang instead may or may not work.)
	svn co http://llvm.org/svn/llvm-project/llvm/trunk llvm
	cd llvm/tools
	svn co http://llvm.org/svn/llvm-project/cfe/trunk clang
	svn co http://llvm.org/svn/llvm-project/lldb/trunk lldb
	cd ~/llvm
	rm -rf build
	mkdir build
	cd build
	cmake -D CMAKE_BUILD_TYPE:STRING=Release ..    # If you don't choose Release, it defaults to Debug which takes lots more space
	make -j8   # 8=your number of build CPUs
	echo "export PATH=\$PATH:~/llvm/build/bin" &gt;&gt; ~/.bashrc
	echo "export CC=clang"  &gt;&gt; ~/.bashrc
	echo "export CXX=clang++" &gt;&gt; ~/.bashrc
	export PATH=$PATH:~/llvm/build/bin
	. ~/.bashrc

	export CC=clang
	export CXX=clang++

	clang -v
	clang++ -v

	cd ~/libobjc2
	rm -rf build
	mkdir build
	cd build
	cmake ..
	make -j8
	sudo -E make install

	cd ~/core/make
	./configure --enable-debug-by-default --with-layout=gnustep --enable-objc-nonfragile-abi
	make &amp;&amp; sudo -E make install
	echo ". /usr/GNUstep/System/Library/Makefiles/GNUstep.sh" &gt;&gt; ~/.bashrc

	. /usr/GNUstep/System/Library/Makefiles/GNUstep.sh

	sudo /sbin/ldconfig

	cd ~/core/base/
	./configure
	make -j8
	sudo -E make install

	cd ~/libdispatch
	rm -rf libdispatch-build
	mkdir libdispatch-build &amp;&amp; cd libdispatch-build
	../configure
	make
	sudo make install
	sudo ldconfig

	cd ~/core/gui
	./configure
	make -j8
	sudo -E make install

	cd ~/core/back
	./configure
	make -j8
	sudo -E make install

	echo "Install is done. Open a new terminal or type source ~/.bashrc"

<br />

[[edit][9]]

<>

### 12.04

This uses the same as the 14.04 &amp; 15.04 except there are some additional requirements.

On Ubuntu 12.04, the default installed version of CMake is 2.8.7 but you need 2.8.8 or later to compile LLVM. And the default installed version of GCC and G++ is 4.6 but you need 4.8 or later to compile LLVM.

For CMake, the solution is to download and compile CMake yourself. Use the existing CMake 2.8.7 and then replace it:

1. Download the latest CMake version from the CMake web site (<http://www.cmake.org/cmake/resources/software.html>), and uncompress it in a folder.
2. Create a \_build directory in the CMake sources folder.
3. From the \_build directory, run the following commands to build and install CMake from sources:

	cmake .. -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=/usr
	make
	cpack -G DEB
	sudo apt-get remove cmake cmake-data
	sudo dpkg -i cmake*.deb

To get GCC and G++ 4.8, do the following:

	sudo add-apt-repository ppa:ubuntu-toolchain-r/test
	sudo apt-get update
	sudo apt-get install gcc-4.8 g++-4.8
	sudo update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-4.8 50
	sudo update-alternatives --install /usr/bin/g++ g++ /usr/bin/g++-4.8 50

Now run the 14.04 &amp; 15.04 script.

<br />

[[edit][10]]

<>

## Test Code

The following is some Objective-C source code from the internet. It demonstrates blocks, Grand Central Dispatch, and the use of GNUStep GUI.

	cat &gt; blocktest.m &lt;&lt; EOF
	#include &lt;stdio.h&gt;

	int main() {
	    void (^hello)(void) = ^(void) {
	        printf("Hello, block!\n");
	    };
	    hello();
	    return 0;
	}
	EOF

	cat &gt; helloGCD_objc.m &lt;&lt; EOF

	#include &lt;dispatch/dispatch.h&gt;
	#import &lt;stdio.h&gt;
	#import "Fraction.h"

	int main( int argc, const char *argv[] ) {
	   dispatch_queue_t queue = dispatch_queue_create(NULL, NULL);
	   Fraction *frac = [[Fraction alloc] init];

	   [frac setNumerator: 1];
	   [frac setDenominator: 3];

	   // print it
	   dispatch_sync(queue, ^{
	     printf( "The fraction is: " );
	     [frac print];
	     printf( "\n" );
	   });
	   dispatch_release(queue);

	   return 0;
	}

	EOF

	cat &gt; Fraction.h &lt;&lt; EOF

	#import &lt;Foundation/NSObject.h&gt;

	@interface Fraction: NSObject {
	   int numerator;
	   int denominator;
	}

	-(void) print;
	-(void) setNumerator: (int) n;
	-(void) setDenominator: (int) d;
	-(int) numerator;
	-(int) denominator;
	@end

	EOF

	cat &gt; Fraction.m &lt;&lt; EOF
	#import "Fraction.h"
	#import &lt;stdio.h&gt;

	@implementation Fraction
	-(void) print {
	   printf( "%i/%i", numerator, denominator );
	}

	-(void) setNumerator: (int) n {
	   numerator = n;
	}

	-(void) setDenominator: (int) d {
	   denominator = d;
	}

	-(int) denominator {
	   return denominator;
	}

	-(int) numerator {
	   return numerator;
	}
	@end

	EOF

	cat &gt; guitest.m &lt;&lt; EOF
	#import &lt;AppKit/AppKit.h&gt;

	int main()
	{
	  NSApplication *app;  // Without these 2 lines, seg fault may occur
	  app = [NSApplication sharedApplication];

	  NSAlert * alert = [[NSAlert alloc] init];
	  [alert setMessageText:@"Hello alert"];
	  [alert addButtonWithTitle:@"All done"];
	  int result = [alert runModal];
	  if (result == NSAlertFirstButtonReturn) {
	    NSLog(@"First button pressed");
	  }
	}
	EOF

	# ======================================================================
	# COMPILE USING THE FOLLOWING COMMAND LINES, OR CREATE A MAKEFILE
	# ======================================================================

	# Using COMMAND LINE

	clang `gnustep-config --objc-flags` `gnustep-config --objc-libs` -fobjc-runtime=gnustep -fblocks -fobjc-arc -lobjc  blocktest.m

	clang `gnustep-config --objc-flags` `gnustep-config --objc-libs` -fobjc-runtime=gnustep -fblocks -lobjc -ldispatch -lgnustep-base  Fraction.m helloGCD_objc.m

	clang `gnustep-config --objc-flags` `gnustep-config --objc-libs`  -fobjc-runtime=gnustep -fblocks -lobjc -fobjc-arc -ldispatch -lgnustep-base -lgnustep-gui  guitest.m

	# Using MAKEFILE

	cat &gt; GNUmakefile &lt;&lt; EOF
	include \$(GNUSTEP_MAKEFILES)/common.make

	APP_NAME = GUITest
	GUITest_OBJC_FILES = guitest.m

	include \$(GNUSTEP_MAKEFILES)/application.make
	EOF

	make
	openapp ./GUITest.app

General Note: When compiling your own code, it is generally good to tell clang both the family and version of the runtime: -fobjc-runtime=gnustep-1.8.1 (The current version number can be had by looking at the latest ANNOUNCE filename in <https://github.com/gnustep/libobjc2> (e.g., ANNOUNCE.1.8.1))

 Retrieved from "[http://wiki.gnustep.org/index.php/GNUstep\_under\_Ubuntu\_Linux][11]"

##### Views

* [Article][12]
* [Discussion][13]
* [Edit][14]
* [History][15]

##### Personal tools

* [Create an account or log in][16]

[][17]

##### users

* [Applications][18]
* [Guides][19]
* [FAQ][20]
* [Get Help][21]
* [Report Bugs][22]
* [Donations][23]
* [Screenshots][24]

##### developers

* [Guides][25]
* [FAQ][26]
* [Base API (Foundation)][27]
* [GUI API (AppKit)][28]
* [Frameworks][29]

##### Navigation

* [Main Page][30]
* [Community portal][31]
* [Current events][32]
* [Recent changes][33]
* [Random page][34]
* [Help][35]

##### Search

##### Toolbox

* [What links here][36]
* [Related changes][37]
* [Upload file][38]
* [Special pages][39]
* [Printable version][40]

[![MediaWiki][41]][42]

* This page was last modified 02:49, 20 October 2016.
* This page has been accessed 54,139 times.
* Content is available under [GNU General Public License][43].
* [About GNUstepWiki][44]
* [Disclaimers][45]

  [1]: #Compiling_Everything_from_Scratch
  [2]: #16.04_.26_16.10
  [3]: #14.04_.26_15.04
  [4]: #12.04
  [5]: #Test_Code
  [6]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=edit&section=1 "GNUstep under Ubuntu Linux"
  [7]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=edit&section=2 "GNUstep under Ubuntu Linux"
  [8]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=edit&section=3 "GNUstep under Ubuntu Linux"
  [9]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=edit&section=4 "GNUstep under Ubuntu Linux"
  [10]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=edit&section=5 "GNUstep under Ubuntu Linux"
  [11]: http://wiki.gnustep.org/index.php/GNUstep_under_Ubuntu_Linux
  [12]: /index.php/GNUstep_under_Ubuntu_Linux
  [13]: /index.php?title=Talk:GNUstep_under_Ubuntu_Linux&action=edit
  [14]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=edit
  [15]: /index.php?title=GNUstep_under_Ubuntu_Linux&action=history
  [16]: /index.php?title=Special:Userlogin&returnto=GNUstep_under_Ubuntu_Linux
  [17]: /index.php/Main_Page "Main Page"
  [18]: /index.php/Category:Applications
  [19]: /index.php/User_Guides
  [20]: /index.php/User_FAQ
  [21]: /index.php/Get_Help
  [22]: /index.php/Report_Bugs
  [23]: /index.php/GNUstepWiki:Site_support
  [24]: /index.php/Screenshots
  [25]: /index.php/Developer_Guides
  [26]: /index.php/Developer_FAQ
  [27]: /index.php/Foundation
  [28]: /index.php/AppKit
  [29]: /index.php/Category:Frameworks
  [30]: /index.php/Main_Page
  [31]: /index.php/GNUstepWiki:Community_Portal
  [32]: /index.php/Current_events
  [33]: /index.php/Special:Recentchanges
  [34]: /index.php/Special:Random
  [35]: /index.php/Help:Contents
  [36]: /index.php/Special:Whatlinkshere/GNUstep_under_Ubuntu_Linux
  [37]: /index.php/Special:Recentchangeslinked/GNUstep_under_Ubuntu_Linux
  [38]: /index.php/Special:Upload
  [39]: /index.php/Special:Specialpages
  [40]: /index.php?title=GNUstep_under_Ubuntu_Linux&printable=yes&printable=yes
  [41]: /skins/common/images/poweredby_mediawiki_88x31.png
  [42]: http://www.mediawiki.org/
  [43]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [44]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [45]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"