<>

# Gorm FAQ

### From GNUstepWiki	{#siteSub}

<table>
<tr>
<td>
## Contents
* [1 Should I modify the data.classes of file in the .gorm package?][1]
* [2 Why does my application crash when I add additional attributes for encoding in encodeWithCoder: or initWithCoder: in my custom class?][2]
* [3 Why should I be careful when using Gorm with GSAppKitUserBundles?][3]
* [4 How can I avoid loading GSAppKitUserBundles in Gorm?][4]
* [5 How can I change the font for a widget?][5]
* [6 Does Gorm use "fake" objects in the Gorm gui when building the model?][6]
* [7 Does Gorm itself encode/decode the objects in the .gorm file?][7]
* [8 Who should release the top level objects?][8]
* [9 Why doesn't Gorm/GNUstep read nib files?][9]
</td>
</tr>
</table>

[[edit][10]]

<>

### Should I modify the data.classes of file in the .gorm package?

My advice is never to do this, ever. Some have said that "they're plain text and I should be able to change them". My response to this rather weak rationale is that if they are modified I cannot and will not guarantee that Gorm will be able to read them or will function correctly if it does.

[[edit][11]]

<>

### Why does my application crash when I add additional attributes for encoding in encodeWithCoder: or initWithCoder: in my custom class?

If you've selected the custom class by clicking on an existing object and then selecting a subclass in the Custom Class Inspector in Gorm's inspector panel, then when the .gorm file is saved, Gorm must use what is called a template to take the place of the class so that when the .gorm is unarchived in the running application, the template can become the custom subclass you specified. Gorm has no way of knowing about the additional attributes of your subclass, so when it's archived the template depends on the encodeWithCoder: of the existing class. Also, when AppKit loads the .gorm file, the initWithCoder: on the subclass is called to allow the user to do any actions, except for additional encoding, which need to be done at that time. This is particularly true when non-keyed coding is used, since, with keyed coding, it's possible to skip keys that are not present. The application may not crash if keyed coding is used, but Gorm would still not know about the additional attributes and would not be able to persist them anyway. Please see information in previous chapters regarding palettes, if you would like to be able to add your classes to Gorm so that they don't need to be replaced by templates, or proxy objects.

[[edit][12]]

<>

### Why should I be careful when using Gorm with GSAppKitUserBundles?

Some bundles may use poseAs: to affect change in the existing behavior of some GNUstep classes. The poseAs: method causes an issue which may cause Gorm to incorrectly encode the class name for the object which was replaced. This makes the resulting .gorm file unusable when another user who is not using the same bundle attempts to load it.

[[edit][13]]

<>

### How can I avoid loading GSAppKitUserBundles in Gorm?

You need to write to Gorm's defaults like this:

	defaults write Gorm GSAppKitUserBundles '()'

Doing this overrides the settings in NSGlobalDomain for Gorm and forces Gorm not to load any user bundles at all. To eliminate this simply do:

	defaults delete Gorm GSAppKitUserBundles

[[edit][14]]

<>

### How can I change the font for a widget?

This is a simple two step process. Select the window the widget is in and then select the widget itself, then bring up the font panel by hitting Command-t (or by choosing the menu item). By doing this you're making the window the main window and by selecting the widget, you're telling the editor for that object to accept changes. Then you can select the font in the panel and hit "Set". Remember to set the pop up button to "As Selected Above". For some objects, the font panel isn't effective because those objects can't have a font directly set.

[[edit][15]]

<>

### Does Gorm use "fake" objects in the Gorm gui when building the model?

No, it doesn't. While it's true that Gorm proxies some of the custom objects for the user in various ways described above in #2, Gorm uses actual instances of most objects to do it's work. Gorm utilizes special classes called Editors. These editors wrap the actual instance and make it possible for Gorm to modify aspects of those objects. For instance, a button in a Gorm model is selected (i.e. knobs appear around it) when the user selects it. The knobs and the ability to change things about the selected button are enabled by the button editor. Normally, the button would simply have been pressed.

[[edit][16]]

<>

### Does Gorm itself encode/decode the objects in the .gorm file?

Yes and no. Gorm relies heavily on the use of NSArchiver and NSUnarchiver. These two classes are absolutely vital to Gorm's operation. They facilitate the use of proxy objects described above which is essential to Gorm's function. All of the code for actually saving the objects in the model resides in AppKit. The method initWithCoder: and encodeWithCoder: (the NSCoding protocol) are implemented on every object in both gui and base which are capable of being encoded. Gorm utilizes these methods and the above mentioned techniques to do it's job.

[[edit][17]]

<>

### Who should release the top level objects?

After the .gorm file is finished loading, all of the top level objects should have a retain count of one. It is the responsibility of the File's Owner/NSOwner to release these objects. The NSOwner, as previously described, is usually the controller class which loaded the file. In the case of NSWindowController, the window controller should release all of the top level objects for you.

[[edit][18]]

<>

### Why doesn't Gorm/GNUstep read nib files?

Until recently, the format of the NeXT nibs has been simply a serialized binary. Now that Apple's nibs are XML based using the NSKeyedArchiver and NSKeyedUnarchiver, it makes it easier to reverse engineer the format and allow GNUstep and Gorm to read the nib files. The older, non-xml, serialized format really isn't a "format" as much as it is a byte stream. Part of the issue is that the data encoded in the nibs is strongly tied to the implementation of each control. Additionally, each control has serveral versions and it's possible for different versions to be combined. So, in order to reverse engineer this we would need to understand the internal implementation of each and every control and know in what sequence each of it's attributes is stored as well as implement every version of each control and make whatever corrections need to be made when loading an older version into a newer implementation, etc ,etc. Add to this that Apple/NeXT would likely change the encoding of some classes between each version and may even change the internal implementation, which would require a full investigation into all of the classes to ensure that our encoding matches for every version of every class. With the keyed nibs, this is no longer an issue. Forward and backward compatibility is possible with them and it eases the burden each time there is a new release. The Gorm maintainer and others are currently, as of this writing, working on implementation of modern XML nib support in GNUstep.

 Retrieved from "[http://wiki.gnustep.org/index.php/Gorm\_FAQ][19]"

[Categories][20]: [FAQ][21]

##### Views

* [Article][22]
* [Discussion][23]
* [Edit][24]
* [History][25]

##### Personal tools

* [Create an account or log in][26]

[][27]

##### users

* [Applications][28]
* [Guides][29]
* [FAQ][30]
* [Get Help][31]
* [Report Bugs][32]
* [Donations][33]
* [Screenshots][34]

##### developers

* [Guides][35]
* [FAQ][36]
* [Base API (Foundation)][37]
* [GUI API (AppKit)][38]
* [Frameworks][39]

##### Navigation

* [Main Page][40]
* [Community portal][41]
* [Current events][42]
* [Recent changes][43]
* [Random page][44]
* [Help][45]

##### Search

##### Toolbox

* [What links here][46]
* [Related changes][47]
* [Upload file][48]
* [Special pages][49]
* [Printable version][50]

[![MediaWiki][51]][52]

* This page was last modified 16:58, 8 September 2006.
* This page has been accessed 38,540 times.
* Content is available under [GNU General Public License][53].
* [About GNUstepWiki][54]
* [Disclaimers][55]

  [1]: #Should_I_modify_the_data.classes_of_file_in_the_.gorm_package.3F
  [2]: #Why_does_my_application_crash_when_I_add_additional_attributes_for_encoding_in_encodeWithCoder:_or_initWithCoder:_in_my_custom_class.3F
  [3]: #Why_should_I_be_careful_when_using_Gorm_with_GSAppKitUserBundles.3F
  [4]: #How_can_I_avoid_loading_GSAppKitUserBundles_in_Gorm.3F
  [5]: #How_can_I_change_the_font_for_a_widget.3F
  [6]: #Does_Gorm_use_.22fake.22_objects_in_the_Gorm_gui_when_building_the_model.3F
  [7]: #Does_Gorm_itself_encode.2Fdecode_the_objects_in_the_.gorm_file.3F
  [8]: #Who_should_release_the_top_level_objects.3F
  [9]: #Why_doesn.27t_Gorm.2FGNUstep_read_nib_files.3F
  [10]: /index.php?title=Gorm_FAQ&action=edit&section=1 "Gorm FAQ"
  [11]: /index.php?title=Gorm_FAQ&action=edit&section=2 "Gorm FAQ"
  [12]: /index.php?title=Gorm_FAQ&action=edit&section=3 "Gorm FAQ"
  [13]: /index.php?title=Gorm_FAQ&action=edit&section=4 "Gorm FAQ"
  [14]: /index.php?title=Gorm_FAQ&action=edit&section=5 "Gorm FAQ"
  [15]: /index.php?title=Gorm_FAQ&action=edit&section=6 "Gorm FAQ"
  [16]: /index.php?title=Gorm_FAQ&action=edit&section=7 "Gorm FAQ"
  [17]: /index.php?title=Gorm_FAQ&action=edit&section=8 "Gorm FAQ"
  [18]: /index.php?title=Gorm_FAQ&action=edit&section=9 "Gorm FAQ"
  [19]: http://wiki.gnustep.org/index.php/Gorm_FAQ
  [20]: /index.php?title=Special:Categories&article=Gorm_FAQ "Special:Categories"
  [21]: /index.php/Category:FAQ "Category:FAQ"
  [22]: /index.php/Gorm_FAQ
  [23]: /index.php?title=Talk:Gorm_FAQ&action=edit
  [24]: /index.php?title=Gorm_FAQ&action=edit
  [25]: /index.php?title=Gorm_FAQ&action=history
  [26]: /index.php?title=Special:Userlogin&returnto=Gorm_FAQ
  [27]: /index.php/Main_Page "Main Page"
  [28]: /index.php/Category:Applications
  [29]: /index.php/User_Guides
  [30]: /index.php/User_FAQ
  [31]: /index.php/Get_Help
  [32]: /index.php/Report_Bugs
  [33]: /index.php/GNUstepWiki:Site_support
  [34]: /index.php/Screenshots
  [35]: /index.php/Developer_Guides
  [36]: /index.php/Developer_FAQ
  [37]: /index.php/Foundation
  [38]: /index.php/AppKit
  [39]: /index.php/Category:Frameworks
  [40]: /index.php/Main_Page
  [41]: /index.php/GNUstepWiki:Community_Portal
  [42]: /index.php/Current_events
  [43]: /index.php/Special:Recentchanges
  [44]: /index.php/Special:Random
  [45]: /index.php/Help:Contents
  [46]: /index.php/Special:Whatlinkshere/Gorm_FAQ
  [47]: /index.php/Special:Recentchangeslinked/Gorm_FAQ
  [48]: /index.php/Special:Upload
  [49]: /index.php/Special:Specialpages
  [50]: /index.php?title=Gorm_FAQ&printable=yes&printable=yes
  [51]: /skins/common/images/poweredby_mediawiki_88x31.png
  [52]: http://www.mediawiki.org/
  [53]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [54]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [55]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"