<>

# Identifying the target platform

### From GNUstepWiki	{#siteSub}

A common problem is identifying the target platform at compile-time so that specific code can be used, perhaps to work around a quirk, or to access a non-standard feature of the target platform.

[[edit][1]]

<>

## Standard compiler platform macros

The following table is a partial extract of [[Pre-defined C/C++ Compiler Macros][2]], part of a useful resource to compiler macro definitions.

Please update the table carefully with your platform or corrections:

<table>
<caption>Platform macros </caption>
<tr>
<th> Platform </th>
<th> Defined macro </th>
<th> Other notes </th>
</tr>
<tr>
<th> Darwin </th>
<td> DARWIN </td>
<td> Darwin is not necessarily OS X, see below </td>
</tr>
<tr>
<th> FreeBSD </th>
<td> \_\_FreeBSD\_\_ </td>
<td> Consider using the BSD macro </td>
</tr>
<tr>
<th> Linux </th>
<td> linux or \_\_linux </td>
<td> I also found LINUX </td>
</tr>
<tr>
<th> MacOS X </th>
<td> \_\_MACOSX\_\_ or \_\_APPLE\_\_ </td>
<td></td>
</tr>
<tr>
<th> NetBSD </th>
<td> \_\_NetBSD\_\_ </td>
<td> Consider using the BSD macro </td>
</tr>
<tr>
<th> OpenBSD </th>
<td> \_\_OpenBSD\_\_ </td>
<td> Consider using the BSD macro </td>
</tr>
<tr>
<th> Solaris </th>
<td> sun or \_\_sun </td>
<td> SunOS versions &lt; 5 will not have \_\_SVR4 or \_\_svr4\_\_ defined </td>
</tr>
<tr>
<th> Windows </th>
<td> \_WIN32 or \_\_WIN32\_\_ </td>
<td></td>
</tr>
</table>

<br />
 You can use #if wrappers like:

	#if defined (__FreeBSD__)
	...
	#elif defined (__linux) || defined (linux)
	...
	#else
	...
	#endif

[[edit][3]]

<>

## Using GNUStep-Make's support

Chris Vetter shared a tip on the use of your GNUmakefile.preamble with the following line:

	ADDITIONAL_CPPFLAGS += -D$(GNUSTEP_HOST_OS)

and then the #if wrappers will look like:

	#if defined( freebsd )
	...
	#elif defined( netbsdelf )
	...
	#else
	...
	#endif

To be on the safe side, you may then want to mix the compiler defaults and GNUstep's definitions. It's also good style to add an error or at least a warning in case a particular platform is not (yet) supported.

	#if defined( freebsd ) || defined( __FreeBSD__ )
	...
	#elif defined( darwin ) || defined( DARWIN )
	...
	#else
	# error Do not know how to handle this feature on your platform.
	#endif

Always keep in mind that not everyone is using your preferred platform and that implementations may vary. This is especially true with respect to the implementation and usage of _/proc_ on Linux as compared to other systems.

It's much better generating an error (as mentioned above) than just assuming your code will work on a different platform. The former will most likely get someone involved in your pet project and have them send in patches for their particular system. The latter will probably just annoy people, especially if your code screws up (on) their system due to differences...

 Retrieved from "[http://wiki.gnustep.org/index.php/Identifying\_the\_target\_platform][4]"

[Categories][5]: [Development][6]

##### Views

* [Article][7]
* [Discussion][8]
* [Edit][9]
* [History][10]

##### Personal tools

* [Create an account or log in][11]

[][12]

##### users

* [Applications][13]
* [Guides][14]
* [FAQ][15]
* [Get Help][16]
* [Report Bugs][17]
* [Donations][18]
* [Screenshots][19]

##### developers

* [Guides][20]
* [FAQ][21]
* [Base API (Foundation)][22]
* [GUI API (AppKit)][23]
* [Frameworks][24]

##### Navigation

* [Main Page][25]
* [Community portal][26]
* [Current events][27]
* [Recent changes][28]
* [Random page][29]
* [Help][30]

##### Search

##### Toolbox

* [What links here][31]
* [Related changes][32]
* [Upload file][33]
* [Special pages][34]
* [Printable version][35]

[![MediaWiki][36]][37]

* This page was last modified 10:18, 16 January 2007.
* This page has been accessed 21,206 times.
* Content is available under [GNU General Public License][38].
* [About GNUstepWiki][39]
* [Disclaimers][40]

  [1]: /index.php?title=Identifying_the_target_platform&action=edit&section=1 "Identifying the target platform"
  [2]: http://predef.sourceforge.net/preos.html "http://predef.sourceforge.net/preos.html"
  [3]: /index.php?title=Identifying_the_target_platform&action=edit&section=2 "Identifying the target platform"
  [4]: http://wiki.gnustep.org/index.php/Identifying_the_target_platform
  [5]: /index.php?title=Special:Categories&article=Identifying_the_target_platform "Special:Categories"
  [6]: /index.php/Category:Development "Category:Development"
  [7]: /index.php/Identifying_the_target_platform
  [8]: /index.php?title=Talk:Identifying_the_target_platform&action=edit
  [9]: /index.php?title=Identifying_the_target_platform&action=edit
  [10]: /index.php?title=Identifying_the_target_platform&action=history
  [11]: /index.php?title=Special:Userlogin&returnto=Identifying_the_target_platform
  [12]: /index.php/Main_Page "Main Page"
  [13]: /index.php/Category:Applications
  [14]: /index.php/User_Guides
  [15]: /index.php/User_FAQ
  [16]: /index.php/Get_Help
  [17]: /index.php/Report_Bugs
  [18]: /index.php/GNUstepWiki:Site_support
  [19]: /index.php/Screenshots
  [20]: /index.php/Developer_Guides
  [21]: /index.php/Developer_FAQ
  [22]: /index.php/Foundation
  [23]: /index.php/AppKit
  [24]: /index.php/Category:Frameworks
  [25]: /index.php/Main_Page
  [26]: /index.php/GNUstepWiki:Community_Portal
  [27]: /index.php/Current_events
  [28]: /index.php/Special:Recentchanges
  [29]: /index.php/Special:Random
  [30]: /index.php/Help:Contents
  [31]: /index.php/Special:Whatlinkshere/Identifying_the_target_platform
  [32]: /index.php/Special:Recentchangeslinked/Identifying_the_target_platform
  [33]: /index.php/Special:Upload
  [34]: /index.php/Special:Specialpages
  [35]: /index.php?title=Identifying_the_target_platform&printable=yes&printable=yes
  [36]: /skins/common/images/poweredby_mediawiki_88x31.png
  [37]: http://www.mediawiki.org/
  [38]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [39]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [40]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"