<>

# Implementing the class

### From GNUstepWiki	{#siteSub}

<table>
<tr>
<td>
## Contents
* [1 Start small][1]
* [2 Pick small groups of methods][2]
* [3 Document and write test cases as you go][3]
* [4 Let other people know what you've done][4]
* [5 Avoid using new language features][5]
* [6 Avoid system specific code][6]
</td>
</tr>
</table>

[[edit][7]]

<>

### Start small

The most important thing to keep in mind when implementing new functionality is to do it in small sections ... break the task up. You should release little and often so that others can review changes and offer helpful advice early.

[[edit][8]]

<>

### Pick small groups of methods

When implementing a class, you need to start by implementing an initial version of the designated initialiser and the -dealloc method so that you can create and destroy instances of the class. You may want to revise those methods as you implement more of the class, but you can start by implementing very simple versions.

Once you can create and destroy instances, it makes sense to implement core methods like -hash, -isEqual:, and -description.

Next you can implement things like -copyWithZone: and -mutableCopyWithZone: (if the class supports copying and perhaps mutable copying), and the -initWithCoder: and -encodeWithCoder: methods if the class supports coding.

Then pick small groups of methods with related functionality to implement, so that you can document and test those methods together.

[[edit][9]]

<>

### Document and write test cases as you go

Ideally, you should do this **before** implementing:

You can write one or more test cases for each method, and if you have access to an OSX system, you can run those test cases there to check that the OSX behaviour of the method actually is what you expect. If you don't have an OSX system, you can still ask other people to run your testcases for you, and email the results back to you. It is extremely useful to run test cases before designing how your code will work ... since that can inform your design and avoid wasting time writing code which doesn't match the OSX implementation.

You can add a comment to the header file, before each method you are about to implement. The comment would describe what you think the method should be doing. If you've implemented test cases and tried them on OSX, you will by now **know** what the method is supposed to do.

Then, when you actually implement the method for GNUstep, you can run the test case you wrote, and be sure that your code does just what it should.

<br />

[[edit][10]]

<>

### Let other people know what you've done

If you make each batch of changes available immediately, other people might try them out on other operating systems or different processor architectures. If you have provided test cases in the test suite, people will be able to see if the code behaves the same way on their systems as on yours. Portability issues can be addressed quickly, and problems can be spotted and fixed quickly.

<br />

[[edit][11]]

<>

### Avoid using new language features

We use #if...#else...#endif to deal with Objective-C language variations ... most people don't use the more recent additions Apple have made to the Objective-C language, and you must assume that the source code will be built by a compiler which doesn't support those features, so you need to have alternatives which will work with other compiler versions.

<br />

[[edit][12]]

<>

### Avoid system specific code

We always write for portability ... GNUstep has to run on many operating systems and different types of CPU. In particular you need to ensure that any code which uses UNIX system/library functions also has a variant which works under ms-windows.

 Retrieved from "[http://wiki.gnustep.org/index.php/Implementing\_the\_class][13]"

##### Views

* [Article][14]
* [Discussion][15]
* [Edit][16]
* [History][17]

##### Personal tools

* [Create an account or log in][18]

[][19]

##### users

* [Applications][20]
* [Guides][21]
* [FAQ][22]
* [Get Help][23]
* [Report Bugs][24]
* [Donations][25]
* [Screenshots][26]

##### developers

* [Guides][27]
* [FAQ][28]
* [Base API (Foundation)][29]
* [GUI API (AppKit)][30]
* [Frameworks][31]

##### Navigation

* [Main Page][32]
* [Community portal][33]
* [Current events][34]
* [Recent changes][35]
* [Random page][36]
* [Help][37]

##### Search

##### Toolbox

* [What links here][38]
* [Related changes][39]
* [Upload file][40]
* [Special pages][41]
* [Printable version][42]

[![MediaWiki][43]][44]

* This page was last modified 08:22, 13 February 2012.
* This page has been accessed 6,067 times.
* Content is available under [GNU General Public License][45].
* [About GNUstepWiki][46]
* [Disclaimers][47]

  [1]: #Start_small
  [2]: #Pick_small_groups_of_methods
  [3]: #Document_and_write_test_cases_as_you_go
  [4]: #Let_other_people_know_what_you.27ve_done
  [5]: #Avoid_using_new_language_features
  [6]: #Avoid_system_specific_code
  [7]: /index.php?title=Implementing_the_class&action=edit&section=1 "Implementing the class"
  [8]: /index.php?title=Implementing_the_class&action=edit&section=2 "Implementing the class"
  [9]: /index.php?title=Implementing_the_class&action=edit&section=3 "Implementing the class"
  [10]: /index.php?title=Implementing_the_class&action=edit&section=4 "Implementing the class"
  [11]: /index.php?title=Implementing_the_class&action=edit&section=5 "Implementing the class"
  [12]: /index.php?title=Implementing_the_class&action=edit&section=6 "Implementing the class"
  [13]: http://wiki.gnustep.org/index.php/Implementing_the_class
  [14]: /index.php/Implementing_the_class
  [15]: /index.php?title=Talk:Implementing_the_class&action=edit
  [16]: /index.php?title=Implementing_the_class&action=edit
  [17]: /index.php?title=Implementing_the_class&action=history
  [18]: /index.php?title=Special:Userlogin&returnto=Implementing_the_class
  [19]: /index.php/Main_Page "Main Page"
  [20]: /index.php/Category:Applications
  [21]: /index.php/User_Guides
  [22]: /index.php/User_FAQ
  [23]: /index.php/Get_Help
  [24]: /index.php/Report_Bugs
  [25]: /index.php/GNUstepWiki:Site_support
  [26]: /index.php/Screenshots
  [27]: /index.php/Developer_Guides
  [28]: /index.php/Developer_FAQ
  [29]: /index.php/Foundation
  [30]: /index.php/AppKit
  [31]: /index.php/Category:Frameworks
  [32]: /index.php/Main_Page
  [33]: /index.php/GNUstepWiki:Community_Portal
  [34]: /index.php/Current_events
  [35]: /index.php/Special:Recentchanges
  [36]: /index.php/Special:Random
  [37]: /index.php/Help:Contents
  [38]: /index.php/Special:Whatlinkshere/Implementing_the_class
  [39]: /index.php/Special:Recentchangeslinked/Implementing_the_class
  [40]: /index.php/Special:Upload
  [41]: /index.php/Special:Specialpages
  [42]: /index.php?title=Implementing_the_class&printable=yes&printable=yes
  [43]: /skins/common/images/poweredby_mediawiki_88x31.png
  [44]: http://www.mediawiki.org/
  [45]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [46]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [47]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"