<>

# Key Value Observing

### From GNUstepWiki	{#siteSub}

Stefan Urbanek wrote:

Is anyone working on the Key-value observing?

**I've just been updating KVC and thinking about KVO**

<http://developer.apple.com/documentation/Cocoa/Conceptual/KeyValueObserving/index.html>

In the documentation one can read:

"Automatic key-value observing is implemented using a technique called isa-swizzling.

The isa pointer, as the name suggests, points to the object's class which maintains a dispatch table. This dispatch table essentially contains pointers to the methods the class implements, among other data.

When an observer is registered for an attribute of an object the isa pointer of the observed object is modified, pointing to an intermediate class rather than at the true class. As a result the value of the isa pointer does not necessarily reflect the actual class of the instance. "

Is it difficult to implement it in GNUstep?

**No more than in MacOSX.**

If not, what is needed?

If noone is working on it and if someone skilled knows how to implement it or has some hints, please write notes for others here:

**OK, see below ...**

1\. You need to write a class to manage observing of objects (call it GSKVN for instance). This class neeeds to have instance variables to hold -

a. a class pointer

b. information about all observers of the object and what sort of notifications they want to get.

	@interface GSObservedProxy
	{
	    id       target;
	    Class    targetClass;
	    NSArray *observerInfo;
	}
	@end

	@interface GSObserverInfo
	{
	    id       observer;
	    NSArray *keys;     /* Observed keys */
	}
	@end

<br />
 2. You need to create a lock protected NSMapTable which will contain pointers to observed objects as keys, and instances of the KVN class as values.

When you start observing an object, you create an instance of the GSKVN class using NSAllocateObject(), and store it in the map table.

Within the GSKVN instance, you store the class of the object being observed. You change the isa variable of the object being observed to be a pointer to the GSKVN class.

_Pseudo-code:_

	@implementation GSObservedProxy
	+ (GSObservedProxy *)proxyForObject:(id)anObject
	{
	    GSObservedProxy *proxy;

	    /* get a proxy if exists. FIXME: this should be thread safe */
	    proxy = [observedProxies objectForKey:anObject];

	    if(!proxy)
	    {
	        proxy = [[GSObservedProxy alloc] initWithTarget:anObject];
	        anObject-&gt;isa = [GSObservedProxy class];

	        [observedProxies addObject:proxy forKey:anObject];
	    }
	}
	- initWithTarget:(id)anObject
	{
	    target = anObject;
	    targetClass = [anObject class];
	    return self;
	}
	- addObserver:(id)anObserver
	   forKeyPath:(NSString *)keyPath
	      options:(unsigned int)options
	      context:(void *)context
	{
	    /* FIXME: add implementation here */
	}
	- (void)removeObserver:(NSObject *)anObserver forKeyPath:(NSString *)keyPath
	{
	     remove observer from observers
	     if([observers count] == 0)
	     {
	         /* last observer was removed, we should put the target to its original state */
	         target-&gt;isa = originalClass;
	         [observedProxies removeObject:self];

	         /* FIXME: somehow release and dealloc self */
	     }
	}
	@end

	@implementation NSObject(GSKeyValueObserving)
	- addObserver:(id)anObserver
	   forKeyPath:(NSString *)keyPath
	      options:(unsigned int)options
	      context:(void *)context
	{
	    GSObservedProxy *proxy;

	    /* get proxy for self */
	    proxy = [GSObservedProxy proxyForObject:self];
	    [proxy addObserver:anObserver forKeyPath:keyPath options:options context:context];
	}
	@end

Now, when a message is sent to the original object, it actually gets sent to the GSKVN class. This class doesn't implement the method, but it does implement things like -respondsToSelector:, -methodForSelector: -methodSignatureForSelector: and forwardInvocation:

So, the implementations of these methods in the GSKVN class will -

a. use the map table to look up the GSKVN instance corresponding to the object being observed.

b. use the class pointer stored in the GSKVN instance to look up methods and dispatch messages, intercepting those of interest and sending out notifications.

There are obviously a few other special cases - If the observed object receives a -dealloc message, the GSKVN instance must also remove itsself from the map table. If the observed object receives a -class message, the GSKVN instance must return the original class pointer. etc.

When there are no longer any observers watching an object, the GSKVN instance for the object is removed from the map table.

When the GSKVN object is removed from the map table, it must be deallocated using NSDeallocateObject()

Finally, the big special case ... When an observed object receives a -respondsToSelector: or -methodForSelector: etc message for a selector corresponding to an accessor method which is not implemented by the class of the observed object, the GSKVN class needs to have -respondesToSelector: return YES if there is an instance variable corresponding to it, and -methodForSelector: must return a method which is able to access the instance variables accordingly (looking at the \_cmd argument to see which instance method to acccess). This is messy, but fairly strightforward.

One thing worth noting ... information for this case should be assembled when the object is first observed ... by examining all the ivars of the object and seeing whether corresponding accessor methods exist. There are two reasons for this -

1\. performance ... you don't want to do that sort of thing often.

2\. so that the appropriate selectors for the fake accessor methods can be registered with the runtime otherwise the KVC system would be unable to attempt to access the ivars via accessor methods, and might attempt to access them directly ... which would mean that the notification systtem would be unaware of changes.

Hope that this helps.

 Retrieved from "[http://wiki.gnustep.org/index.php/Key\_Value\_Observing][1]"

[Categories][2]: [Objective-C][3]

##### Views

* [Article][4]
* [Discussion][5]
* [Edit][6]
* [History][7]

##### Personal tools

* [Create an account or log in][8]

[][9]

##### users

* [Applications][10]
* [Guides][11]
* [FAQ][12]
* [Get Help][13]
* [Report Bugs][14]
* [Donations][15]
* [Screenshots][16]

##### developers

* [Guides][17]
* [FAQ][18]
* [Base API (Foundation)][19]
* [GUI API (AppKit)][20]
* [Frameworks][21]

##### Navigation

* [Main Page][22]
* [Community portal][23]
* [Current events][24]
* [Recent changes][25]
* [Random page][26]
* [Help][27]

##### Search

##### Toolbox

* [What links here][28]
* [Related changes][29]
* [Upload file][30]
* [Special pages][31]
* [Printable version][32]

[![MediaWiki][33]][34]

* This page was last modified 14:50, 23 October 2006.
* This page has been accessed 14,942 times.
* Content is available under [GNU General Public License][35].
* [About GNUstepWiki][36]
* [Disclaimers][37]

  [1]: http://wiki.gnustep.org/index.php/Key_Value_Observing
  [2]: /index.php?title=Special:Categories&article=Key_Value_Observing "Special:Categories"
  [3]: /index.php/Category:Objective-C "Category:Objective-C"
  [4]: /index.php/Key_Value_Observing
  [5]: /index.php?title=Talk:Key_Value_Observing&action=edit
  [6]: /index.php?title=Key_Value_Observing&action=edit
  [7]: /index.php?title=Key_Value_Observing&action=history
  [8]: /index.php?title=Special:Userlogin&returnto=Key_Value_Observing
  [9]: /index.php/Main_Page "Main Page"
  [10]: /index.php/Category:Applications
  [11]: /index.php/User_Guides
  [12]: /index.php/User_FAQ
  [13]: /index.php/Get_Help
  [14]: /index.php/Report_Bugs
  [15]: /index.php/GNUstepWiki:Site_support
  [16]: /index.php/Screenshots
  [17]: /index.php/Developer_Guides
  [18]: /index.php/Developer_FAQ
  [19]: /index.php/Foundation
  [20]: /index.php/AppKit
  [21]: /index.php/Category:Frameworks
  [22]: /index.php/Main_Page
  [23]: /index.php/GNUstepWiki:Community_Portal
  [24]: /index.php/Current_events
  [25]: /index.php/Special:Recentchanges
  [26]: /index.php/Special:Random
  [27]: /index.php/Help:Contents
  [28]: /index.php/Special:Whatlinkshere/Key_Value_Observing
  [29]: /index.php/Special:Recentchangeslinked/Key_Value_Observing
  [30]: /index.php/Special:Upload
  [31]: /index.php/Special:Specialpages
  [32]: /index.php?title=Key_Value_Observing&printable=yes&printable=yes
  [33]: /skins/common/images/poweredby_mediawiki_88x31.png
  [34]: http://www.mediawiki.org/
  [35]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [36]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [37]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"