<>

# MusicKit

### From GNUstepWiki	{#siteSub}

object-oriented software system for building music, sound, signal processing, and MIDI applications.

<>

#### Current Version: V5.5.2

* Released: 2005-05-14
* Licensed: [MusicKit License][1]

<>

### Overview

The MusicKit is an object-oriented software system for building music, sound, signal processing, and MIDI applications. It has been used in such diverse commercial applications as music sequencers, computer games, and document processors. Professors and students in academia have used the MusicKit in a host of areas, including music performance, scientific experiments, computer-aided instruction, and physical modeling. The MusicKit was the first to unify the MIDI and Music V paradigms, thus combining interaction with generality (Music V, written by Max Mathews and others at Bell Labs four decades ago, was the first widely available "computer music compiler").

The NeXT MusicKit was first demonstrated at the 1988 NeXT product introduction and was bundled in NeXT software releases 1.0 and 2.0. Beginning with NeXT's 3.0 release, the MusicKit was no longer part of the standard NeXT software release. Instead, it was being distributed and supported as Version 4.0 by the Center for Computer Research in Music and Acoustics (CCRMA) of Stanford University. Versions 5.0 to 5.4.1 were then supported by tomandandy music, porting to several more popular operating systems.

The MusicKit Distribution is a comprehensive package that includes on-line documentation, programming examples, utilities, applications and sample score documents. The MusicKit is dependent on the SndKit distribution, originally written by Stephen Brandon, and both Framework collections are available at the same distribution site. The SndKit was written to be a complete open source implementation of NeXTs SoundKit. The re-write started and almost finished before the SoundKit itself was released in source code form.

Source code is available for everything, with the exception of the NeXT hardware implementation of the low-level sound and DSP drivers. This means researchers and developers may study the source or even customize the Music Kit and DSP tools to suit their needs. Enhancements can be committed to the CVS repository to have them incorporated for future releases. Commercial software developers may freely incorporate and adapt the software to accelerate development of software products.

<>

### Features

* Applicable to composers writing real-time computer music applications.
* Applicable to programmers writing cross-platform audio/music applications.
* Extensible, high-level object-oriented frameworks that are a super-set of Music V and MIDI paradigms.
* Written in Objective C and C, using Apple's OpenStep/Cocoa API, the FoundationKit.
* Using the Python to Objective C bridge PyObjC enables applications and utilities to be written in Python, an interpreted object-oriented language.
* Functionally comparable (although architecturally dissimilar) to JMSL (Java Music Specification Language).
* Representation system capable of depicting phrase-level structure such as legato transitions.
* General time management/scheduling mechanism, supporting synchronization to MIDI time code.
* Efficient real-time synthesis and sound processing, including option for quadraphonic sound.
* Complete support for multiple MIDI inputs and outputs.
* Fully-dynamic DSP resource allocation system with dynamic linking and loading, on multiple DSPs.
* Digital sound I/O from the DSP port with support for serial port devices by all popular vendors.
* Non-real time mode, where the DSP returns data to the application or writes a sound file.
* Suite of applications, including Ensemble Ã¢ÂÂ an interactive algorithmic composition and performance environment (including a built-in sampler), and ScorePlayer Ã¢ÂÂ a Scorefile and standard MIDI file player.
* Library of instruments, including FM, wavetable, physical modeling and waveshaping synthesis.
* Library of unit generators for synthesis and sound processing.
* Documentation, programming examples, utilities, including a sound file mixer, sample rate converter, etc.
* ScoreFile, a textual scripting language for music.
* Connectable audio processing modules (Ã¢ÂÂpluginsÃ¢ÂÂ) including standard audio effects such as reverb.
* Sound data held in a specifiable variety of formats, i.e 8, 16, 24 bit or floating point. Allows trading off sample data size vs. processing time.
* MP3 file reading and writing. Decoding of MP3 can be done in a background thread after reading, or on-the-fly during playback, allowing selection of memory consumption versus processor load.
* MP3 and Ogg/Vorbis streaming of audio output to web servers using the libshout library. The libshout library license is LGPL, not GPL and so do not compromise the MusicKit license

<>

### Maintainer

Leigh M. Smith

<>

### Related Links

* [The MusicKit Project][2]
* [David Jaffe's (the original author) MusicKit site.][3]
* [CCRMA's MusicKit site.][4]

 Retrieved from "<http://wiki.gnustep.org/index.php/MusicKit>"

[Categories][5]: [Audio Frameworks][6] | [Frameworks][7]

##### Views

* [Article][8]
* [Discussion][9]
* [Edit][10]
* [History][11]

##### Personal tools

* [Create an account or log in][12]

[][13]

##### users

* [Applications][14]
* [Guides][15]
* [FAQ][16]
* [Get Help][17]
* [Report Bugs][18]
* [Donations][19]
* [Screenshots][20]

##### developers

* [Guides][21]
* [FAQ][22]
* [Base API (Foundation)][23]
* [GUI API (AppKit)][24]
* [Frameworks][25]

##### Navigation

* [Main Page][26]
* [Community portal][27]
* [Current events][28]
* [Recent changes][29]
* [Random page][30]
* [Help][31]

##### Search

##### Toolbox

* [What links here][32]
* [Related changes][33]
* [Upload file][34]
* [Special pages][35]
* [Printable version][36]

[![MediaWiki][37]][38]

* This page was last modified 09:26, 4 July 2008.
* This page has been accessed 8,322 times.
* Content is available under [GNU General Public License][39].
* [About GNUstepWiki][40]
* [Disclaimers][41]

  [1]: http://musickit.sourceforge.net/license.html "http://musickit.sourceforge.net/license.html"
  [2]: http://musickit.sourceforge.net/ "http://musickit.sourceforge.net/"
  [3]: http://www.jaffe.com/mk97.html "http://www.jaffe.com/mk97.html"
  [4]: http://ccrma-www.stanford.edu/CCRMA/Overview/hardsoftware.html "http://ccrma-www.stanford.edu/CCRMA/Overview/hardsoftware.html"
  [5]: /index.php?title=Special:Categories&article=MusicKit "Special:Categories"
  [6]: /index.php/Category:Audio_Frameworks "Category:Audio Frameworks"
  [7]: /index.php/Category:Frameworks "Category:Frameworks"
  [8]: /index.php/MusicKit
  [9]: /index.php?title=Talk:MusicKit&action=edit
  [10]: /index.php?title=MusicKit&action=edit
  [11]: /index.php?title=MusicKit&action=history
  [12]: /index.php?title=Special:Userlogin&returnto=MusicKit
  [13]: /index.php/Main_Page "Main Page"
  [14]: /index.php/Category:Applications
  [15]: /index.php/User_Guides
  [16]: /index.php/User_FAQ
  [17]: /index.php/Get_Help
  [18]: /index.php/Report_Bugs
  [19]: /index.php/GNUstepWiki:Site_support
  [20]: /index.php/Screenshots
  [21]: /index.php/Developer_Guides
  [22]: /index.php/Developer_FAQ
  [23]: /index.php/Foundation
  [24]: /index.php/AppKit
  [25]: /index.php/Category:Frameworks
  [26]: /index.php/Main_Page
  [27]: /index.php/GNUstepWiki:Community_Portal
  [28]: /index.php/Current_events
  [29]: /index.php/Special:Recentchanges
  [30]: /index.php/Special:Random
  [31]: /index.php/Help:Contents
  [32]: /index.php/Special:Whatlinkshere/MusicKit
  [33]: /index.php/Special:Recentchangeslinked/MusicKit
  [34]: /index.php/Special:Upload
  [35]: /index.php/Special:Specialpages
  [36]: /index.php?title=MusicKit&printable=yes&printable=yes
  [37]: /skins/common/images/poweredby_mediawiki_88x31.png
  [38]: http://www.mediawiki.org/
  [39]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [40]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [41]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"