<>

# NSArray

### From GNUstepWiki	{#siteSub}

[NSArray][1] is an immutable, integer indexed, array of objects.

<table>
<tr>
<td>
## Contents
* [1 Creating Arrays][2]
  * [1\.1 From a List][3]
  * [1\.2 Copy an Array][4]
  * [1\.3 From an Array][5]
* [2 Code chunks][6]
  * [2\.1 Create index dictionary][7]
* [3 See Also][8]
</td>
</tr>
</table>

[[edit][9]]

<>

## Creating Arrays

[[edit][10]]

<>

### From a List

The most common method to create an array is to just pass it a list:

	 NSArray *array = [NSArray arrayWithObjects: @"John", @"Bob", [NSNull null], @"Jane", nil];

When creating arrays remember that any kind of object can be included, but only objects can be included. Note that `nil` values cannot be included in an array; you should use the [`[NSNull null]`][11] dummy object instead.

Note that when you provide a variable-length list of objects in Objective-C, you need to "terminate" the list with `nil`. Otherwise, the function has no way of knowing how many arguments there are.

[[edit][12]]

<>

### Copy an Array

A copy of an array can be done simply by doing the following:

	 NSArray *array1 = [NSArray arrayWithObjects: @"John", @"Bob", [NSNull null], @"Jane", nil];
	 NSArray *array2 = [NSArray arrayWithArray: array1];

[[edit][13]]

<>

### From an Array

An array object can be made with a regular array of objects, as shown in the following example:

	 id array1[4] = {@"John", @"Bob", [NSNull null], @"Jane"};
	 NSArray *array2 = [NSArray arrayWithObjects: array1 count: 4];

Count being the number of objects from the array to be used.

[[edit][14]]

<>

## Code chunks

[[edit][15]]

<>

### Create index dictionary

Following NSArray category method creates a dictionary which works as an index by an attribute of contained objects. It uses [Key Value Coding][16].

	- (NSDictionary *)indexDictionaryForKey:(NSString *)key
	{
	   NSMutableDictionary *dict = [[NSMutableDictionary alloc] init];
	   NSDictionary        *retval;
	   NSEnumerator        *enumerator;
	   id                   object;

	   enumerator = [self objectEnumerator];

	   while( (object = [enumerator nextObject]) )
	   {
	       [dict setObject:object forKey:[object valueForKey:key]];
	   }

	   retval = [[NSDictionary alloc] initWithDictionary:dict];
	   RELEASE(dict);

	   return AUTORELEASE(retval);
	}

[[edit][17]]

<>

## See Also

* [NSMutableArray][18]
* [NSEnumerator][19]

 Retrieved from "<http://wiki.gnustep.org/index.php/NSArray>"

[Categories][20]: [Foundation][21] | [Snippets][22]

##### Views

* [Article][23]
* [Discussion][24]
* [Edit][25]
* [History][26]

##### Personal tools

* [Create an account or log in][27]

[][28]

##### users

* [Applications][29]
* [Guides][30]
* [FAQ][31]
* [Get Help][32]
* [Report Bugs][33]
* [Donations][34]
* [Screenshots][35]

##### developers

* [Guides][36]
* [FAQ][37]
* [Base API (Foundation)][38]
* [GUI API (AppKit)][39]
* [Frameworks][40]

##### Navigation

* [Main Page][41]
* [Community portal][42]
* [Current events][43]
* [Recent changes][44]
* [Random page][45]
* [Help][46]

##### Search

##### Toolbox

* [What links here][47]
* [Related changes][48]
* [Upload file][49]
* [Special pages][50]
* [Printable version][51]

[![MediaWiki][52]][53]

* This page was last modified 08:00, 12 May 2009.
* This page has been accessed 30,190 times.
* Content is available under [GNU General Public License][54].
* [About GNUstepWiki][55]
* [Disclaimers][56]

  [1]: http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSArray.html#class$NSArray "http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSArray.html#class$NSArray"
  [2]: #Creating_Arrays
  [3]: #From_a_List
  [4]: #Copy_an_Array
  [5]: #From_an_Array
  [6]: #Code_chunks
  [7]: #Create_index_dictionary
  [8]: #See_Also
  [9]: /index.php?title=NSArray&action=edit&section=1 "NSArray"
  [10]: /index.php?title=NSArray&action=edit&section=2 "NSArray"
  [11]: /index.php?title=NSNull&action=edit "NSNull"
  [12]: /index.php?title=NSArray&action=edit&section=3 "NSArray"
  [13]: /index.php?title=NSArray&action=edit&section=4 "NSArray"
  [14]: /index.php?title=NSArray&action=edit&section=5 "NSArray"
  [15]: /index.php?title=NSArray&action=edit&section=6 "NSArray"
  [16]: /index.php/Key_Value_Coding "Key Value Coding"
  [17]: /index.php?title=NSArray&action=edit&section=7 "NSArray"
  [18]: /index.php?title=NSMutableArray&action=edit "NSMutableArray"
  [19]: /index.php/NSEnumerator "NSEnumerator"
  [20]: /index.php?title=Special:Categories&article=NSArray "Special:Categories"
  [21]: /index.php/Category:Foundation "Category:Foundation"
  [22]: /index.php/Category:Snippets "Category:Snippets"
  [23]: /index.php/NSArray
  [24]: /index.php?title=Talk:NSArray&action=edit
  [25]: /index.php?title=NSArray&action=edit
  [26]: /index.php?title=NSArray&action=history
  [27]: /index.php?title=Special:Userlogin&returnto=NSArray
  [28]: /index.php/Main_Page "Main Page"
  [29]: /index.php/Category:Applications
  [30]: /index.php/User_Guides
  [31]: /index.php/User_FAQ
  [32]: /index.php/Get_Help
  [33]: /index.php/Report_Bugs
  [34]: /index.php/GNUstepWiki:Site_support
  [35]: /index.php/Screenshots
  [36]: /index.php/Developer_Guides
  [37]: /index.php/Developer_FAQ
  [38]: /index.php/Foundation
  [39]: /index.php/AppKit
  [40]: /index.php/Category:Frameworks
  [41]: /index.php/Main_Page
  [42]: /index.php/GNUstepWiki:Community_Portal
  [43]: /index.php/Current_events
  [44]: /index.php/Special:Recentchanges
  [45]: /index.php/Special:Random
  [46]: /index.php/Help:Contents
  [47]: /index.php/Special:Whatlinkshere/NSArray
  [48]: /index.php/Special:Recentchangeslinked/NSArray
  [49]: /index.php/Special:Upload
  [50]: /index.php/Special:Specialpages
  [51]: /index.php?title=NSArray&printable=yes&printable=yes
  [52]: /skins/common/images/poweredby_mediawiki_88x31.png
  [53]: http://www.mediawiki.org/
  [54]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [55]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [56]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"