<>

# NSMutableString

### From GNUstepWiki	{#siteSub}

[NSMutableString][1] inherits from [NSString][2], but includes methods for changing the string.

<table>
<tr>
<td>
## Contents
* [1 Editing Strings][3]
  * [1\.1 Adding To Strings][4]
    * [1\.1.1 Appending Strings][5]
    * [1\.1.2 Inserting Substrings][6]
  * [1\.2 Replacing Substrings][7]
</td>
</tr>
</table>

[[edit][8]]

<>

## Editing Strings

[[edit][9]]

<>

### Adding To Strings

Strings can be added on to by appending the new substring to the end, or by inserting it any where in the middle.

[[edit][10]]

<>

#### Appending Strings

The simplest way to edit a string is by appending to the end of the string, as shown here:

	 NSMutableString *str = [NSMutableString stringWithString: @"short string"];
	 [str appendString: @" made longer"];
	 // str is now = @"short string made longer"

C style formating flags can also be used as follows:

	 NSMutableString *str = [NSMutableString stringWithString: @"short string"];
	 [str appendFormat: @" made longer %@.", @"with formating"];
	 // str is now = @"short string made longer with formating."

[[edit][11]]

<>

#### Inserting Substrings

The more advanced method of adding to strings in by insertion, as demonstrated here:

	 NSMutableString *str = [NSMutableString stringWithString: @"a string"];
	 [str insertString: @"new " atIndex: 2];
	 // str is now = @"a new string"

[[edit][12]]

<>

### Replacing Substrings

A certain substring can be replaced with a new one as follows:

	 NSMutableString *str = [NSMutableString stringWithString: @"a old string"];
	 [str replaceString: @"old" withString: @"new];
	 // str is now = @"a new string"

This can also be done with ranges:

	 NSMutableString *str = [NSMutableString stringWithString: @"a old string"];
	 // start at index 2 and include the next 3 characters
	 [str replaceCharactersInRange: NSMakeRange(2, 3) withString: @"new];
	 // str is now = @"a new string"

 Retrieved from "<http://wiki.gnustep.org/index.php/NSMutableString>"

[Categories][13]: [Foundation][14] | [Snippets][15]

##### Views

* [Article][16]
* [Discussion][17]
* [Edit][18]
* [History][19]

##### Personal tools

* [Create an account or log in][20]

[][21]

##### users

* [Applications][22]
* [Guides][23]
* [FAQ][24]
* [Get Help][25]
* [Report Bugs][26]
* [Donations][27]
* [Screenshots][28]

##### developers

* [Guides][29]
* [FAQ][30]
* [Base API (Foundation)][31]
* [GUI API (AppKit)][32]
* [Frameworks][33]

##### Navigation

* [Main Page][34]
* [Community portal][35]
* [Current events][36]
* [Recent changes][37]
* [Random page][38]
* [Help][39]

##### Search

##### Toolbox

* [What links here][40]
* [Related changes][41]
* [Upload file][42]
* [Special pages][43]
* [Printable version][44]

[![MediaWiki][45]][46]

* This page was last modified 04:50, 12 May 2009.
* This page has been accessed 22,004 times.
* Content is available under [GNU General Public License][47].
* [About GNUstepWiki][48]
* [Disclaimers][49]

  [1]: http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSString.html#class$NSMutableString "http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSString.html#class$NSMutableString"
  [2]: /index.php/NSString "NSString"
  [3]: #Editing_Strings
  [4]: #Adding_To_Strings
  [5]: #Appending_Strings
  [6]: #Inserting_Substrings
  [7]: #Replacing_Substrings
  [8]: /index.php?title=NSMutableString&action=edit&section=1 "NSMutableString"
  [9]: /index.php?title=NSMutableString&action=edit&section=2 "NSMutableString"
  [10]: /index.php?title=NSMutableString&action=edit&section=3 "NSMutableString"
  [11]: /index.php?title=NSMutableString&action=edit&section=4 "NSMutableString"
  [12]: /index.php?title=NSMutableString&action=edit&section=5 "NSMutableString"
  [13]: /index.php?title=Special:Categories&article=NSMutableString "Special:Categories"
  [14]: /index.php/Category:Foundation "Category:Foundation"
  [15]: /index.php/Category:Snippets "Category:Snippets"
  [16]: /index.php/NSMutableString
  [17]: /index.php?title=Talk:NSMutableString&action=edit
  [18]: /index.php?title=NSMutableString&action=edit
  [19]: /index.php?title=NSMutableString&action=history
  [20]: /index.php?title=Special:Userlogin&returnto=NSMutableString
  [21]: /index.php/Main_Page "Main Page"
  [22]: /index.php/Category:Applications
  [23]: /index.php/User_Guides
  [24]: /index.php/User_FAQ
  [25]: /index.php/Get_Help
  [26]: /index.php/Report_Bugs
  [27]: /index.php/GNUstepWiki:Site_support
  [28]: /index.php/Screenshots
  [29]: /index.php/Developer_Guides
  [30]: /index.php/Developer_FAQ
  [31]: /index.php/Foundation
  [32]: /index.php/AppKit
  [33]: /index.php/Category:Frameworks
  [34]: /index.php/Main_Page
  [35]: /index.php/GNUstepWiki:Community_Portal
  [36]: /index.php/Current_events
  [37]: /index.php/Special:Recentchanges
  [38]: /index.php/Special:Random
  [39]: /index.php/Help:Contents
  [40]: /index.php/Special:Whatlinkshere/NSMutableString
  [41]: /index.php/Special:Recentchangeslinked/NSMutableString
  [42]: /index.php/Special:Upload
  [43]: /index.php/Special:Specialpages
  [44]: /index.php?title=NSMutableString&printable=yes&printable=yes
  [45]: /skins/common/images/poweredby_mediawiki_88x31.png
  [46]: http://www.mediawiki.org/
  [47]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [48]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [49]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"