<>

# NSString

### From GNUstepWiki	{#siteSub}

Strings in GNUstep use the [NSString][1] class in gnustep-base. NSString is a immutable class, meaning it cannot change. For mutable strings, see [NSMutableString][2]. See the reference manual for gnustep-base for more details about NSString.

<table>
<tr>
<td>
## Contents
* [1 Constructing Strings][3]
  * [1\.1 Constant Strings][4]
  * [1\.2 Copy Strings][5]
  * [1\.3 C Strings][6]
  * [1\.4 Formated Strings][7]
* [2 Getting a C String][8]
* [3 Reading and Writing Files With String][9]
* [4 Substrings][10]
</td>
</tr>
</table>

[[edit][11]]

<>

## Constructing Strings

[[edit][12]]

<>

### Constant Strings

As you can create static instances of char\* plain C, you can create strings in GNUstep that automatically flatten out to be static instances of NSString. This is done by preceding the quoted string by an "at" symbol ('@'). For example:

	 NSString * myString = @"This is an example of a string.";
	 NSLog(myString);

myString is now an NSString object, and can have methods called on it like any other string.

[[edit][13]]

<>

### Copy Strings

You can also make a copy of a string as shown in the following example:

	 NSString *myString = @"This is an example of a string.";
	 NSString *newString = [NSString stringWithString: myString];

[[edit][14]]

<>

### C Strings

Or if you already have a C string you can convert it to a NSString object as follows:

	 char *myString = "This is a C string.";
	 ...
	 NSString *NSString newString1 = [NSString stringWithCString: myString encoding: [NSString defaultCStringEncoding]];
	 // Or:
	 NSString *NSString newString2 = [NSString stringWithUTF8String: myString];

Note that using [NSString stringWithCString] is deprecated!

[[edit][15]]

<>

### Formated Strings

A more flexable way of creating a string, using C style format flags follows:

	 NSString *myString = [NSString stringWithFormat: @"This is an%@ of a string with %d integer.", @" example", 1];

[[edit][16]]

<>

## Getting a C String

You can convert an NSString object to a plain C string using the cStringUsingEncoding: method. For example:

	 NSString *newString = @"This is a test string.";
	 char     *theString;

	 theString = [newString cStringWithEncoding:[NSString defaultCStringEncoding]];

or:

	 theString = [newString UTF8String];

Note that using [string cString] is deprecated!

[[edit][17]]

<>

## Reading and Writing Files With String

The following example shows how you would use files with NSString:

	 // Read in the file.
	 NSString *aString = [NSString stringWithContentsOfFile: @"infile.txt"];
	 // Do something with our new string.
	 aString = _doSomething_(aString);
	 // And finally save our changes to a file.
	 if([aString writeToFile: @"outfile" atomically: YES])
	   // Success code.
	 else
	   // Error code.

[[edit][18]]

<>

## Substrings

If you have a delimiter for breaking the string up, the easiest method to use would be the [string componentsSeparatedByString:] method. The following example demonstrates this:

	 NSString *string = @"John, Bob, Jane";
	 NSArray *strings = [string componentsSeparatedByString: @", "];
	 // give us the array {@"John", @"Bob", @"Jane"}

An array of string can also be joined together with the [array componentsJoinedByString:] method as follows:

	 NSArray *strings = [NSArray arrayWithObjects: @"John", @"Bob", @"Jane", nil];
	 NSString *string = [strings componentsJoinedByString: @", "];
	 // creating the string @"John, Bob, Jane"

If you need something more advanced [NSScanner][19] will be need.

----

One the other hand, if you know the indexes ahead of time one of three substring methods could be used, as demonstrated in the following example:

	 NSString *string = @"John, Bob, Jane";

	 NSLog([string substringFromIndex: 6]);
	 // Get the last six characters in the string (", Jane")

	 NSLog([string substringToIndex: 6]);
	 // Get the first six characters in the string ("John, ")

	 NSLog([string substringWithRange: NSMakeRange(3, 6)]);
	 // Starting at index three get a string of length six ("hn, Bo")

[[NSRange][20]] is a structure used mainly in string and arrays, defining the beginning index and the offset.

 Retrieved from "<http://wiki.gnustep.org/index.php/NSString>"

[Categories][21]: [Foundation][22] | [Snippets][23]

##### Views

* [Article][24]
* [Discussion][25]
* [Edit][26]
* [History][27]

##### Personal tools

* [Create an account or log in][28]

[][29]

##### users

* [Applications][30]
* [Guides][31]
* [FAQ][32]
* [Get Help][33]
* [Report Bugs][34]
* [Donations][35]
* [Screenshots][36]

##### developers

* [Guides][37]
* [FAQ][38]
* [Base API (Foundation)][39]
* [GUI API (AppKit)][40]
* [Frameworks][41]

##### Navigation

* [Main Page][42]
* [Community portal][43]
* [Current events][44]
* [Recent changes][45]
* [Random page][46]
* [Help][47]

##### Search

##### Toolbox

* [What links here][48]
* [Related changes][49]
* [Upload file][50]
* [Special pages][51]
* [Printable version][52]

[![MediaWiki][53]][54]

* This page was last modified 04:51, 12 May 2009.
* This page has been accessed 102,310 times.
* Content is available under [GNU General Public License][55].
* [About GNUstepWiki][56]
* [Disclaimers][57]

  [1]: http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSString.html#class$NSString "http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSString.html#class$NSString"
  [2]: /index.php/NSMutableString "NSMutableString"
  [3]: #Constructing_Strings
  [4]: #Constant_Strings
  [5]: #Copy_Strings
  [6]: #C_Strings
  [7]: #Formated_Strings
  [8]: #Getting_a_C_String
  [9]: #Reading_and_Writing_Files_With_String
  [10]: #Substrings
  [11]: /index.php?title=NSString&action=edit&section=1 "NSString"
  [12]: /index.php?title=NSString&action=edit&section=2 "NSString"
  [13]: /index.php?title=NSString&action=edit&section=3 "NSString"
  [14]: /index.php?title=NSString&action=edit&section=4 "NSString"
  [15]: /index.php?title=NSString&action=edit&section=5 "NSString"
  [16]: /index.php?title=NSString&action=edit&section=6 "NSString"
  [17]: /index.php?title=NSString&action=edit&section=7 "NSString"
  [18]: /index.php?title=NSString&action=edit&section=8 "NSString"
  [19]: /index.php?title=NSScanner&action=edit "NSScanner"
  [20]: http://www.gnustep.org/resources/documentation/Developer/Base/Reference/TypesAndConstants.html#type$NSRange "http://www.gnustep.org/resources/documentation/Developer/Base/Reference/TypesAndConstants.html#type$NSRange"
  [21]: /index.php?title=Special:Categories&article=NSString "Special:Categories"
  [22]: /index.php/Category:Foundation "Category:Foundation"
  [23]: /index.php/Category:Snippets "Category:Snippets"
  [24]: /index.php/NSString
  [25]: /index.php/Talk:NSString
  [26]: /index.php?title=NSString&action=edit
  [27]: /index.php?title=NSString&action=history
  [28]: /index.php?title=Special:Userlogin&returnto=NSString
  [29]: /index.php/Main_Page "Main Page"
  [30]: /index.php/Category:Applications
  [31]: /index.php/User_Guides
  [32]: /index.php/User_FAQ
  [33]: /index.php/Get_Help
  [34]: /index.php/Report_Bugs
  [35]: /index.php/GNUstepWiki:Site_support
  [36]: /index.php/Screenshots
  [37]: /index.php/Developer_Guides
  [38]: /index.php/Developer_FAQ
  [39]: /index.php/Foundation
  [40]: /index.php/AppKit
  [41]: /index.php/Category:Frameworks
  [42]: /index.php/Main_Page
  [43]: /index.php/GNUstepWiki:Community_Portal
  [44]: /index.php/Current_events
  [45]: /index.php/Special:Recentchanges
  [46]: /index.php/Special:Random
  [47]: /index.php/Help:Contents
  [48]: /index.php/Special:Whatlinkshere/NSString
  [49]: /index.php/Special:Recentchangeslinked/NSString
  [50]: /index.php/Special:Upload
  [51]: /index.php/Special:Specialpages
  [52]: /index.php?title=NSString&printable=yes&printable=yes
  [53]: /skins/common/images/poweredby_mediawiki_88x31.png
  [54]: http://www.mediawiki.org/
  [55]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [56]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [57]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"