<>

# NSTextField

### From GNUstepWiki	{#siteSub}

NSTextField displays text a user can select or edit and sends its action message to its target when the user presses the Return key while editing.

[[edit][1]]

<>

## Code chunks

[[edit][2]]

<>

### Testing _chars_ entered by users in _NSTextField_

When the contents of a NSTextField are changed by the user, it is possible to check whether or not to accept the changes.

1\. Subclass NSTextField

2\. In your subclass implement the

	        - (BOOL) textView: (NSTextView*) textView
	        shouldChangeTextInRange: (NSRange) range
	        replacementString: (NSString*) replacementString

method.

3\. Within this method you can access to the _replacementString_ as an NSString, or as _char_ with the following line:

	        char c = *([replacementString cString] + 0);

4\. You should return YES or NO depending on whether you accept the replacement string.

[[edit][3]]

<>

### Limiting text input length in _NSTextField_

(based on Alexander Malmberg's snippet)

1\. Subclass NSTextField

2\. In your subclass implement the

	        - (BOOL) textView: (NSTextView*) textView
	        shouldChangeTextInRange: (NSRange) range
	        replacementString: (NSString*) replacementString

method.

3\. Also create an instance variable setting method:

	         - (void) setMaxLength: (int) ml
	         {
	            maxLength = ml;
	         }

4\. Then fill your implementation of textView:shouldChangeTextInRange:replacementString: with the following code:

	         int newLength;
	         /* The exact change isn't known. Disallow the change to be safe. */
	          if (range.location == NSNotFound)
	               return NO;
	          newLength=[[textView textStorage] length]+[replacementString length]-range.length;
	          if (newLength&gt;maxLength)
	               return YES; //allowing
	          else
	               return NO; // not allowing

 Retrieved from "<http://wiki.gnustep.org/index.php/NSTextField>"

[Categories][4]: [AppKit][5] | [Snippets][6]

##### Views

* [Article][7]
* [Discussion][8]
* [Edit][9]
* [History][10]

##### Personal tools

* [Create an account or log in][11]

[][12]

##### users

* [Applications][13]
* [Guides][14]
* [FAQ][15]
* [Get Help][16]
* [Report Bugs][17]
* [Donations][18]
* [Screenshots][19]

##### developers

* [Guides][20]
* [FAQ][21]
* [Base API (Foundation)][22]
* [GUI API (AppKit)][23]
* [Frameworks][24]

##### Navigation

* [Main Page][25]
* [Community portal][26]
* [Current events][27]
* [Recent changes][28]
* [Random page][29]
* [Help][30]

##### Search

##### Toolbox

* [What links here][31]
* [Related changes][32]
* [Upload file][33]
* [Special pages][34]
* [Printable version][35]

[![MediaWiki][36]][37]

* This page was last modified 15:47, 21 April 2006.
* This page has been accessed 14,065 times.
* Content is available under [GNU General Public License][38].
* [About GNUstepWiki][39]
* [Disclaimers][40]

  [1]: /index.php?title=NSTextField&action=edit&section=1 "NSTextField"
  [2]: /index.php?title=NSTextField&action=edit&section=2 "NSTextField"
  [3]: /index.php?title=NSTextField&action=edit&section=3 "NSTextField"
  [4]: /index.php?title=Special:Categories&article=NSTextField "Special:Categories"
  [5]: /index.php/Category:AppKit "Category:AppKit"
  [6]: /index.php/Category:Snippets "Category:Snippets"
  [7]: /index.php/NSTextField
  [8]: /index.php?title=Talk:NSTextField&action=edit
  [9]: /index.php?title=NSTextField&action=edit
  [10]: /index.php?title=NSTextField&action=history
  [11]: /index.php?title=Special:Userlogin&returnto=NSTextField
  [12]: /index.php/Main_Page "Main Page"
  [13]: /index.php/Category:Applications
  [14]: /index.php/User_Guides
  [15]: /index.php/User_FAQ
  [16]: /index.php/Get_Help
  [17]: /index.php/Report_Bugs
  [18]: /index.php/GNUstepWiki:Site_support
  [19]: /index.php/Screenshots
  [20]: /index.php/Developer_Guides
  [21]: /index.php/Developer_FAQ
  [22]: /index.php/Foundation
  [23]: /index.php/AppKit
  [24]: /index.php/Category:Frameworks
  [25]: /index.php/Main_Page
  [26]: /index.php/GNUstepWiki:Community_Portal
  [27]: /index.php/Current_events
  [28]: /index.php/Special:Recentchanges
  [29]: /index.php/Special:Random
  [30]: /index.php/Help:Contents
  [31]: /index.php/Special:Whatlinkshere/NSTextField
  [32]: /index.php/Special:Recentchangeslinked/NSTextField
  [33]: /index.php/Special:Upload
  [34]: /index.php/Special:Specialpages
  [35]: /index.php?title=NSTextField&printable=yes&printable=yes
  [36]: /skins/common/images/poweredby_mediawiki_88x31.png
  [37]: http://www.mediawiki.org/
  [38]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [39]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [40]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"