<>

# Property Lists

### From GNUstepWiki	{#siteSub}

NOTE: this document is still a work in progress. No responsibility is accepted for any problems arising from inaccuracies.

<table>
<tr>
<td>
## Contents
* [1 Introduction][1]
* [2 Dictionary][2]
* [3 Array][3]
* [4 Programming][4]
* [5 Other tips][5]
</td>
</tr>
</table>

[[edit][6]]

<>

## Introduction

Property lists are used throughout GNUstep to store defaults, program settings, application meta information, and so on. MacOS X has begun to use XML based property lists, but GNUstep uses the classic property list format. Support in GNUstep for XML property lists is still limited on some platforms (namely Windows); this situation should improve in the future as libxml platform build issues are resolved within GNUstep.

A property list is a logical tree of arrays, dictionaries, strings and numbers. The arrays and dictionaries may contain other arrays and dictionaries as data elements, and structures may become quite rich and expressive when representing complex data relationships.

[[edit][7]]

<>

## Dictionary

A dictionary is a list of key-value pairs, where each item in the list has a name associated with it (key) and another type (value), which could be another dictionary, an array or often a string. It programmatically corresponds to NSDictionary/NSMutableDictionary. They take the following syntax:

	{
	   KeyName1 = Value1;
	   AnotherKeyName = "Value2";
	   Something = ( "ArrayItem1", "ArrayItem2", "ArrayItem3" );
	   Key4 = 0.10;
	   KeyFive = { Dictionary2Key1 = "Something"; AnotherKey = "Somethingelse"; };
	}

As can be seen, each key-value pair is separated by a semi-colon. Within the pair, the key is seperated from the value with an "equals" (=) sign. The key name is arbitrary, and not put in inverted commas (""). Shown above are: an unknown type (could be some sort of string - TODO), a string, an array, a number and another dictionary (respectively).

[[edit][8]]

<>

## Array

An array is a list of values, each of the same type (often arrays or dictionaries). Programmatically, it uses NSArray/NSMutableArray. It takes a syntax similar to the following:

	( Value1, Value2, Value3, Value4 )<br />

	or<br />

	(
	   Value1,
	   Value2,
	   Value3,
	   Value4
	)

Each value is seperated by commas. By the technical definition of an array, each value is of the same "type".

[[edit][9]]

<>

## Programming

GNUstep permits such property list files (normally having a .plist extension) to be loaded and subsequently used in your applications or tools. FoundationKit - in GNUstep's case gnustep-base - classes NSDictionary and NSArray are used as representations of the property list data structures. Check the base API documentation for more information on working with these types programmatically.

NSString can be used to turn property lists in string form (either read from a file or constructed programmatically) into an equivalent data structure in memory. Again, see the API documentation for NSString (particularly the -propertyList method).

[[edit][10]]

<>

## Other tips

* Property lists are much like C programming, where newlines and spaces and tabs are not so important to parsing, but syntax elements like braces, semilcolons and operators are.
* Some examples of property lists may include:
  * ~/GNUstep/System/Defaults/.GNUstepDefaults (this is your defaults file for all installed GNUstep software; be careful when editing this file manually)

 Retrieved from "[http://wiki.gnustep.org/index.php/Property\_Lists][11]"

[Categories][12]: [Development][13]

##### Views

* [Article][14]
* [Discussion][15]
* [Edit][16]
* [History][17]

##### Personal tools

* [Create an account or log in][18]

[][19]

##### users

* [Applications][20]
* [Guides][21]
* [FAQ][22]
* [Get Help][23]
* [Report Bugs][24]
* [Donations][25]
* [Screenshots][26]

##### developers

* [Guides][27]
* [FAQ][28]
* [Base API (Foundation)][29]
* [GUI API (AppKit)][30]
* [Frameworks][31]

##### Navigation

* [Main Page][32]
* [Community portal][33]
* [Current events][34]
* [Recent changes][35]
* [Random page][36]
* [Help][37]

##### Search

##### Toolbox

* [What links here][38]
* [Related changes][39]
* [Upload file][40]
* [Special pages][41]
* [Printable version][42]

[![MediaWiki][43]][44]

* This page was last modified 08:50, 18 September 2005.
* This page has been accessed 28,628 times.
* Content is available under [GNU General Public License][45].
* [About GNUstepWiki][46]
* [Disclaimers][47]

  [1]: #Introduction
  [2]: #Dictionary
  [3]: #Array
  [4]: #Programming
  [5]: #Other_tips
  [6]: /index.php?title=Property_Lists&action=edit&section=1 "Property Lists"
  [7]: /index.php?title=Property_Lists&action=edit&section=2 "Property Lists"
  [8]: /index.php?title=Property_Lists&action=edit&section=3 "Property Lists"
  [9]: /index.php?title=Property_Lists&action=edit&section=4 "Property Lists"
  [10]: /index.php?title=Property_Lists&action=edit&section=5 "Property Lists"
  [11]: http://wiki.gnustep.org/index.php/Property_Lists
  [12]: /index.php?title=Special:Categories&article=Property_Lists "Special:Categories"
  [13]: /index.php/Category:Development "Category:Development"
  [14]: /index.php/Property_Lists
  [15]: /index.php?title=Talk:Property_Lists&action=edit
  [16]: /index.php?title=Property_Lists&action=edit
  [17]: /index.php?title=Property_Lists&action=history
  [18]: /index.php?title=Special:Userlogin&returnto=Property_Lists
  [19]: /index.php/Main_Page "Main Page"
  [20]: /index.php/Category:Applications
  [21]: /index.php/User_Guides
  [22]: /index.php/User_FAQ
  [23]: /index.php/Get_Help
  [24]: /index.php/Report_Bugs
  [25]: /index.php/GNUstepWiki:Site_support
  [26]: /index.php/Screenshots
  [27]: /index.php/Developer_Guides
  [28]: /index.php/Developer_FAQ
  [29]: /index.php/Foundation
  [30]: /index.php/AppKit
  [31]: /index.php/Category:Frameworks
  [32]: /index.php/Main_Page
  [33]: /index.php/GNUstepWiki:Community_Portal
  [34]: /index.php/Current_events
  [35]: /index.php/Special:Recentchanges
  [36]: /index.php/Special:Random
  [37]: /index.php/Help:Contents
  [38]: /index.php/Special:Whatlinkshere/Property_Lists
  [39]: /index.php/Special:Recentchangeslinked/Property_Lists
  [40]: /index.php/Special:Upload
  [41]: /index.php/Special:Specialpages
  [42]: /index.php?title=Property_Lists&printable=yes&printable=yes
  [43]: /skins/common/images/poweredby_mediawiki_88x31.png
  [44]: http://www.mediawiki.org/
  [45]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [46]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [47]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"