<>

# Protocol

### From GNUstepWiki	{#siteSub}

A protocol is a declaration of a group of methods not associated with any particular class.

[[edit][1]]

<>

## Formal Protocol

Formal Protocols are used to define the [Interface][2] for a set of methods, but not the implementation or any data members.

This is useful for defining an interface which objects will need to conform to in order to take advantage of some service or other.

Example:

	   @protocol MyFormalProtocol

	   -(void) someMethod;
	   -(id) someOtherMethod;

	   @end

<br />

[[edit][3]]

<>

## Informal Protocol

Informal Protocols are constructs that allow you to share a common [Interface][4] between two classes without them having to inherit from any specific object (the notable exception being NSObject).

They are generally made with a category on NSObject that has no implementation associated with it.

Example:

	   @interface NSObject (MyInformalProtocol)

	   - (id) someMethod;
	   - (void) anotherMethod;

	   @end

[[edit][5]]

<>

## Implementing Protocols

Formal and informal protocols take slightly different implementation paths. For formal protocols, you enclose the protocol name in less than/greater than signs e.g.:

	   @interface MyClass &lt;MyFormalProtocol&gt;

	   /* Methods in protocol */

	   -(void) someMethod;
	   -(id) someOtherMethod;

	   /* Your methods */

	   @end

With informal protocols, you place the protocol name in brackets after your class name, both in the interface and implemenation i.e.:

	   @interface MyClass (MyInformalProtocol)

and

	   @implementation MyClass (MyInformalProtocol)

Although the interface declaration is optional.

 Retrieved from "<http://wiki.gnustep.org/index.php/Protocol>"

[Categories][6]: [Objective-C][7]

##### Views

* [Article][8]
* [Discussion][9]
* [Edit][10]
* [History][11]

##### Personal tools

* [Create an account or log in][12]

[][13]

##### users

* [Applications][14]
* [Guides][15]
* [FAQ][16]
* [Get Help][17]
* [Report Bugs][18]
* [Donations][19]
* [Screenshots][20]

##### developers

* [Guides][21]
* [FAQ][22]
* [Base API (Foundation)][23]
* [GUI API (AppKit)][24]
* [Frameworks][25]

##### Navigation

* [Main Page][26]
* [Community portal][27]
* [Current events][28]
* [Recent changes][29]
* [Random page][30]
* [Help][31]

##### Search

##### Toolbox

* [What links here][32]
* [Related changes][33]
* [Upload file][34]
* [Special pages][35]
* [Printable version][36]

[![MediaWiki][37]][38]

* This page was last modified 09:47, 21 June 2006.
* This page has been accessed 16,435 times.
* Content is available under [GNU General Public License][39].
* [About GNUstepWiki][40]
* [Disclaimers][41]

  [1]: /index.php?title=Protocol&action=edit&section=1 "Protocol"
  [2]: /index.php/Interface "Interface"
  [3]: /index.php?title=Protocol&action=edit&section=2 "Protocol"
  [4]: /index.php/Interface "Interface"
  [5]: /index.php?title=Protocol&action=edit&section=3 "Protocol"
  [6]: /index.php?title=Special:Categories&article=Protocol "Special:Categories"
  [7]: /index.php/Category:Objective-C "Category:Objective-C"
  [8]: /index.php/Protocol
  [9]: /index.php?title=Talk:Protocol&action=edit
  [10]: /index.php?title=Protocol&action=edit
  [11]: /index.php?title=Protocol&action=history
  [12]: /index.php?title=Special:Userlogin&returnto=Protocol
  [13]: /index.php/Main_Page "Main Page"
  [14]: /index.php/Category:Applications
  [15]: /index.php/User_Guides
  [16]: /index.php/User_FAQ
  [17]: /index.php/Get_Help
  [18]: /index.php/Report_Bugs
  [19]: /index.php/GNUstepWiki:Site_support
  [20]: /index.php/Screenshots
  [21]: /index.php/Developer_Guides
  [22]: /index.php/Developer_FAQ
  [23]: /index.php/Foundation
  [24]: /index.php/AppKit
  [25]: /index.php/Category:Frameworks
  [26]: /index.php/Main_Page
  [27]: /index.php/GNUstepWiki:Community_Portal
  [28]: /index.php/Current_events
  [29]: /index.php/Special:Recentchanges
  [30]: /index.php/Special:Random
  [31]: /index.php/Help:Contents
  [32]: /index.php/Special:Whatlinkshere/Protocol
  [33]: /index.php/Special:Recentchangeslinked/Protocol
  [34]: /index.php/Special:Upload
  [35]: /index.php/Special:Specialpages
  [36]: /index.php?title=Protocol&printable=yes&printable=yes
  [37]: /skins/common/images/poweredby_mediawiki_88x31.png
  [38]: http://www.mediawiki.org/
  [39]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [40]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [41]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"