<>

# Reference counting

### From GNUstepWiki	{#siteSub}

Reference counting is used to automatically deallocate objects when they are no longer needed.

<table>
<tr>
<td>
## Contents
* [1 Using reference counting][1]
  * [1\.1 Example][2]
  * [1\.2 Tight Loop][3]
* [2 See also][4]
</td>
</tr>
</table>

[[edit][5]]

<>

## Using reference counting

By convention when using an autorelased object you must "retain" before using it, and release it when you are done with it. For consistency you may "retain the object you want at the beginign of your method, and release it at the end, though in a tight loop you may wish to only retain once.

[[edit][6]]

<>

### Example

&lt;source lang="objc"&gt;

-(void)myMethod:(NSObject\*)myObject \{

[myObject retain] //my code [myObject release]

\} &lt;/source&gt;

[[edit][7]]

<>

### Tight Loop

` `

-(void)myMethod:(NSObject\*)myObject \{

[myObject retain] for(int64\_t i = 0; i&lt;LONG\_LONG\_MAX; i++)

\{

[self mySubMethod:myObject]

\}

[myObject release]

\}

-(void)mySubMethod:(NSObject\*)myObject \{

//Remove retain/relase overhead

//[myObject\* retain]

//my code

//[myObject\* release]

\}

<br />

[[edit][8]]

<>

## See also

[Wikipedia on reference counting][9]

 Retrieved from "[http://wiki.gnustep.org/index.php/Reference\_counting][10]"

##### Views

* [Article][11]
* [Discussion][12]
* [Edit][13]
* [History][14]

##### Personal tools

* [Create an account or log in][15]

[][16]

##### users

* [Applications][17]
* [Guides][18]
* [FAQ][19]
* [Get Help][20]
* [Report Bugs][21]
* [Donations][22]
* [Screenshots][23]

##### developers

* [Guides][24]
* [FAQ][25]
* [Base API (Foundation)][26]
* [GUI API (AppKit)][27]
* [Frameworks][28]

##### Navigation

* [Main Page][29]
* [Community portal][30]
* [Current events][31]
* [Recent changes][32]
* [Random page][33]
* [Help][34]

##### Search

##### Toolbox

* [What links here][35]
* [Related changes][36]
* [Upload file][37]
* [Special pages][38]
* [Printable version][39]

[![MediaWiki][40]][41]

* This page was last modified 20:21, 21 July 2012.
* This page has been accessed 2,690 times.
* Content is available under [GNU General Public License][42].
* [About GNUstepWiki][43]
* [Disclaimers][44]

  [1]: #Using_reference_counting
  [2]: #Example
  [3]: #Tight_Loop
  [4]: #See_also
  [5]: /index.php?title=Reference_counting&action=edit&section=1 "Reference counting"
  [6]: /index.php?title=Reference_counting&action=edit&section=2 "Reference counting"
  [7]: /index.php?title=Reference_counting&action=edit&section=3 "Reference counting"
  [8]: /index.php?title=Reference_counting&action=edit&section=4 "Reference counting"
  [9]: http://en.wikipedia.org/wiki/Reference_counting "http://en.wikipedia.org/wiki/Reference counting"
  [10]: http://wiki.gnustep.org/index.php/Reference_counting
  [11]: /index.php/Reference_counting
  [12]: /index.php?title=Talk:Reference_counting&action=edit
  [13]: /index.php?title=Reference_counting&action=edit
  [14]: /index.php?title=Reference_counting&action=history
  [15]: /index.php?title=Special:Userlogin&returnto=Reference_counting
  [16]: /index.php/Main_Page "Main Page"
  [17]: /index.php/Category:Applications
  [18]: /index.php/User_Guides
  [19]: /index.php/User_FAQ
  [20]: /index.php/Get_Help
  [21]: /index.php/Report_Bugs
  [22]: /index.php/GNUstepWiki:Site_support
  [23]: /index.php/Screenshots
  [24]: /index.php/Developer_Guides
  [25]: /index.php/Developer_FAQ
  [26]: /index.php/Foundation
  [27]: /index.php/AppKit
  [28]: /index.php/Category:Frameworks
  [29]: /index.php/Main_Page
  [30]: /index.php/GNUstepWiki:Community_Portal
  [31]: /index.php/Current_events
  [32]: /index.php/Special:Recentchanges
  [33]: /index.php/Special:Random
  [34]: /index.php/Help:Contents
  [35]: /index.php/Special:Whatlinkshere/Reference_counting
  [36]: /index.php/Special:Recentchangeslinked/Reference_counting
  [37]: /index.php/Special:Upload
  [38]: /index.php/Special:Specialpages
  [39]: /index.php?title=Reference_counting&printable=yes&printable=yes
  [40]: /skins/common/images/poweredby_mediawiki_88x31.png
  [41]: http://www.mediawiki.org/
  [42]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [43]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [44]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"