<>

# Roadmap to Windows

### From GNUstepWiki	{#siteSub}

This page is the starter for the "Road to Windows", a goal of the GNUstep project to deliver a very [native][1] implementation. GNUstep currently works very well on Windows, but does not entirely blend in. The hope is that by completing the tasks discussed here that it will help GNUstep be a better Windows "citizen."

Windows has many differences with \*nix and OpenStep generally. These need to be dealt with in a way that delivers a 'Windows experience' to the end users but doesn't compromise the OpenStep API. Some differences are expected, but must be minimised in order to maximise software portability.

If you'd like to work on any of these tasks you should put your hand up in gnustep-discuss or e-mail [me][2] directly.

<table>
<tr>
<td>
## Contents
* [1 Make][3]
* [2 Base][4]
  * [2\.1 General][5]
  * [2\.2 GSXML][6]
  * [2\.3 Logging][7]
  * [2\.4 Dates &amp; Times][8]
  * [2\.5 Strings][9]
* [3 Gui][10]
  * [3\.1 General][11]
  * [3\.2 Drawing][12]
  * [3\.3 Panels][13]
</td>
</tr>
</table>

[[edit][14]]

<>

## Make

* Relies on a unix shell: We use MSYS and the mingw32 toolchain to provide a very unix-like build environment.
* Make doesn't support paths with spaces. Fundamental design flaw. Ideally we'd like a solution to this.
* Current implementation of 'make install' assumes \*nix which doesn't really apply. What does this mean?

[[edit][15]]

<>

## Base

[[edit][16]]

<>

### General

* More flexible layout mechanism (what needs doing for this) &amp; options to control in config file. What does this mean? perhaps we actually need a less flexible mechanism, but the 'right' one?
* Win32 "native" mechanism over-rides ... but for what?

[[edit][17]]

<>

### GSXML

* Use single url expansion mechanism for all (no special -//GNUstep//DTD)
* Organise them clearly somehow ... need tio decide how.

[[edit][18]]

<>

### Logging

* NSLog() should only be used for vital/error messages. These should be localizable.
* Localize all error output.
* Should implement FACILITY options for logging to SYSLOG if MacOS-X does this ... should be compatible.
* Use more flexible DebugLog for other output.

[[edit][19]]

<>

### Dates &amp; Times

* NSDate
  * Olsen &lt;-&gt; Windows timezone name mapping
  * knownTimeZoneNames returns Olsen
  * timeZoneWithName takes Olsen
  * unicode improvements (I have code for this...)

* Install/runtime option for native timezones only

* Add classes for other calendars as soon as we have both windows and unix implementations:
  * + GSJulianCalendarDate
  * + GSHebrewCalendarDate
  * + GSChineseCalendarDate
  * + GSJapaneseCalendarDate
  * + GSBuddhistCalendarDate

[[edit][20]]

<>

### Strings

* NSCaseInsensitiveSearch
  * Implementation tests
  * Add full Unicode case folding

* NSLiteralSearch
  * Corrections for composed sequences?

* Composed sequences &amp; Normalisation
  * Check composed sequence handling generally
  * Implement additional normalisation forms
  * proper (full) collation and comparison

* UTF32
  * Does this handle non-BMP characters right now? If not, what needs fixing?

* NSStringEncoding
  * additional encodings for Indian, SE Asia...

[[edit][21]]

<>

## Gui

[[edit][22]]

<>

### General

* NSMenu
  * Want horizontal, in-window menus theme

* NSPopupButton
  * Menu shouldn't require continuous mousedown but rather behave like other windows menus when using windows theme.

* NSHelpPanel
  * Interface to native windows help system and/or 'normal' help
  * [NSApplication showHelp] looks in Resources/(lang).lproj
    * Use Info.plist for name of help book
    * opens "AppName Help.chm" or
    * opens "AppName Help.hlp"
  * [NSApplication activateContextHelpMode]
  * Need a help generation/editing tool to support both unix and windows style help.

* Logging
  * Use NSLog() only for vital messages
  * Use NSDebugLLog() everywhere else
  * Localise everywhere

[[edit][23]]

<>

### Drawing

* Some controls are drawn. Others use pre-drawn images. These don't change in response to color preferences. That should be corrected. Notable: Radio buttons, check boxes. scrollbar arrows, menu arrows. Clean drawing code to use right colors from system color map ... should all go into theme system.

* Drawing should be improved generally so that it looks better and is faster

* Taskbar
  * Application icons should appear in the taskbar and on the applications windows in the same way as other windows applications. Behaviour should follow.

* NSImage
  * support for more image types

* NSColor/NSColorList
  * Windows theme code may load System color palette from current desktop settings (I have code for this...)
  * improve system color startup, don't automatically write System.clr to user folder
  * get gnustep-back to handle WM\_SYSCOLORCHANGE messages
  * Support ICCM colour profiles and colour correction
  * +[availableColorLists] should check directory modification date every time.

[[edit][24]]

<>

### Panels

* NSOpenPanel, NSSavePanel
  * If NSDefaultOpenDirectory isn't set should use "~/" on \*nix and "My Documents" on Win32.
  * Must support multiple drives etc on Win32
  * Should have theme able to display as Treeview, rather than Browser

 Retrieved from "[http://wiki.gnustep.org/index.php/Roadmap\_to\_Windows][25]"

[Categories][26]: [Microsoft Windows][27]

##### Views

* [Article][28]
* [Discussion][29]
* [Edit][30]
* [History][31]

##### Personal tools

* [Create an account or log in][32]

[][33]

##### users

* [Applications][34]
* [Guides][35]
* [FAQ][36]
* [Get Help][37]
* [Report Bugs][38]
* [Donations][39]
* [Screenshots][40]

##### developers

* [Guides][41]
* [FAQ][42]
* [Base API (Foundation)][43]
* [GUI API (AppKit)][44]
* [Frameworks][45]

##### Navigation

* [Main Page][46]
* [Community portal][47]
* [Current events][48]
* [Recent changes][49]
* [Random page][50]
* [Help][51]

##### Search

##### Toolbox

* [What links here][52]
* [Related changes][53]
* [Upload file][54]
* [Special pages][55]
* [Printable version][56]

[![MediaWiki][57]][58]

* This page was last modified 19:28, 3 April 2009.
* This page has been accessed 27,749 times.
* Content is available under [GNU General Public License][59].
* [About GNUstepWiki][60]
* [Disclaimers][61]

  [1]: /index.php/What_is_Native_on_Windows "What is Native on Windows"
  [2]: /index.php/User:Sheldon "User:Sheldon"
  [3]: #Make
  [4]: #Base
  [5]: #General
  [6]: #GSXML
  [7]: #Logging
  [8]: #Dates_.26_Times
  [9]: #Strings
  [10]: #Gui
  [11]: #General_2
  [12]: #Drawing
  [13]: #Panels
  [14]: /index.php?title=Roadmap_to_Windows&action=edit&section=1 "Roadmap to Windows"
  [15]: /index.php?title=Roadmap_to_Windows&action=edit&section=2 "Roadmap to Windows"
  [16]: /index.php?title=Roadmap_to_Windows&action=edit&section=3 "Roadmap to Windows"
  [17]: /index.php?title=Roadmap_to_Windows&action=edit&section=4 "Roadmap to Windows"
  [18]: /index.php?title=Roadmap_to_Windows&action=edit&section=5 "Roadmap to Windows"
  [19]: /index.php?title=Roadmap_to_Windows&action=edit&section=6 "Roadmap to Windows"
  [20]: /index.php?title=Roadmap_to_Windows&action=edit&section=7 "Roadmap to Windows"
  [21]: /index.php?title=Roadmap_to_Windows&action=edit&section=8 "Roadmap to Windows"
  [22]: /index.php?title=Roadmap_to_Windows&action=edit&section=9 "Roadmap to Windows"
  [23]: /index.php?title=Roadmap_to_Windows&action=edit&section=10 "Roadmap to Windows"
  [24]: /index.php?title=Roadmap_to_Windows&action=edit&section=11 "Roadmap to Windows"
  [25]: http://wiki.gnustep.org/index.php/Roadmap_to_Windows
  [26]: /index.php?title=Special:Categories&article=Roadmap_to_Windows "Special:Categories"
  [27]: /index.php/Category:Microsoft_Windows "Category:Microsoft Windows"
  [28]: /index.php/Roadmap_to_Windows
  [29]: /index.php/Talk:Roadmap_to_Windows
  [30]: /index.php?title=Roadmap_to_Windows&action=edit
  [31]: /index.php?title=Roadmap_to_Windows&action=history
  [32]: /index.php?title=Special:Userlogin&returnto=Roadmap_to_Windows
  [33]: /index.php/Main_Page "Main Page"
  [34]: /index.php/Category:Applications
  [35]: /index.php/User_Guides
  [36]: /index.php/User_FAQ
  [37]: /index.php/Get_Help
  [38]: /index.php/Report_Bugs
  [39]: /index.php/GNUstepWiki:Site_support
  [40]: /index.php/Screenshots
  [41]: /index.php/Developer_Guides
  [42]: /index.php/Developer_FAQ
  [43]: /index.php/Foundation
  [44]: /index.php/AppKit
  [45]: /index.php/Category:Frameworks
  [46]: /index.php/Main_Page
  [47]: /index.php/GNUstepWiki:Community_Portal
  [48]: /index.php/Current_events
  [49]: /index.php/Special:Recentchanges
  [50]: /index.php/Special:Random
  [51]: /index.php/Help:Contents
  [52]: /index.php/Special:Whatlinkshere/Roadmap_to_Windows
  [53]: /index.php/Special:Recentchangeslinked/Roadmap_to_Windows
  [54]: /index.php/Special:Upload
  [55]: /index.php/Special:Specialpages
  [56]: /index.php?title=Roadmap_to_Windows&printable=yes&printable=yes
  [57]: /skins/common/images/poweredby_mediawiki_88x31.png
  [58]: http://www.mediawiki.org/
  [59]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [60]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [61]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"