<>

# Using Subversion

### From GNUstepWiki	{#siteSub}

(Redirected from [SVN][1])

<table>
<tr>
<td>
## Contents
* [1 Anonymous GNUstep SVN Checkout][2]
* [2 Developer GNUstep SVN Checkout][3]
* [3 Setting up Subversion for Developer Use][4]
  * [3\.1 If you have a different username on your system than on svn.gna.org][5]
  * [3\.2 If you are prompted for a private key password][6]
  * [3\.3 Subversion on Windows][7]
* [4 Some background on repository layout][8]
* [5 Tips, Tricks, and Resources][9]
</td>
</tr>
</table>

[[edit][10]]

<>

## Anonymous GNUstep SVN Checkout

Simply run:

	svn co <http://svn.gna.org/svn/gnustep/modules>

You cannot use SVN+SSH unless you are a developer, and have a username and SSH public key registered at gna.org. See below for more details. You cannot check out /devmodules unless you are a developer. /modules is the same as /devmodules, except the SVN external references work for anonymous SVN checkouts.

[[edit][11]]

<>

## Developer GNUstep SVN Checkout

Simply run:

	svn co svn+ssh://svn.gna.org/svn/gnustep/devmodules

[[edit][12]]

<>

## Setting up Subversion for Developer Use

The first thing you will want to do is setup the ssh access to svn.gna.org. If you cannot type

	svn list svn+ssh://svn.gna.org/svn/gnustep/devmodules

without having to type a password or in some way change the above command, read below.

[[edit][13]]

<>

### If you have a different username on your system than on svn.gna.org

To get around this problem, you can setup per host SSH settings. To do this, open ~/.ssh/config and at the end add the lines

	Host svn.gna.org
	      User aeruder

This makes it so that everytime I connect to svn.gna.org with SSH, it will automatically use the username aeruder instead of my unix username.

[[edit][14]]

<>

### If you are prompted for a private key password

This will look something like:

	Enter passphrase for key '/home/andy/.ssh/id_dsa':

To get around this you can either setup ssh-agent to cache this password or you can simply turn off the password on your private key. To do the latter, simply type:

	ssh-keygen -t dsa -p

and follow the prompts, and when it prompts for a new passphrase, simply hit enter.

[[edit][15]]

<>

### Subversion on Windows

[TortiseSVN][16] is the preferred Subversion client on Windows.

For developers checking out devmodules, follow these instructions to get your system to remember your private key password (see the sections "PuTTY Configuration" and Pageant and "TortoiseSVN Usage").

<http://matttrent.com/blog/2005/aug/21/how-use-ssh-agent-windows-tortoisesvn/>

You will need the tools Putty, Puttygen, and Pageant from [[1]][17].

Subversion could also be obtained from Cygwin, however the Cygwin subversion client is currently broken for me (and less convenient than TortiseSVN.)

[[edit][18]]

<>

## Some background on repository layout

To familiarize yourself with the layout, I would recommend looking at the [web-access to svn][19] for GNUstep. You will notice that every project is in its own portion of the repository. For example:

	/libs
	/libs/gui
	/libs/gui/trunk

	/libs/gui/branches
	/libs/gui/branches/dawn
	/libs/gui/branches/...

	/libs/gui/tags
	/libs/gui/tags/alex_last_semistable
	/libs/gui/tags/...

This layout is very handy for having a per-project repository. I can easily branch or tag just /libs/gui and it all stays in its own namespace. However, what this DOES mean is that you cannot simply checkout /libs/gui or you will end up with several copies of the source. To get around this, we are using a nifty feature of Subversion called externals. Externals are metadata on a directory that basically tell the svn client to checkout some other url into a subdirectory when it is checked out. So if I type:

	svn proplist -v svn+ssh://svn.gna.org/svn/gnustep/devmodules/core

It will tell me that the svn:externals property contains:

	gui     svn+ssh://svn.gna.org/svn/gnustep/libs/gui/trunk
	back    svn+ssh://svn.gna.org/svn/gnustep/libs/back/trunk
	base    svn+ssh://svn.gna.org/svn/gnustep/libs/base/trunk
	make    svn+ssh://svn.gna.org/svn/gnustep/tools/make/trunk

So everytime I checkout /devmodules/core the svn client will automatically go to these URLs and check them out into subdirectories. When I make changes in gui/ and commit them, it will really commit to /libs/gui/trunk. For the most part if you checkout /devmodules, the externals have already been setup such that it will checkout something similar to checking out the whole repository before.

[[edit][20]]

<>

## Tips, Tricks, and Resources

* [Version Control with Subversion][21]
* [Appendix A: Subversion for CVS Users][22]
* [GCC's SVN Setup page][23] - Look especially at the section on [ssh connection caching][24].
* [Subversion\_Migration][25] - Some initial notes on the layout of the repository.
* [ZSH svn tab completion][26] - On this page is a tab completion module that can tab complete into subversion repositories. Very handy for ZSH users.

 Retrieved from "[http://wiki.gnustep.org/index.php/Using\_Subversion][27]"

##### Views

* [Article][28]
* [Discussion][29]
* [Edit][30]
* [History][31]

##### Personal tools

* [Create an account or log in][32]

[][33]

##### users

* [Applications][34]
* [Guides][35]
* [FAQ][36]
* [Get Help][37]
* [Report Bugs][38]
* [Donations][39]
* [Screenshots][40]

##### developers

* [Guides][41]
* [FAQ][42]
* [Base API (Foundation)][43]
* [GUI API (AppKit)][44]
* [Frameworks][45]

##### Navigation

* [Main Page][46]
* [Community portal][47]
* [Current events][48]
* [Recent changes][49]
* [Random page][50]
* [Help][51]

##### Search

##### Toolbox

* [What links here][52]
* [Related changes][53]
* [Upload file][54]
* [Special pages][55]
* [Printable version][56]

[![MediaWiki][57]][58]

* This page was last modified 18:26, 8 June 2010.
* This page has been accessed 140,758 times.
* Content is available under [GNU General Public License][59].
* [About GNUstepWiki][60]
* [Disclaimers][61]

  [1]: /index.php?title=SVN&redirect=no "SVN"
  [2]: #Anonymous_GNUstep_SVN_Checkout
  [3]: #Developer_GNUstep_SVN_Checkout
  [4]: #Setting_up_Subversion_for_Developer_Use
  [5]: #If_you_have_a_different_username_on_your_system_than_on_svn.gna.org
  [6]: #If_you_are_prompted_for_a_private_key_password
  [7]: #Subversion_on_Windows
  [8]: #Some_background_on_repository_layout
  [9]: #Tips.2C_Tricks.2C_and_Resources
  [10]: /index.php?title=Using_Subversion&action=edit&section=1 "Using Subversion"
  [11]: /index.php?title=Using_Subversion&action=edit&section=2 "Using Subversion"
  [12]: /index.php?title=Using_Subversion&action=edit&section=3 "Using Subversion"
  [13]: /index.php?title=Using_Subversion&action=edit&section=4 "Using Subversion"
  [14]: /index.php?title=Using_Subversion&action=edit&section=5 "Using Subversion"
  [15]: /index.php?title=Using_Subversion&action=edit&section=6 "Using Subversion"
  [16]: http://tortoisesvn.tigris.org/ "http://tortoisesvn.tigris.org/"
  [17]: http://www.chiark.greenend.org.uk/~sgtatham/putty/download.html "http://www.chiark.greenend.org.uk/~sgtatham/putty/download.html"
  [18]: /index.php?title=Using_Subversion&action=edit&section=7 "Using Subversion"
  [19]: http://svn.gna.org/viewcvs/gnustep/ "http://svn.gna.org/viewcvs/gnustep/"
  [20]: /index.php?title=Using_Subversion&action=edit&section=8 "Using Subversion"
  [21]: http://svnbook.red-bean.com "http://svnbook.red-bean.com"
  [22]: http://svnbook.red-bean.com/en/1.1/apa.html "http://svnbook.red-bean.com/en/1.1/apa.html"
  [23]: http://gcc.gnu.org/wiki/SvnSetup "http://gcc.gnu.org/wiki/SvnSetup"
  [24]: http://gcc.gnu.org/wiki/SSH%20connection%20caching "http://gcc.gnu.org/wiki/SSH connection caching"
  [25]: /index.php/Subversion_Migration "Subversion Migration"
  [26]: http://www.aeruder.net/software/misc/softwarelist.html "http://www.aeruder.net/software/misc/softwarelist.html"
  [27]: http://wiki.gnustep.org/index.php/Using_Subversion
  [28]: /index.php/Using_Subversion
  [29]: /index.php?title=Talk:Using_Subversion&action=edit
  [30]: /index.php?title=Using_Subversion&action=edit
  [31]: /index.php?title=Using_Subversion&action=history
  [32]: /index.php?title=Special:Userlogin&returnto=Using_Subversion
  [33]: /index.php/Main_Page "Main Page"
  [34]: /index.php/Category:Applications
  [35]: /index.php/User_Guides
  [36]: /index.php/User_FAQ
  [37]: /index.php/Get_Help
  [38]: /index.php/Report_Bugs
  [39]: /index.php/GNUstepWiki:Site_support
  [40]: /index.php/Screenshots
  [41]: /index.php/Developer_Guides
  [42]: /index.php/Developer_FAQ
  [43]: /index.php/Foundation
  [44]: /index.php/AppKit
  [45]: /index.php/Category:Frameworks
  [46]: /index.php/Main_Page
  [47]: /index.php/GNUstepWiki:Community_Portal
  [48]: /index.php/Current_events
  [49]: /index.php/Special:Recentchanges
  [50]: /index.php/Special:Random
  [51]: /index.php/Help:Contents
  [52]: /index.php/Special:Whatlinkshere/Using_Subversion
  [53]: /index.php/Special:Recentchangeslinked/Using_Subversion
  [54]: /index.php/Special:Upload
  [55]: /index.php/Special:Specialpages
  [56]: /index.php?title=Using_Subversion&printable=yes&printable=yes
  [57]: /skins/common/images/poweredby_mediawiki_88x31.png
  [58]: http://www.mediawiki.org/
  [59]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [60]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [61]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"