<>

# Script objects

### From GNUstepWiki	{#siteSub}

Script object looks like ordinary object. However, it's behaviour is described by small scripts - methods written in some scripting language.

They can be used for:

* Custom application objects
* Event and notiication handlers
* Objects in servers with customisable behaviour
* ...

_NOTE: See TODO list at the end of this page._

<br />

<table>
<tr>
<td>
## Contents
* [1 Using script objects][1]
* [2 Creating script objetcs][2]
  * [2\.1 Adding methods][3]
  * [2\.2 Methods with arguments][4]
  * [2\.3 Script object interface][5]
* [3 TODO][6]
</td>
</tr>
</table>

[[edit][7]]

<>

## Using script objects

Just send it a message as to any other object:

	[object sayHi];

[[edit][8]]

<>

## Creating script objetcs

	object = [STScriptObject scriptObject];
	[object setEnvironment:someScriptingEnvironment];

[[edit][9]]

<>

### Adding methods

Create a source:

	source = @"sayHi Transcript showLine: 'Hi.'. ^self".

or

	source = [NSString stringWithContentsOfFile:@"SomeFile"];

Get the the proper engine for a language used in the source:

	engine = [STEngine engineForLanguageWithName:@"Smalltalk"];

create a method:

	method = [engine methodFromSource:source
	                      forReceiver:object
	                    inEnvironment:Environment];

and finally add the method to the object:

	   [object addMethod:method];

[[edit][10]]

<>

### Methods with arguments

Well, no difference to any other methods. If you have source:

	source = @"sayHiTo:someone Transcript showLine: ('Hi ', someone). ^self";

you can do:

	[object sayHiTo:@"World"];

[[edit][11]]

<>

### Script object interface

Script object understands following:

* addMethod:aMethod
* removeMethod:aMethod
* removeMethodWithName:aString
* methodWithName:aString
* methodNames
* respondsToSelector:aSelector

[[edit][12]]

<>

## TODO

Here are unimplemented features of the Script Objects. Feel free to add them, if you have a bit of time. Please consult with the [author of StepTalk][13] and on the [gnustep lists][14].

* object variables (this is high priority)
* inheritance of variables and methods (traits like in Self?)
* object archiving
* object cloning (copying)

* integration with [scripting contexts][15]

* script object builder application (it should be something simple)

----

See also: [StepTalk][16], [Scripting][17]

 Retrieved from "[http://wiki.gnustep.org/index.php/Script\_objects][18]"

[Categories][19]: [Scripting][20]

##### Views

* [Article][21]
* [Discussion][22]
* [Edit][23]
* [History][24]

##### Personal tools

* [Create an account or log in][25]

[][26]

##### users

* [Applications][27]
* [Guides][28]
* [FAQ][29]
* [Get Help][30]
* [Report Bugs][31]
* [Donations][32]
* [Screenshots][33]

##### developers

* [Guides][34]
* [FAQ][35]
* [Base API (Foundation)][36]
* [GUI API (AppKit)][37]
* [Frameworks][38]

##### Navigation

* [Main Page][39]
* [Community portal][40]
* [Current events][41]
* [Recent changes][42]
* [Random page][43]
* [Help][44]

##### Search

##### Toolbox

* [What links here][45]
* [Related changes][46]
* [Upload file][47]
* [Special pages][48]
* [Printable version][49]

[![MediaWiki][50]][51]

* This page was last modified 12:26, 18 February 2005.
* This page has been accessed 8,022 times.
* Content is available under [GNU General Public License][52].
* [About GNUstepWiki][53]
* [Disclaimers][54]

  [1]: #Using_script_objects
  [2]: #Creating_script_objetcs
  [3]: #Adding_methods
  [4]: #Methods_with_arguments
  [5]: #Script_object_interface
  [6]: #TODO
  [7]: /index.php?title=Script_objects&action=edit&section=1 "Script objects"
  [8]: /index.php?title=Script_objects&action=edit&section=2 "Script objects"
  [9]: /index.php?title=Script_objects&action=edit&section=3 "Script objects"
  [10]: /index.php?title=Script_objects&action=edit&section=4 "Script objects"
  [11]: /index.php?title=Script_objects&action=edit&section=5 "Script objects"
  [12]: /index.php?title=Script_objects&action=edit&section=6 "Script objects"
  [13]: /index.php/User:Stefan_Urbanek "User:Stefan Urbanek"
  [14]: /index.php/Contact "Contact"
  [15]: /index.php/Scripting_context "Scripting context"
  [16]: /index.php/StepTalk "StepTalk"
  [17]: /index.php/Scripting "Scripting"
  [18]: http://wiki.gnustep.org/index.php/Script_objects
  [19]: /index.php?title=Special:Categories&article=Script_objects "Special:Categories"
  [20]: /index.php/Category:Scripting "Category:Scripting"
  [21]: /index.php/Script_objects
  [22]: /index.php?title=Talk:Script_objects&action=edit
  [23]: /index.php?title=Script_objects&action=edit
  [24]: /index.php?title=Script_objects&action=history
  [25]: /index.php?title=Special:Userlogin&returnto=Script_objects
  [26]: /index.php/Main_Page "Main Page"
  [27]: /index.php/Category:Applications
  [28]: /index.php/User_Guides
  [29]: /index.php/User_FAQ
  [30]: /index.php/Get_Help
  [31]: /index.php/Report_Bugs
  [32]: /index.php/GNUstepWiki:Site_support
  [33]: /index.php/Screenshots
  [34]: /index.php/Developer_Guides
  [35]: /index.php/Developer_FAQ
  [36]: /index.php/Foundation
  [37]: /index.php/AppKit
  [38]: /index.php/Category:Frameworks
  [39]: /index.php/Main_Page
  [40]: /index.php/GNUstepWiki:Community_Portal
  [41]: /index.php/Current_events
  [42]: /index.php/Special:Recentchanges
  [43]: /index.php/Special:Random
  [44]: /index.php/Help:Contents
  [45]: /index.php/Special:Whatlinkshere/Script_objects
  [46]: /index.php/Special:Recentchangeslinked/Script_objects
  [47]: /index.php/Special:Upload
  [48]: /index.php/Special:Specialpages
  [49]: /index.php?title=Script_objects&printable=yes&printable=yes
  [50]: /skins/common/images/poweredby_mediawiki_88x31.png
  [51]: http://www.mediawiki.org/
  [52]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [53]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [54]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"