<>

# Scripting language bundle

### From GNUstepWiki	{#siteSub}

Scripting language bundle is, well, a bundle that offers a language for [StepTalk][1]. The bundle provides mechanisms for understanding the language and interpreting it.

Core of a language bundle is a scripting engine. Each language should have its own engine that executes scripts. The engine should take into account a context, where the script will be executed, and the script itself. After the execution, the engine should provide some feedback, for example a result object or it should throw an exception when something went wrong.

Few steps for creating a custom language bundle:

1. take a language template from StepTalk sources or create one of your own
2. create your own language engine as a subclass of the [STEngine][2]
3. implement method _executeCode:inEnvironment:_
4. provide an information list about the bundle

<table>
<tr>
<td>
## Contents
* [1 Language Template][3]
* [2 Implementation][4]
* [3 Proposed Changes][5]
  * [3\.1 STLanguageManager][6]
</td>
</tr>
</table>

[[edit][7]]

<>

### Language Template

Template for a language bundle can be found [here][8].

[[edit][9]]

<>

### Implementation

Header file for a custom language should look like this:

	#import &lt;StepTalk/STEngine.h&gt;

	@interface MyLanguageEngine:STEngine
	{
	    /* ... */
	}
	@end

And the implementation:

	#import "MyLanguageEngine.h"

	@implementation MyLanguageEngine
	- (id)  executeCode:(NSString *)sourceCode
	      inEnvironment:(STEnvironment *)env
	{
	    id retval = nil;

	    /* execute the code sourceCode using environment env */

	    /* retval = return value from the interpreter; */
	    return retval;
	}
	@end

You may want to use _[environment objectDictionary]_ to get all environment's named objects.

To translate a selector (for example a symbolic selector) you can use _[environment translateSelector:aString forReceiver:anObject]_ which returns a [NSString][10] containing translated selector or nil if the selector should not be sent (because it should be fobidden by the environment). Moreover you should use this method if you want to use restrictions of selectors of the scripting envornment. See [STEnvironment][11] and [STEnvironmentDescription][12] for more information.

If your language can execute scripts from files, you may specify the file type in the MyLanguageInfo.plist. Then script manager and [StepTalk][13] tools can execute files with an appropriate language engine.

	{
	    /* Array of file types of your language scripts */
	    STFileTypes = ( "mylang" );
	}

[[edit][14]]

<>

## Proposed Changes

	- (id)  executeCode:(NSString *)sourceCode
	      inEnvironment:(STEnvironment *)env

is going to be renamed to

	- (id)interpretScript:(NSString *)sourceCode
	            inContext:(STContext *)context

[[edit][15]]

<>

### STLanguageManager

New class is going to be added: **STLanguageManager**

	+ defaultManager
	- registerLanguage:engineClassName:info:
	- registerLanguagesFromBundle:
	- availableLanguages
	- removeLanguage:

	- createEngineForLanguage:
	- engineClassForLanguage:

	- infoForLanguage:
	- bundleForLanguage:
	- languageForFileType:

Class STLanguage is going to be removed as well as language related methods from STEngine.

 Retrieved from "[http://wiki.gnustep.org/index.php/Scripting\_language\_bundle][16]"

[Categories][17]: [Scripting][18]

##### Views

* [Article][19]
* [Discussion][20]
* [Edit][21]
* [History][22]

##### Personal tools

* [Create an account or log in][23]

[][24]

##### users

* [Applications][25]
* [Guides][26]
* [FAQ][27]
* [Get Help][28]
* [Report Bugs][29]
* [Donations][30]
* [Screenshots][31]

##### developers

* [Guides][32]
* [FAQ][33]
* [Base API (Foundation)][34]
* [GUI API (AppKit)][35]
* [Frameworks][36]

##### Navigation

* [Main Page][37]
* [Community portal][38]
* [Current events][39]
* [Recent changes][40]
* [Random page][41]
* [Help][42]

##### Search

##### Toolbox

* [What links here][43]
* [Related changes][44]
* [Upload file][45]
* [Special pages][46]
* [Printable version][47]

[![MediaWiki][48]][49]

* This page was last modified 14:25, 30 August 2005.
* This page has been accessed 17,495 times.
* Content is available under [GNU General Public License][50].
* [About GNUstepWiki][51]
* [Disclaimers][52]

  [1]: /index.php/StepTalk "StepTalk"
  [2]: /index.php?title=STEngine&action=edit "STEngine"
  [3]: #Language_Template
  [4]: #Implementation
  [5]: #Proposed_Changes
  [6]: #STLanguageManager
  [7]: /index.php?title=Scripting_language_bundle&action=edit&section=1 "Scripting language bundle"
  [8]: http://stefan.agentfarms.net/Download/GNUstep/MyLanguage-20041021.tar.gz "http://stefan.agentfarms.net/Download/GNUstep/MyLanguage-20041021.tar.gz"
  [9]: /index.php?title=Scripting_language_bundle&action=edit&section=2 "Scripting language bundle"
  [10]: /index.php/NSString "NSString"
  [11]: /index.php?title=STEnvironment&action=edit "STEnvironment"
  [12]: /index.php?title=STEnvironmentDescription&action=edit "STEnvironmentDescription"
  [13]: /index.php/StepTalk "StepTalk"
  [14]: /index.php?title=Scripting_language_bundle&action=edit&section=3 "Scripting language bundle"
  [15]: /index.php?title=Scripting_language_bundle&action=edit&section=4 "Scripting language bundle"
  [16]: http://wiki.gnustep.org/index.php/Scripting_language_bundle
  [17]: /index.php?title=Special:Categories&article=Scripting_language_bundle "Special:Categories"
  [18]: /index.php/Category:Scripting "Category:Scripting"
  [19]: /index.php/Scripting_language_bundle
  [20]: /index.php?title=Talk:Scripting_language_bundle&action=edit
  [21]: /index.php?title=Scripting_language_bundle&action=edit
  [22]: /index.php?title=Scripting_language_bundle&action=history
  [23]: /index.php?title=Special:Userlogin&returnto=Scripting_language_bundle
  [24]: /index.php/Main_Page "Main Page"
  [25]: /index.php/Category:Applications
  [26]: /index.php/User_Guides
  [27]: /index.php/User_FAQ
  [28]: /index.php/Get_Help
  [29]: /index.php/Report_Bugs
  [30]: /index.php/GNUstepWiki:Site_support
  [31]: /index.php/Screenshots
  [32]: /index.php/Developer_Guides
  [33]: /index.php/Developer_FAQ
  [34]: /index.php/Foundation
  [35]: /index.php/AppKit
  [36]: /index.php/Category:Frameworks
  [37]: /index.php/Main_Page
  [38]: /index.php/GNUstepWiki:Community_Portal
  [39]: /index.php/Current_events
  [40]: /index.php/Special:Recentchanges
  [41]: /index.php/Special:Random
  [42]: /index.php/Help:Contents
  [43]: /index.php/Special:Whatlinkshere/Scripting_language_bundle
  [44]: /index.php/Special:Recentchangeslinked/Scripting_language_bundle
  [45]: /index.php/Special:Upload
  [46]: /index.php/Special:Specialpages
  [47]: /index.php?title=Scripting_language_bundle&printable=yes&printable=yes
  [48]: /skins/common/images/poweredby_mediawiki_88x31.png
  [49]: http://www.mediawiki.org/
  [50]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [51]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [52]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"