<>

# Scripting of frameworks

### From GNUstepWiki	{#siteSub}

This article describes how to advertise and use scripting capabilities of a frameworks or a bundle.

<table>
<tr>
<td>
## Contents
* [1 Introduction][1]
* [2 Usage][2]
  * [2\.1 Frameworks][3]
  * [2\.2 StepTalk Bundles (or Modules)][4]
  * [2\.3 Generic Bundles][5]
* [3 Advertisment][6]
  * [3\.1 Named Objects][7]
  * [3\.2 Public classes][8]
</td>
</tr>
</table>

[[edit][9]]

<>

## Introduction

Any bundle, including an application or a framework can provide information about scripting. Bundles can advertise:

* classes
* named objects

Frameworks and other bundles do not have to be linked with [StepTalk][10], therefore they **do not have to have StepTalk dependency**. You just include a file named _ScriptingInfo.plist_ in the framework's or bundle's [Resources][11] directory.

[[edit][12]]

<>

## Usage

To include a framework in a script, simply do following:

	Environment includeFramework:'MyFrameworkName'.

[[edit][13]]

<>

### Frameworks

You can use GNUstep Frameworks from StepTalk scripts. Frameworks are stored in standard paths \*/Library/Frameworks. To get a list of all available frameworks:

	 NSBundle allFrameworkNames.

To load a framework with its public classes:

	 Environment includeFramework:'MyFramework'

[[edit][14]]

<>

### StepTalk Bundles (or Modules)

StepTalk bundles are stored in \*/Library/StepTalk/Modules and can be loaded this way:

	Environment loadModule:'moduleName'.

For example, to load the AppKit module:

	Environment loadModule:'AppKit'

To get list of all available StepTalk bundle names use:

	namesÃÂ := NSBundle stepTalkBundleNames

[[edit][15]]

<>

### Generic Bundles

To use scripting capabilities from any bundle, you have to find the bundle and include its capabilities in a scripting environment.

	bundleÃÂ := NSBundle bundleWithPath:'/path/to/my/bundle'.
	Environment includeBundle:bundle.

This will register all public classes and named objects provided by the bundle.

To include scripting capabilities of all loaded bundles, do:

	(NSBundle allBundles) do: [ÃÂ :bundle | Environment includeBundle:bundle ]

To include scripting capabilities of all loaded frameworks, do:

	(NSBundle allFrameworks) do: [ÃÂ :bundle | Environment includeBundle:bundle ]

_Note: Ignore the logs._

[[edit][16]]

<>

## Advertisment

List public classes in bundle's info dictionary _(Info.plist)_

	Classes = ( /* Array of public classes */ );

[[edit][17]]

<>

### Named Objects

Bundles can provide objects like global variables or constants. To make objects available, create a _script info class_ and provide it's name in bundle's info dictionary. Return a dictionary of named objects in specific class method.

Interface:

	@interface MyBundleScriptingInfo:NSObject
	+ (NSDictionary *)namedObjectsForScripting;
	@end

Implementation:

	@implementationÃÂ !MyBundleScriptingInfo
	+ (NSDictionary *)namedObjectsForScripting
	{
	    NSMutableDictionary *dictionary;

	    /* ... fill the dictionary with objects ...*/

	    return [[NSDictionary dictionaryWithDictionary:dictionary]; /* Return an immutable copy */
	}
	@end

[[edit][18]]

<>

### Public classes

Then provide the class name in the file _MyBundleInfo.plist_:

	ScriptingInfoClass = MyBundleScriptingInfo;

Example info dictionary:

	{
	    ScriptingInfoClass = ObjectiveCModule;
	    Classes = (
	        ObjectiveCRuntime
	    );
	}

 Retrieved from "[http://wiki.gnustep.org/index.php/Scripting\_of\_frameworks][19]"

[Categories][20]: [Scripting][21]

##### Views

* [Article][22]
* [Discussion][23]
* [Edit][24]
* [History][25]

##### Personal tools

* [Create an account or log in][26]

[][27]

##### users

* [Applications][28]
* [Guides][29]
* [FAQ][30]
* [Get Help][31]
* [Report Bugs][32]
* [Donations][33]
* [Screenshots][34]

##### developers

* [Guides][35]
* [FAQ][36]
* [Base API (Foundation)][37]
* [GUI API (AppKit)][38]
* [Frameworks][39]

##### Navigation

* [Main Page][40]
* [Community portal][41]
* [Current events][42]
* [Recent changes][43]
* [Random page][44]
* [Help][45]

##### Search

##### Toolbox

* [What links here][46]
* [Related changes][47]
* [Upload file][48]
* [Special pages][49]
* [Printable version][50]

[![MediaWiki][51]][52]

* This page was last modified 14:58, 31 August 2005.
* This page has been accessed 15,226 times.
* Content is available under [GNU General Public License][53].
* [About GNUstepWiki][54]
* [Disclaimers][55]

  [1]: #Introduction
  [2]: #Usage
  [3]: #Frameworks
  [4]: #StepTalk_Bundles_.28or_Modules.29
  [5]: #Generic_Bundles
  [6]: #Advertisment
  [7]: #Named_Objects
  [8]: #Public_classes
  [9]: /index.php?title=Scripting_of_frameworks&action=edit&section=1 "Scripting of frameworks"
  [10]: /index.php/StepTalk "StepTalk"
  [11]: /index.php?title=Bundle_resources&action=edit "Bundle resources"
  [12]: /index.php?title=Scripting_of_frameworks&action=edit&section=2 "Scripting of frameworks"
  [13]: /index.php?title=Scripting_of_frameworks&action=edit&section=3 "Scripting of frameworks"
  [14]: /index.php?title=Scripting_of_frameworks&action=edit&section=4 "Scripting of frameworks"
  [15]: /index.php?title=Scripting_of_frameworks&action=edit&section=5 "Scripting of frameworks"
  [16]: /index.php?title=Scripting_of_frameworks&action=edit&section=6 "Scripting of frameworks"
  [17]: /index.php?title=Scripting_of_frameworks&action=edit&section=7 "Scripting of frameworks"
  [18]: /index.php?title=Scripting_of_frameworks&action=edit&section=8 "Scripting of frameworks"
  [19]: http://wiki.gnustep.org/index.php/Scripting_of_frameworks
  [20]: /index.php?title=Special:Categories&article=Scripting_of_frameworks "Special:Categories"
  [21]: /index.php/Category:Scripting "Category:Scripting"
  [22]: /index.php/Scripting_of_frameworks
  [23]: /index.php/Talk:Scripting_of_frameworks
  [24]: /index.php?title=Scripting_of_frameworks&action=edit
  [25]: /index.php?title=Scripting_of_frameworks&action=history
  [26]: /index.php?title=Special:Userlogin&returnto=Scripting_of_frameworks
  [27]: /index.php/Main_Page "Main Page"
  [28]: /index.php/Category:Applications
  [29]: /index.php/User_Guides
  [30]: /index.php/User_FAQ
  [31]: /index.php/Get_Help
  [32]: /index.php/Report_Bugs
  [33]: /index.php/GNUstepWiki:Site_support
  [34]: /index.php/Screenshots
  [35]: /index.php/Developer_Guides
  [36]: /index.php/Developer_FAQ
  [37]: /index.php/Foundation
  [38]: /index.php/AppKit
  [39]: /index.php/Category:Frameworks
  [40]: /index.php/Main_Page
  [41]: /index.php/GNUstepWiki:Community_Portal
  [42]: /index.php/Current_events
  [43]: /index.php/Special:Recentchanges
  [44]: /index.php/Special:Random
  [45]: /index.php/Help:Contents
  [46]: /index.php/Special:Whatlinkshere/Scripting_of_frameworks
  [47]: /index.php/Special:Recentchangeslinked/Scripting_of_frameworks
  [48]: /index.php/Special:Upload
  [49]: /index.php/Special:Specialpages
  [50]: /index.php?title=Scripting_of_frameworks&printable=yes&printable=yes
  [51]: /skins/common/images/poweredby_mediawiki_88x31.png
  [52]: http://www.mediawiki.org/
  [53]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [54]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [55]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"