<>

# Scripting support

### From GNUstepWiki	{#siteSub}

<table>
<tr>
<td>
## Contents
* [1 Introduction][1]
  * [1\.1 Objects to be used for scripting][2]
  * [1\.2 Scripting context or environment][3]
* [2 Creating scripting environment][4]
* [3 Executing a script][5]
* [4 Automated scripting in applications][6]
  * [4\.1 Creating a scriptable application][7]
  * [4\.2 The scripts][8]
</td>
</tr>
</table>

[[edit][9]]

<>

## Introduction

_Note: if something is not clear, add questions under the discussion tab or ask [the author][10] directly._

To make a tool or an application scriptable you need to prepare:

* objects for scripting
* scripting context
* mechanism for script execution

For applications, there are two possibilities, to make them scriptable. One is custom, that means, that you have to create scripting mechanisms by yourself. The other is automatic, where the developer only needs to add few lines of code and several menu items to his application.

In brief, to add scripting you have to do:

1. set-up and provide a scripting context/environment ([STContect][11] or [STEnvironment][12])
2. prepare a conversation with the environment ([STConversation][13])
3. use the conversation to execute a script in a scripting language

[[edit][14]]

<>

### Objects to be used for scripting

What do you offer to users? What should users customise? What should users talk to? As scripting deals with objects, you need to think about the objects you would like to make available to the user.

It is up to developer to prepare a list of object names and ways of getting the objects.

[[edit][15]]

<>

### Scripting context or environment

Like on our speech, we use references to object without any closer specification. How we do know what objects wer are refering to? From the conversation context. It is similar in the scripting language.

A simple context contains a map (or a dictionary, if you like), of object names and actual objects. Related classes: [STContext][16] or [STEnvironment][17].

[[edit][18]]

<>

## Creating scripting environment

To prepare a scripting environment.

	#import &lt;StepTalk/STEnvironment.h&gt;

	STEnvironment *environment;

	environment = [STEnvironment environmentWithDefaultDescription]

or

	description = [STEnvironmentDescription descriptionWithName:name]
	environment = [STEnvironment environmentWithDescription:description];

Environment serves besides other things also like namespace for objects and you have to register all objects that you would like to have accesible by name:

	[environment setObject:object forName:@"ObjectName"];

like in:

	[environment setObject:MyApplication forName:@"Application"];

<br />

[[edit][19]]

<>

## Executing a script

One way to execute scripts is by using a 'conversation' objects. Conversations are made in a environment and using specified language. The language may change during scripting conversation.

	#import &lt;StepTalk/STConversation.h&gt;

	conversation = [STConversation conversationWithEnvironment: environment language: @"Smalltalk"];

To get names of all available languages:

	STLanguageManager *languageManager;
	NSArray *languages;
	NSString *defaultLanguage;

	languageManager = [STLanguageManager defaultManager];

	languages = [languageManager availableLanguages];
	defaultLanguage = [languageManager defaultLanguage];

<br />
 Now when you have opened a conversation in an environment you can run the script string. It is better to guard the execution with an exception handler:

<br />

	id        result;

	NS_DURING
	   [conversation interpretScript:string];
	   result = [conversation result];
	NS_HANDLER
	   /* handle an exception */
	NS_ENDHANDLER

<br />
_Note: the result handling will change in future StepTalk releases. The result will be no longer be returned by the direct execution message, but instead will need to be requested separately. There are several reasons for this change, including better handling of remote scripting environments (long distance conversations)._

To change a language of script conversation, just use:

	 [conversation setLanguage:@"ObjectiveC"]

[[edit][20]]

<>

## Automated scripting in applications

StepTalk provideas a bundle that allows users to 'script' their applications automatically. With this bundle, it instantly allows users of the application to:

* extend the behaviour of application by adding their own functionality
* automate tasks in the application
* create a batch task

The Application Scripting bundle is installed together with StepTalk. _Note: the bundle needs a refresh, as it is quite out-dated._

[[edit][21]]

<>

### Creating a scriptable application

As usual, first think of objects you want to provide for scripting. Then create _ScriptingInfo.plist_ file as described above. For example a file for a Mail application would be:

	{
	    STClasses =
	    (
	        MessageComposition,
	        InternetAddress
	    );
	}

Use the [Project Center][22] application to include the file or put this line to your makefile:

	MyApp_RESOURCE_FILES = ScriptingInfo.plist

Then include the bundle loading code. Copy files _STScriptingSupport.h_ and _STScriptingSupport.m_ from **ApplicationScripting/Support** directory to your project and add them to your project or add the following line to your makefile:

	   MyApp_OBJC_FILES += STScriptingSupport.m

Funally, make scripting available to the user:

	   #import "STScriptingSupport.h"
	   ...
	       if([NSApp isScriptingSupported])
	       {
	           [menu addItemWithTitle: @"Scripting"
	                           action: NULL
	                    keyEquivalent: @""];

	           [menu setSubmenu: [NSApp scriptingMenu]
	                    forItem: [menu itemWithTitle:@"Scripting"]];
	       }
	   ...

_FIXME: what is needed to do that with [Gorm][23] in a simple way?_

[[edit][24]]

<>

### The scripts

See: [Script management][25]

 Retrieved from "[http://wiki.gnustep.org/index.php/Scripting\_support][26]"

[Categories][27]: [Scripting][28]

##### Views

* [Article][29]
* [Discussion][30]
* [Edit][31]
* [History][32]

##### Personal tools

* [Create an account or log in][33]

[][34]

##### users

* [Applications][35]
* [Guides][36]
* [FAQ][37]
* [Get Help][38]
* [Report Bugs][39]
* [Donations][40]
* [Screenshots][41]

##### developers

* [Guides][42]
* [FAQ][43]
* [Base API (Foundation)][44]
* [GUI API (AppKit)][45]
* [Frameworks][46]

##### Navigation

* [Main Page][47]
* [Community portal][48]
* [Current events][49]
* [Recent changes][50]
* [Random page][51]
* [Help][52]

##### Search

##### Toolbox

* [What links here][53]
* [Related changes][54]
* [Upload file][55]
* [Special pages][56]
* [Printable version][57]

[![MediaWiki][58]][59]

* This page was last modified 11:36, 17 September 2005.
* This page has been accessed 26,604 times.
* Content is available under [GNU General Public License][60].
* [About GNUstepWiki][61]
* [Disclaimers][62]

  [1]: #Introduction
  [2]: #Objects_to_be_used_for_scripting
  [3]: #Scripting_context_or_environment
  [4]: #Creating_scripting_environment
  [5]: #Executing_a_script
  [6]: #Automated_scripting_in_applications
  [7]: #Creating_a_scriptable_application
  [8]: #The_scripts
  [9]: /index.php?title=Scripting_support&action=edit&section=1 "Scripting support"
  [10]: /index.php/User:Stefan_Urbanek "User:Stefan Urbanek"
  [11]: /index.php?title=STContect&action=edit "STContect"
  [12]: /index.php?title=STEnvironment&action=edit "STEnvironment"
  [13]: /index.php?title=STConversation&action=edit "STConversation"
  [14]: /index.php?title=Scripting_support&action=edit&section=2 "Scripting support"
  [15]: /index.php?title=Scripting_support&action=edit&section=3 "Scripting support"
  [16]: /index.php?title=STContext&action=edit "STContext"
  [17]: /index.php?title=STEnvironment&action=edit "STEnvironment"
  [18]: /index.php?title=Scripting_support&action=edit&section=4 "Scripting support"
  [19]: /index.php?title=Scripting_support&action=edit&section=5 "Scripting support"
  [20]: /index.php?title=Scripting_support&action=edit&section=6 "Scripting support"
  [21]: /index.php?title=Scripting_support&action=edit&section=7 "Scripting support"
  [22]: /index.php?title=Project_Center&action=edit "Project Center"
  [23]: /index.php/Gorm "Gorm"
  [24]: /index.php?title=Scripting_support&action=edit&section=8 "Scripting support"
  [25]: /index.php/Script_management "Script management"
  [26]: http://wiki.gnustep.org/index.php/Scripting_support
  [27]: /index.php?title=Special:Categories&article=Scripting_support "Special:Categories"
  [28]: /index.php/Category:Scripting "Category:Scripting"
  [29]: /index.php/Scripting_support
  [30]: /index.php/Talk:Scripting_support
  [31]: /index.php?title=Scripting_support&action=edit
  [32]: /index.php?title=Scripting_support&action=history
  [33]: /index.php?title=Special:Userlogin&returnto=Scripting_support
  [34]: /index.php/Main_Page "Main Page"
  [35]: /index.php/Category:Applications
  [36]: /index.php/User_Guides
  [37]: /index.php/User_FAQ
  [38]: /index.php/Get_Help
  [39]: /index.php/Report_Bugs
  [40]: /index.php/GNUstepWiki:Site_support
  [41]: /index.php/Screenshots
  [42]: /index.php/Developer_Guides
  [43]: /index.php/Developer_FAQ
  [44]: /index.php/Foundation
  [45]: /index.php/AppKit
  [46]: /index.php/Category:Frameworks
  [47]: /index.php/Main_Page
  [48]: /index.php/GNUstepWiki:Community_Portal
  [49]: /index.php/Current_events
  [50]: /index.php/Special:Recentchanges
  [51]: /index.php/Special:Random
  [52]: /index.php/Help:Contents
  [53]: /index.php/Special:Whatlinkshere/Scripting_support
  [54]: /index.php/Special:Recentchangeslinked/Scripting_support
  [55]: /index.php/Special:Upload
  [56]: /index.php/Special:Specialpages
  [57]: /index.php?title=Scripting_support&printable=yes&printable=yes
  [58]: /skins/common/images/poweredby_mediawiki_88x31.png
  [59]: http://www.mediawiki.org/
  [60]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [61]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [62]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"