<>

# Scripting

### From GNUstepWiki	{#siteSub}

Scripting is a process for task automation, functionality enhancing, fast prototyping, batch processing, etc. The process is done by a scripting language interpreter.

<table>
<tr>
<td>
## Contents
* [1 Introduction][1]
* [2 Ways of scripting][2]
* [3 Languages][3]
* [4 References][4]
* [5 Future][5]
</td>
</tr>
</table>

[[edit][6]]

<>

## Introduction

There are situations, where you would like to:

* quickly create a handy program
* do some computation with numbers or objects
* process some objects with one or more applications in a batch
* use functionality of some framework without an application
* test your program
* ...

Those are situations where you can do scripting. Well, what the scripting is? It can be thought as manipulating objects in a handy way without need of long development process. The GNUstep environment offers more possibilities for scripting:

* [StepTalk][7] - official GNUstep, language independent, scripting framework with [Smalltalk][8] as the default scripting language.
* [GNUstep Guile][9] - GNUstep extension to make use of the [GUILE][10] scripting language.

Following sections describes StepTalk scripting capabilites. For more information, you can also consult articles in the [scripting category][11].

[[edit][12]]

<>

## Ways of scripting

How would you like to do that? Interactively, in a batch, from an application, from automaticaly generated script or from a database? There are many ways how you can do the scripting.

**Shell** - a handy tool for interactive scripting with GNUstep objects. StepTalk offers a tool named _stshell ([StepTalk tools][13])_.

**Stand-alone script execution** - The tool **stexec ([StepTalk tools][14])** allows you to execute scripts stored in files. Just use:

	&gt; stexec myscript.st

**Applications** can have built-in scripting capabilities. To access them, just find the _Scripting_ menu item, which opens standard application scripting panel with all application related scripts. For more information, read the [Application scripting][15].

**Any tool** can create a scripting interface for users, where users can do customisation of the tool's behaviour. If you are interested in adding scripting extension to your tool, follow: [Scripting support][16].

[[edit][17]]

<>

## Languages

It is language independent - it uses languages as separate bundles. It can be extended by the "language bundles" providing other scripting languages. One experimental language bundle for Guile is included in the sources package.

See: [Scripting language bundle][18]

[[edit][19]]

<>

## References

**For developers (mainly)**

* [Scripting of frameworks][20] - how to make your framework or bundle scriptable
* [Scripting support][21] - how to make your product scriptable
* [Language bundle][22] - how to add a new language
* [Script management][23]

**For users (mainly)**

* [Scripting context][24] - what object do you know in scripts? what you should do with them?
* [Script objects][25] - how to build objects with script-defined behaviour

* [Category:Scripting][26] - everything about scripting in GNUstep

[[edit][27]]

<>

## Future

See: [Scripting ideas][28]

 Retrieved from "<http://wiki.gnustep.org/index.php/Scripting>"

[Categories][29]: [Scripting][30]

##### Views

* [Article][31]
* [Discussion][32]
* [Edit][33]
* [History][34]

##### Personal tools

* [Create an account or log in][35]

[][36]

##### users

* [Applications][37]
* [Guides][38]
* [FAQ][39]
* [Get Help][40]
* [Report Bugs][41]
* [Donations][42]
* [Screenshots][43]

##### developers

* [Guides][44]
* [FAQ][45]
* [Base API (Foundation)][46]
* [GUI API (AppKit)][47]
* [Frameworks][48]

##### Navigation

* [Main Page][49]
* [Community portal][50]
* [Current events][51]
* [Recent changes][52]
* [Random page][53]
* [Help][54]

##### Search

##### Toolbox

* [What links here][55]
* [Related changes][56]
* [Upload file][57]
* [Special pages][58]
* [Printable version][59]

[![MediaWiki][60]][61]

* This page was last modified 19:43, 20 February 2005.
* This page has been accessed 37,620 times.
* Content is available under [GNU General Public License][62].
* [About GNUstepWiki][63]
* [Disclaimers][64]

  [1]: #Introduction
  [2]: #Ways_of_scripting
  [3]: #Languages
  [4]: #References
  [5]: #Future
  [6]: /index.php?title=Scripting&action=edit&section=1 "Scripting"
  [7]: /index.php/StepTalk "StepTalk"
  [8]: /index.php/Smalltalk "Smalltalk"
  [9]: /index.php?title=GNUstep_Guile&action=edit "GNUstep Guile"
  [10]: /index.php?title=GUILE&action=edit "GUILE"
  [11]: /index.php/Category:Scripting "Category:Scripting"
  [12]: /index.php?title=Scripting&action=edit&section=2 "Scripting"
  [13]: /index.php/StepTalk_tools "StepTalk tools"
  [14]: /index.php/StepTalk_tools "StepTalk tools"
  [15]: /index.php?title=Application_scripting&action=edit "Application scripting"
  [16]: /index.php/Scripting_support "Scripting support"
  [17]: /index.php?title=Scripting&action=edit&section=3 "Scripting"
  [18]: /index.php/Scripting_language_bundle "Scripting language bundle"
  [19]: /index.php?title=Scripting&action=edit&section=4 "Scripting"
  [20]: /index.php/Scripting_of_frameworks "Scripting of frameworks"
  [21]: /index.php/Scripting_support "Scripting support"
  [22]: /index.php/Scripting_language_bundle "Scripting language bundle"
  [23]: /index.php/Script_management "Script management"
  [24]: /index.php/Scripting_context "Scripting context"
  [25]: /index.php/Script_objects "Script objects"
  [26]: /index.php/Category:Scripting "Category:Scripting"
  [27]: /index.php?title=Scripting&action=edit&section=5 "Scripting"
  [28]: /index.php/Scripting_ideas "Scripting ideas"
  [29]: /index.php?title=Special:Categories&article=Scripting "Special:Categories"
  [30]: /index.php/Category:Scripting "Category:Scripting"
  [31]: /index.php/Scripting
  [32]: /index.php?title=Talk:Scripting&action=edit
  [33]: /index.php?title=Scripting&action=edit
  [34]: /index.php?title=Scripting&action=history
  [35]: /index.php?title=Special:Userlogin&returnto=Scripting
  [36]: /index.php/Main_Page "Main Page"
  [37]: /index.php/Category:Applications
  [38]: /index.php/User_Guides
  [39]: /index.php/User_FAQ
  [40]: /index.php/Get_Help
  [41]: /index.php/Report_Bugs
  [42]: /index.php/GNUstepWiki:Site_support
  [43]: /index.php/Screenshots
  [44]: /index.php/Developer_Guides
  [45]: /index.php/Developer_FAQ
  [46]: /index.php/Foundation
  [47]: /index.php/AppKit
  [48]: /index.php/Category:Frameworks
  [49]: /index.php/Main_Page
  [50]: /index.php/GNUstepWiki:Community_Portal
  [51]: /index.php/Current_events
  [52]: /index.php/Special:Recentchanges
  [53]: /index.php/Special:Random
  [54]: /index.php/Help:Contents
  [55]: /index.php/Special:Whatlinkshere/Scripting
  [56]: /index.php/Special:Recentchangeslinked/Scripting
  [57]: /index.php/Special:Upload
  [58]: /index.php/Special:Specialpages
  [59]: /index.php?title=Scripting&printable=yes&printable=yes
  [60]: /skins/common/images/poweredby_mediawiki_88x31.png
  [61]: http://www.mediawiki.org/
  [62]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [63]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [64]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"