<>

# Smalltalk

### From GNUstepWiki	{#siteSub}

Smalltalk is pure object oriented language with environment. In the context of the GNUstep, the Smalltalk is a _[Scripting language bundle][1]_ for the [StepTalk][2] scripting framework.

Note that the language bundle offers Smalltalk language only, that sits on top of the [Objective-C][3] object environment. Therefore, some classes and mechanisms known from Smalltalk are not (yet) available.

<table>
<tr>
<td>
## Contents
* [1 The Language][4]
  * [1\.1 Basics][5]
  * [1\.2 Literals and basic operations][6]
  * [1\.3 Blocks][7]
  * [1\.4 Cycles][8]
  * [1\.5 Array iteration][9]
* [2 More information and examples][10]
</td>
</tr>
</table>

[[edit][11]]

<>

## The Language

The language has very straightforward and easy to learn syntax. It is said, that the syntax was inspired somehow by the english grammar.

[[edit][12]]

<>

### Basics

The language is based on sending messages to objects, like:

	anObject message

Here are few examples that you should try, for example by using the [StepTalk shell][13]. For example to see current date, just send message _date_ to the object _NSDate_:

	NSDate date

To assign a result to a variable:

	dateÃÂ := NSDate date

or

	aÃÂ := 10.
	bÃÂ := 20.
	resultÃÂ := a + b.

[[edit][14]]

<>

### Literals and basic operations

In a script you should have literal objects: strings, arrays, numbers and selectors.

<table>
<caption></caption>
<tr>
<td> Strings </td>
<td> 'This is a string' 'This is another \\'String\\' with apostrophes' </td>
<caption></caption>
<td> Array </td>
<td> #(1 2 3) #('one' 'two' 'three') </td>
<caption></caption>
<td> Numbers </td>
<td> 1 2 0.1 -1.1e10 </td>
</tr>
</table>

To join two strings use , (comma), like:

	'This is ', 'a string'

To get an object from an array (indexed from 0):

	#('one' 'two' 'three') @ 1

To do computations with numbers:

	1 + 1

Important note: Smalltalk does not take into account operator priority, so you have to enclose an expression into parentheses. Try:

	1 + 2 * 3
	1 + (2 * 3)

You should use operators: + - \* /

[[edit][15]]

<>

### Blocks

Instead of explaining what blocks enclosed by [ ... ] are, try following examples, line by line, and you will get the idea:

	( 1 = 1 ) ifTrue: [ Transcript showLine: 'Yes']
	( 2 &lt; 1 ) ifFalse: [ Transcript showLine: 'No']
	( 1 &gt;= 4 ) ifTrue: [ Transcript showLine: 'Yes'] ifFalse: [ Transcript showLine: 'No']

[[edit][16]]

<>

### Cycles

Cycles are created using blocks:

	1 to: 10 do: [ÃÂ :i | Transcript showLine: (i description) ]
	0 to: 100 step: 10 do: [ÃÂ :i | Transcript showLine: (i description) ]

Other possibilities are:

	conditionBlock whileTrue: toDoBlock.
	conditionBlock whileFalse: toDoBlock.

like:

	aÃÂ := 0 . [ a &lt; 10 ] whileTrue: [ aÃÂ := a + 1 . Transcript showLine: (a description) ]

[[edit][17]]

<>

### Array iteration

	arrayÃÂ := #('one' 'two' 'three').
	array do: [ÃÂ :item | Transcript showLine: item ]
	array select: [ÃÂ :item | item hasPrefix:'t' ]

<table>
<caption></caption>
<tr>
<td> do: </td>
<td> Evaluate block for each object in array and return last evaluated expression </td>
<caption></caption>
<td> select: </td>
<td> Create new array which will contain those objects from receiver, for which value of block was true </td>
<caption></caption>
<td> reject: </td>
<td> Create new array which will contain those objects from receiver, for which value of block was false </td>
<caption></caption>
<td> collect:</td>
<td> Create new array from block return values. </td>
<caption></caption>
<td> detect: </td>
<td> Return first object for which block evaluation result is true. Othervise return nil. </td>
</tr>
</table>

[[edit][18]]

<>

## More information and examples

More examples are included in the StepTalk source distribution in Examples directory, please refer to that place.

For more information, please refer to the Documentation directory. For language reference see Smalltalk.txt file.

 Retrieved from "<http://wiki.gnustep.org/index.php/Smalltalk>"

[Categories][19]: [Scripting][20]

##### Views

* [Article][21]
* [Discussion][22]
* [Edit][23]
* [History][24]

##### Personal tools

* [Create an account or log in][25]

[][26]

##### users

* [Applications][27]
* [Guides][28]
* [FAQ][29]
* [Get Help][30]
* [Report Bugs][31]
* [Donations][32]
* [Screenshots][33]

##### developers

* [Guides][34]
* [FAQ][35]
* [Base API (Foundation)][36]
* [GUI API (AppKit)][37]
* [Frameworks][38]

##### Navigation

* [Main Page][39]
* [Community portal][40]
* [Current events][41]
* [Recent changes][42]
* [Random page][43]
* [Help][44]

##### Search

##### Toolbox

* [What links here][45]
* [Related changes][46]
* [Upload file][47]
* [Special pages][48]
* [Printable version][49]

[![MediaWiki][50]][51]

* This page was last modified 14:29, 29 August 2005.
* This page has been accessed 22,599 times.
* Content is available under [GNU General Public License][52].
* [About GNUstepWiki][53]
* [Disclaimers][54]

  [1]: /index.php/Scripting_language_bundle "Scripting language bundle"
  [2]: /index.php/StepTalk "StepTalk"
  [3]: /index.php/Objective-C "Objective-C"
  [4]: #The_Language
  [5]: #Basics
  [6]: #Literals_and_basic_operations
  [7]: #Blocks
  [8]: #Cycles
  [9]: #Array_iteration
  [10]: #More_information_and_examples
  [11]: /index.php?title=Smalltalk&action=edit&section=1 "Smalltalk"
  [12]: /index.php?title=Smalltalk&action=edit&section=2 "Smalltalk"
  [13]: /index.php?title=StepTalk_shell&action=edit "StepTalk shell"
  [14]: /index.php?title=Smalltalk&action=edit&section=3 "Smalltalk"
  [15]: /index.php?title=Smalltalk&action=edit&section=4 "Smalltalk"
  [16]: /index.php?title=Smalltalk&action=edit&section=5 "Smalltalk"
  [17]: /index.php?title=Smalltalk&action=edit&section=6 "Smalltalk"
  [18]: /index.php?title=Smalltalk&action=edit&section=7 "Smalltalk"
  [19]: /index.php?title=Special:Categories&article=Smalltalk "Special:Categories"
  [20]: /index.php/Category:Scripting "Category:Scripting"
  [21]: /index.php/Smalltalk
  [22]: /index.php?title=Talk:Smalltalk&action=edit
  [23]: /index.php?title=Smalltalk&action=edit
  [24]: /index.php?title=Smalltalk&action=history
  [25]: /index.php?title=Special:Userlogin&returnto=Smalltalk
  [26]: /index.php/Main_Page "Main Page"
  [27]: /index.php/Category:Applications
  [28]: /index.php/User_Guides
  [29]: /index.php/User_FAQ
  [30]: /index.php/Get_Help
  [31]: /index.php/Report_Bugs
  [32]: /index.php/GNUstepWiki:Site_support
  [33]: /index.php/Screenshots
  [34]: /index.php/Developer_Guides
  [35]: /index.php/Developer_FAQ
  [36]: /index.php/Foundation
  [37]: /index.php/AppKit
  [38]: /index.php/Category:Frameworks
  [39]: /index.php/Main_Page
  [40]: /index.php/GNUstepWiki:Community_Portal
  [41]: /index.php/Current_events
  [42]: /index.php/Special:Recentchanges
  [43]: /index.php/Special:Random
  [44]: /index.php/Help:Contents
  [45]: /index.php/Special:Whatlinkshere/Smalltalk
  [46]: /index.php/Special:Recentchangeslinked/Smalltalk
  [47]: /index.php/Special:Upload
  [48]: /index.php/Special:Specialpages
  [49]: /index.php?title=Smalltalk&printable=yes&printable=yes
  [50]: /skins/common/images/poweredby_mediawiki_88x31.png
  [51]: http://www.mediawiki.org/
  [52]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [53]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [54]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"