<>

# StepTalk

### From GNUstepWiki	{#siteSub}

StepTalk is the official GNUstep [scripting][1] framework. In fact, StepTalk is more than a scripting framework with an illusion of a single objective environment between objects of scriptable servers or applications. StepTalk, when combined with the dynamism that the Objective-C language provides, goes way beyond mere scripting. It is language independent - it uses [languages as separate bundles][2].

Author: [Stefan Urbanek][3] - see **[StepTalk blog][4]**.

<table>
<tr>
<td>
## Contents
* [1 Introduction][5]
* [2 Download][6]
* [3 The Framework][7]
* [4 TODO][8]
* [5 Projects using StepTalk][9]
</td>
</tr>
</table>

[[edit][10]]

<>

## Introduction

The Goal of StepTalk is to provide an environment for gluing applications together and to provide a framework for communication between users and objects in the applications. Other major goals are:

* simple and quick extensions of applications or tools
* batch-processing of objects in applications or tools
* fast prototyping of applications or new application features (play and tune a concept "online")

It does not mean that the framework should not be used for whole application development, however it was never designed for that purpose. StepTalk application development is a form of very fast prototyping of an application.

The StepTalk package features a framework, set of tools, [language bundle][11], modules and object finders. **The framework** provides an application interface for developers to make their products scriptable. For more information about the tools, see [StepTalk tools][12]. Concerning the scripting language, the StepTalk is a **language independent framework** It can be extended via "language bundles" to provide and support other scripting languages. An experimental language bundle for Guile is included in the sources package.

The default scripting language in StepTalk is [Smalltalk][13]. This is because Smalltalk is a very simple language and it is easy to learn. There are just a few basic principles that the user has to know to be able to use the language and it is close to the natural language. [Smalltalk][14] uses a similar approach to that of [Objective-C][15], the language used in GNUstep itself.

**Object Finders** are an illusion of a single objective environment. The name of an object may be known, but the object itself not. The object may be an application or it may reside on another host. Object Finder is an object that will search for an object by a specified name.

* **Distributed Object Finder** - This finder will try to look for a registered named object. It is possible to specify a list of possible hosts where the object may reside and to specify a program that will provide the object if it cannot be found.
* **Application Finder** - Looks for a locally installed application and tries to connect to it. If the application is not running, it will try to launch it.

[[edit][16]]

<>

## Download

* [Source][17]
* [Debian packages][18]

* [Browse CVS][19]

Get it by CVS:

	export CVS_RSH="ssh"
	cvs -z3 -d:ext:anoncvs@savannah.gnu.org:/cvsroot/gnustep co StepTalk

[[edit][20]]

<>

## The Framework

Classes:

* [STActor][21]
* [STContext][22]
* [STConversation][23]
* [STDistantConversation][24]
* [STEnvironment][25]
* [STLanguageManager][26]
* [STScriptManager][27]
* [STScriptObject][28]

[[edit][29]]

<>

## TODO

For more information about what should be done in StepTalk see [StepTalk TODO][30].

[[edit][31]]

<>

## Projects using StepTalk

[MolTalk][32] - a computational environment for doing Structural Bioinformatics. It interprets PDB formatted files and creates an object representation of the structure-chain-residue-atom hierarchy. Through the use of MolTalk, the PDB suddenly becomes an object-oriented database.

----

See also: [Scripting][33], [Smalltalk.org][34]

 Retrieved from "<http://wiki.gnustep.org/index.php/StepTalk>"

[Categories][35]: [Scripting][36] | [Scripting Frameworks][37] | [Frameworks][38]

##### Views

* [Article][39]
* [Discussion][40]
* [Edit][41]
* [History][42]

##### Personal tools

* [Create an account or log in][43]

[][44]

##### users

* [Applications][45]
* [Guides][46]
* [FAQ][47]
* [Get Help][48]
* [Report Bugs][49]
* [Donations][50]
* [Screenshots][51]

##### developers

* [Guides][52]
* [FAQ][53]
* [Base API (Foundation)][54]
* [GUI API (AppKit)][55]
* [Frameworks][56]

##### Navigation

* [Main Page][57]
* [Community portal][58]
* [Current events][59]
* [Recent changes][60]
* [Random page][61]
* [Help][62]

##### Search

##### Toolbox

* [What links here][63]
* [Related changes][64]
* [Upload file][65]
* [Special pages][66]
* [Printable version][67]

[![MediaWiki][68]][69]

* This page was last modified 09:31, 29 November 2006.
* This page has been accessed 62,091 times.
* Content is available under [GNU General Public License][70].
* [About GNUstepWiki][71]
* [Disclaimers][72]

  [1]: /index.php/Scripting "Scripting"
  [2]: /index.php/Scripting_language_bundle "Scripting language bundle"
  [3]: /index.php/User:Stefan_Urbanek "User:Stefan Urbanek"
  [4]: http://steptalk.blogspot.com/ "http://steptalk.blogspot.com/"
  [5]: #Introduction
  [6]: #Download
  [7]: #The_Framework
  [8]: #TODO
  [9]: #Projects_using_StepTalk
  [10]: /index.php?title=StepTalk&action=edit&section=1 "StepTalk"
  [11]: /index.php/Scripting_language_bundle "Scripting language bundle"
  [12]: /index.php/StepTalk_tools "StepTalk tools"
  [13]: /index.php/Smalltalk "Smalltalk"
  [14]: /index.php/Smalltalk "Smalltalk"
  [15]: /index.php/Objective-C "Objective-C"
  [16]: /index.php?title=StepTalk&action=edit&section=2 "StepTalk"
  [17]: ftp://ftp.gnustep.org/pub/gnustep/libs/ "ftp://ftp.gnustep.org/pub/gnustep/libs/"
  [18]: http://packages.debian.org/cgi-bin/search_packages.pl?keywords=steptalk&searchon=sourcenames&version=all&release=all&exact=1 "http://packages.debian.org/cgi-bin/search packages.pl?keywords=steptalk&searchon=sourcenames&version=all&release=all&exact=1"
  [19]: http://savannah.gnu.org/cgi-bin/viewcvs/gnustep/gnustep/dev-libs/StepTalk/ "http://savannah.gnu.org/cgi-bin/viewcvs/gnustep/gnustep/dev-libs/StepTalk/"
  [20]: /index.php?title=StepTalk&action=edit&section=3 "StepTalk"
  [21]: /index.php?title=STActor&action=edit "STActor"
  [22]: /index.php?title=STContext&action=edit "STContext"
  [23]: /index.php?title=STConversation&action=edit "STConversation"
  [24]: /index.php?title=STDistantConversation&action=edit "STDistantConversation"
  [25]: /index.php?title=STEnvironment&action=edit "STEnvironment"
  [26]: /index.php?title=STLanguageManager&action=edit "STLanguageManager"
  [27]: /index.php?title=STScriptManager&action=edit "STScriptManager"
  [28]: /index.php?title=STScriptObject&action=edit "STScriptObject"
  [29]: /index.php?title=StepTalk&action=edit&section=4 "StepTalk"
  [30]: /index.php/StepTalk_TODO "StepTalk TODO"
  [31]: /index.php?title=StepTalk&action=edit&section=5 "StepTalk"
  [32]: http://www.moltalk.org/ "http://www.moltalk.org/"
  [33]: /index.php/Scripting "Scripting"
  [34]: http://www.smalltalk.org/ "http://www.smalltalk.org/"
  [35]: /index.php?title=Special:Categories&article=StepTalk "Special:Categories"
  [36]: /index.php/Category:Scripting "Category:Scripting"
  [37]: /index.php/Category:Scripting_Frameworks "Category:Scripting Frameworks"
  [38]: /index.php/Category:Frameworks "Category:Frameworks"
  [39]: /index.php/StepTalk
  [40]: /index.php/Talk:StepTalk
  [41]: /index.php?title=StepTalk&action=edit
  [42]: /index.php?title=StepTalk&action=history
  [43]: /index.php?title=Special:Userlogin&returnto=StepTalk
  [44]: /index.php/Main_Page "Main Page"
  [45]: /index.php/Category:Applications
  [46]: /index.php/User_Guides
  [47]: /index.php/User_FAQ
  [48]: /index.php/Get_Help
  [49]: /index.php/Report_Bugs
  [50]: /index.php/GNUstepWiki:Site_support
  [51]: /index.php/Screenshots
  [52]: /index.php/Developer_Guides
  [53]: /index.php/Developer_FAQ
  [54]: /index.php/Foundation
  [55]: /index.php/AppKit
  [56]: /index.php/Category:Frameworks
  [57]: /index.php/Main_Page
  [58]: /index.php/GNUstepWiki:Community_Portal
  [59]: /index.php/Current_events
  [60]: /index.php/Special:Recentchanges
  [61]: /index.php/Special:Random
  [62]: /index.php/Help:Contents
  [63]: /index.php/Special:Whatlinkshere/StepTalk
  [64]: /index.php/Special:Recentchangeslinked/StepTalk
  [65]: /index.php/Special:Upload
  [66]: /index.php/Special:Specialpages
  [67]: /index.php?title=StepTalk&printable=yes&printable=yes
  [68]: /skins/common/images/poweredby_mediawiki_88x31.png
  [69]: http://www.mediawiki.org/
  [70]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [71]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [72]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"