<>

# Summer Of Code Ideas

### From GNUstepWiki	{#siteSub}

GNUstep is a mentoring organization of the Google Summer of Code.

In the list below you find the ideas that have been proposed as projects for the next Summer of Code. If you have a project that would be interesting, feel free to add it here.

If you find a topic that you want to work on, please apply directly through the SoC page [[1]][1]

<br />

<table>
<tr>
<td>
## Contents
* [1 Porting][2]
  * [1\.1 Port WebKit (using GCC 4.x with ObjC++ support)][3]
* [2 General Improvements][4]
  * [2\.1 Finish input server][5]
  * [2\.2 Finish Project Center][6]
  * [2\.3 Revamp Objective-C garbage collection and make it compatible with the Apple implementation][7]
  * [2\.4 Cross-compilation from GNU/Linux to embedded devices][8]
  * [2\.5 Cross-compilation to GNU/Linux or Windows from Xcode][9]
  * [2\.6 GNUstepWeb][10]
  * [2\.7 SimpleWebKit][11]
  * [2\.8 Screen change support][12]
* [3 AppKit (GUI)][13]
* [4 Foundation (Base)][14]
* [5 Core Data][15]
* [6 Misc][16]
* [7 GAP (GNUstep Application Project) Ideas][17]
</td>
</tr>
</table>

[[edit][18]]

<>

## Porting

[[edit][19]]

<>

### Port [WebKit][20] (using GCC 4.x with ObjC++ support)

* The WebKit team is willing to help whoever wants to take on this project, please see [this email][21].
* Implementation of CoreFoundation and CoreGraphics functions to support this
* Implementation of WTF types in WebKit to interface with GNUstep

Difficulty: Very High; Experience needed: Expert at C/C++ and Core\* Apple libraries)

[[edit][22]]

<>

## General Improvements

[[edit][23]]

<>

### Finish input server

* See [this][24] for more information

Difficulty: High; Required Experience: Objective-C, Cocoa

[[edit][25]]

<>

### Finish Project Center

* Improve integrated editor to have better support for tabs and emacs/vi like editing
* Improve built-in debugger support on Windows and other platforms aside from Linux
* Correct issues which exist on Windows such as:
  * make executable cannot be located unless the user changes it in PC directly.

Difficulty: Medium; Required Experience: Objective-C, Cocoa

[[edit][26]]

<>

### Revamp Objective-C garbage collection and make it compatible with the Apple implementation

* Help finish implementation of Garbage Collection in the libobjc2 runtime (tracing is the only thing left to do, per David Chisnall)

Difficulty: High; Required Experience: C

[[edit][27]]

<>

### Cross-compilation from GNU/Linux to embedded devices

* Compilation of GCC for the target architecture
* Compilation of GNUstep frameworks for target architecture

Difficulty: Medium; Required Experience: GCC

[[edit][28]]

<>

### Cross-compilation to GNU/Linux or Windows from Xcode

* Compilation of GCC for the target architecture and OS.
* Compilation of standard libs for the target architecture and OS
* Knowledge of how to build an SDK for Xcode
* Compilation of GNUstep for target architecture and OS.

Difficulty: Medium; Required Experience: GCC, Mac OS X

[[edit][29]]

<>

### [GNUstepWeb][30]

* add script language support, etc

Difficulty: Medium; Required Experience: Web Development, Cocoa/ObjC

[[edit][31]]

<>

### [SimpleWebKit][32]

* help fix the following things:
  * event handling
  * better renderer
  * parsing quirks

Difficulty: Medium; Required Experience: Cocoa/ObjC

* NSTextTable implementation in -gui and debugging of SWK against it (and Cocoa's reference) for the display of HTML tables

Difficulty: Medium to High; Access to Mac preferred for comparison of Table behaviour.

[[edit][33]]

<>

### Screen change support

* handle resizing of the screen etc. It's now common to run in virtual machines or with multiple displays with different sizes, so we need to gracefully handle changes of screen size while an application is running.

Difficulty: Medium; Required Experience: Cocoa/ObjC

[[edit][34]]

<>

## AppKit (GUI)

* Implement Cocoa Bindings properly. We have some partial implementations of the controller classes, but they're not finished / tested. With 10.6, Apple shipped an NSTreeController implementation that only causes segfaults occasionally (like, when you run one of their example apps), rather than all of the time (as with 10.5), so people will probably start using this stuff a lot more. (David Chisnell)
* Complete theming support ... go through each control in the gui and make sure it draws itself using the theming engine, adding methods to the theming engine as required. Update/improve Thematic.app to match by providing wysiwyg editine/cretion of themes for each control.
* Text System should be cleaned, profiled and finished. Many methods in NSLayoutManager are unfinished or unimplemented, so we currently cannot tweak the test system as much as the one provided by Cocoa. (Quentin Mathe)
* We need NSTypeSetter, NSGlyphStorage, NSGlyphInfo, and NSGlyphGenerator implementations. If NSTypeSetter and NSLayoutManager were implemented, they would probably be used in Etoile. (Quentin Mathe)
* NSTextTable, NSTextTableBlock, NSTextList, &amp; NSTextBlock implementations would also bring the GNUstep text system in line with that of Cocoa as of Mac OS 10.4. The classes could be useful to build a powerful word processor, NSTextTable will help getting Tables for SimpleWebKit. Add relevant UI components (e.g. OS X has some inspectors for these that let you create tables and lists in a text view). (Quentin Mathe, David Chisnell)
* NSOpenGL Classes could be improved, made compatible with current Cocoa implementations, and further tested. Note sure about that anymore. Feedback from people using these classes would be useful? (Quentin Mathe)
* NSBitmapImageRep formats: Currently, we support reading and writing for TIFF, GIF, JPEG, PNG, PNM (reading-only). We would like to complete NSEPSImageRep and NSPDFImageRep (with Cairo?). SVG reading and writing support, would be nice too. (Quentin Mathe)
* NSDatePicker (and obligatory companion NSCell subclass) implementation.
* Backend: especially xlib but also art could use performance improvements. NSImageView scrolling on xlib comes to my mind for example. (shouldn't improvements focus on the preferred, cairo backend rather than the deprecated ones?)
* Fix focusing bugs/issues making sure GNUstep apps can be used with all window managers
* improve our RTF parser, to be able to correctly load OO and MS-Office created RTFs. Add support for reading NeXT RTFDs. Correct loading of Apple RTFs including char encoding

[[edit][35]]

<>

## Foundation (Base)

* Improve testsuite to have regression tests cover much more of base library.
* Implement Apple's scripting/apple-events classes as a subproject of the base library.
* Complete separation of gnustep specific extensions from Apple APIs and implement new Apple methods missing from existing classes for compatibility.
* Complete implementation of Apple's latest URL handling classes based on NSStream... testing on mswindows as well as unix.
* Implement CoreFoundation on Base
* Now that Apple have XML based keyed coding, implement a version of Distributed Objects to talk directly to Apple applications (Nicolaus has done some work towards this in mySTEP).

[[edit][36]]

<>

## Core Data

* Saso Kiselkov started implementing this [framework][37] and now hosted here [[2]][38] as part of GNUstep. However, NSManagedObjectContext &amp; NSPersistentStoreCoordinator have yet to be tackled according to his web page. Presumably NSPersistentDocument also needs to be implemented.
* DataBuilder.app needs some final graphics improvements. And, should become able to read and write model files from Xcode.

[[edit][39]]

<>

## Misc

* Basic CoreAnimation support. The central part of CoreAnimation just does interpolation over some simple functions and modifies properties via KVC. (David Chisnell)
* Porting GNUstep to the browser. I committed an Objective-C to JavaScript compiler to ÃÂtoilÃÂ© svn over the weekend. Many GNUstep classes should work as-is, some will want reimplementing wrapping their JavaScript equivalents (e.g. GSDictionary, GSString, GSArray), and the drawing-related classes will need tweaking to draw on a canvas. The final step would be implementing DO-over-WebSocket, so you can run view and maybe controller classes in the browser, model classes on the server, and have stuff Just WorkÃ¢ÂÂ¢ (David Chisnell)
* Create an AJAX Framework for GNUstepWeb
  * [Project WONDER][40], especially the stuff mentioned here: [[3]][41] could be ported over from Java. See also [[4]][42] and [[5]][43]
* There's a truck load of stuff in WO 5.4.1 that GNUstepWeb is missing: [[6]][44]
* Add support for exposing objects on D-Bus to DBusKit.
* Use your yacc/bison and (f)lex knowledge to finalize a source code translator for ObjC-2.0 to ObjC-1.0 [[7]][45]
* _OpenGL extensions management API_: before using an OpenGL extension a program must first determine its availability. The mechanism for doing this is platform-specific and libraries such as [w:GLEW][46] and [w:GLEE][47] exist to simplify the process. The target of this project is a multiplatform Objective-C wrapper around OpenGL platform-specific functions.
* _HID API_: GNUstep can only handle the usual _human interface devices_ (HID)ÃÂ : keyboard and mouse. A multiplatform framework would allow GNUstep application to handle joystick, graphic tablet or 3D device.

[[edit][48]]

<>

## [GAP][49] (GNUstep Application Project) Ideas

* Debug and Complete FlexiSheet, making sure it works on Cocoa as expected and noting incompatibilities with GNUstep. Those should be either fixed for both platforms (FlexiSheet portability of code improvement) or noted as a bug or missing feature in GNUstep.
  * printing
  * cell formatting
  * improved undo
  * searching

* implementation (Extract from Addresses) of an iSync compatible framework, its corresponding management application and then integrating it with AddressBook (which already has part of such framework). The goal would be to have synchronization of Addresses (but in future, perhaps calendar, Vespucci bookmarks) gnustep to gnustep, gnustep to mac and gnustep to .Mac/MobileMe by having such account.
* porting of Applications from OpenStep or Cocoa abandonware. This needs to be checked on application-per-application: License and dependencies can be a problem as defining the scope of the project well.

* Implement a Dictionary tool based on dict.leo.org

* Implement a portable pure obj-c + Foundation GoogleTalk instant messenging (XMPP) kit or alternatively look at

xmppframework as inspiration and/or porting base

* Some miscellaneous applications that run a Cocoa GUI could be ported to GNUstep:
  * _Vim GUI_ÃÂ : at least two cocoa-based gui projects already exist - [vim-cocoa][50] and [mac-vim][51]
  * [VLC media player][52]ÃÂ : a Cocoa based interface exists for VLC
  * propose your own

* for more ideas check [GAP wishlist][53]

 Retrieved from "[http://wiki.gnustep.org/index.php/Summer\_Of\_Code\_Ideas][54]"

[Categories][55]: [Summer Of Code][56]

##### Views

* [Article][57]
* [Discussion][58]
* [Edit][59]
* [History][60]

##### Personal tools

* [Create an account or log in][61]

[][62]

##### users

* [Applications][63]
* [Guides][64]
* [FAQ][65]
* [Get Help][66]
* [Report Bugs][67]
* [Donations][68]
* [Screenshots][69]

##### developers

* [Guides][70]
* [FAQ][71]
* [Base API (Foundation)][72]
* [GUI API (AppKit)][73]
* [Frameworks][74]

##### Navigation

* [Main Page][75]
* [Community portal][76]
* [Current events][77]
* [Recent changes][78]
* [Random page][79]
* [Help][80]

##### Search

##### Toolbox

* [What links here][81]
* [Related changes][82]
* [Upload file][83]
* [Special pages][84]
* [Printable version][85]

[![MediaWiki][86]][87]

* This page was last modified 08:19, 29 March 2012.
* This page has been accessed 111,376 times.
* Content is available under [GNU General Public License][88].
* [About GNUstepWiki][89]
* [Disclaimers][90]

  [1]: http://code.google.com/soc/ "http://code.google.com/soc/"
  [2]: #Porting
  [3]: #Port_WebKit_.28using_GCC_4.x_with_ObjC.2B.2B_support.29
  [4]: #General_Improvements
  [5]: #Finish_input_server
  [6]: #Finish_Project_Center
  [7]: #Revamp_Objective-C_garbage_collection_and_make_it_compatible_with_the_Apple_implementation
  [8]: #Cross-compilation_from_GNU.2FLinux_to_embedded_devices
  [9]: #Cross-compilation_to_GNU.2FLinux_or_Windows_from_Xcode
  [10]: #GNUstepWeb
  [11]: #SimpleWebKit
  [12]: #Screen_change_support
  [13]: #AppKit_.28GUI.29
  [14]: #Foundation_.28Base.29
  [15]: #Core_Data
  [16]: #Misc
  [17]: #GAP_.28GNUstep_Application_Project.29_Ideas
  [18]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=1 "Summer Of Code Ideas"
  [19]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=2 "Summer Of Code Ideas"
  [20]: http://developer.apple.com/opensource/internet/webkit.html "http://developer.apple.com/opensource/internet/webkit.html"
  [21]: http://lists.gnu.org/archive/html/discuss-gnustep/2007-03/msg00290.html "http://lists.gnu.org/archive/html/discuss-gnustep/2007-03/msg00290.html"
  [22]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=3 "Summer Of Code Ideas"
  [23]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=4 "Summer Of Code Ideas"
  [24]: http://svn.gna.org/viewcvs/gnustep/libs/gui/branches/kazunobu_input_management/ "http://svn.gna.org/viewcvs/gnustep/libs/gui/branches/kazunobu input management/"
  [25]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=5 "Summer Of Code Ideas"
  [26]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=6 "Summer Of Code Ideas"
  [27]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=7 "Summer Of Code Ideas"
  [28]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=8 "Summer Of Code Ideas"
  [29]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=9 "Summer Of Code Ideas"
  [30]: /index.php/GNUstepWeb "GNUstepWeb"
  [31]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=10 "Summer Of Code Ideas"
  [32]: /index.php/SimpleWebKit "SimpleWebKit"
  [33]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=11 "Summer Of Code Ideas"
  [34]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=12 "Summer Of Code Ideas"
  [35]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=13 "Summer Of Code Ideas"
  [36]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=14 "Summer Of Code Ideas"
  [37]: http://gscoredata.nongnu.org/ "http://gscoredata.nongnu.org/"
  [38]: http://svn.gna.org/viewcvs/gnustep/libs/gscoredata/ "http://svn.gna.org/viewcvs/gnustep/libs/gscoredata/"
  [39]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=15 "Summer Of Code Ideas"
  [40]: http://sourceforge.net/projects/wonder "http://sourceforge.net/projects/wonder"
  [41]: http://en.wikibooks.org/wiki/Programming:WebObjects/Project_WONDER/Frameworks/Ajax "http://en.wikibooks.org/wiki/Programming:WebObjects/Project WONDER/Frameworks/Ajax"
  [42]: http://search.lists.apple.com/?cmd=Search!&fmt=long&form=extended&m=all&ps=10&q=Ajax&sp=1&ul=webobjects-dev&wf=2221&wm=wrd&s=DRP "http://search.lists.apple.com/?cmd=Search!&fmt=long&form=extended&m=all&ps=10&q=Ajax&sp=1&ul=webobjects-dev&wf=2221&wm=wrd&s=DRP"
  [43]: http://www.google.com/search?hl=en&safe=off&q=webobjects+ajax&btnG=Search "http://www.google.com/search?hl=en&safe=off&q=webobjects ajax&btnG=Search"
  [44]: http://developer.apple.com/documentation/DeveloperTools/Reference/WO541Reference/index.html "http://developer.apple.com/documentation/DeveloperTools/Reference/WO541Reference/index.html"
  [45]: http://www.quantum-step.com/download/sources/mySTEP/objc-2.0/ "http://www.quantum-step.com/download/sources/mySTEP/objc-2.0/"
  [46]: /index.php?title=W:GLEW&action=edit "W:GLEW"
  [47]: /index.php?title=W:GLEE&action=edit "W:GLEE"
  [48]: /index.php?title=Summer_Of_Code_Ideas&action=edit&section=16 "Summer Of Code Ideas"
  [49]: http://gap.nongnu.org "http://gap.nongnu.org"
  [50]: http://www.ohloh.net/p/vim-cocoa "http://www.ohloh.net/p/vim-cocoa"
  [51]: http://macvim.org/OSX "http://macvim.org/OSX"
  [52]: http://www.videolan.org/vlc "http://www.videolan.org/vlc"
  [53]: http://gap.nongnu.org/developers/wishlist.html "http://gap.nongnu.org/developers/wishlist.html"
  [54]: http://wiki.gnustep.org/index.php/Summer_Of_Code_Ideas
  [55]: /index.php?title=Special:Categories&article=Summer_Of_Code_Ideas "Special:Categories"
  [56]: /index.php/Category:Summer_Of_Code "Category:Summer Of Code"
  [57]: /index.php/Summer_Of_Code_Ideas
  [58]: /index.php?title=Talk:Summer_Of_Code_Ideas&action=edit
  [59]: /index.php?title=Summer_Of_Code_Ideas&action=edit
  [60]: /index.php?title=Summer_Of_Code_Ideas&action=history
  [61]: /index.php?title=Special:Userlogin&returnto=Summer_Of_Code_Ideas
  [62]: /index.php/Main_Page "Main Page"
  [63]: /index.php/Category:Applications
  [64]: /index.php/User_Guides
  [65]: /index.php/User_FAQ
  [66]: /index.php/Get_Help
  [67]: /index.php/Report_Bugs
  [68]: /index.php/GNUstepWiki:Site_support
  [69]: /index.php/Screenshots
  [70]: /index.php/Developer_Guides
  [71]: /index.php/Developer_FAQ
  [72]: /index.php/Foundation
  [73]: /index.php/AppKit
  [74]: /index.php/Category:Frameworks
  [75]: /index.php/Main_Page
  [76]: /index.php/GNUstepWiki:Community_Portal
  [77]: /index.php/Current_events
  [78]: /index.php/Special:Recentchanges
  [79]: /index.php/Special:Random
  [80]: /index.php/Help:Contents
  [81]: /index.php/Special:Whatlinkshere/Summer_Of_Code_Ideas
  [82]: /index.php/Special:Recentchangeslinked/Summer_Of_Code_Ideas
  [83]: /index.php/Special:Upload
  [84]: /index.php/Special:Specialpages
  [85]: /index.php?title=Summer_Of_Code_Ideas&printable=yes&printable=yes
  [86]: /skins/common/images/poweredby_mediawiki_88x31.png
  [87]: http://www.mediawiki.org/
  [88]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [89]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [90]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"