<>

# Window manager

### From GNUstepWiki	{#siteSub}

In Windows and Mac OS X the window manager is tied into the OS. That's not the case for Linux or BSD. [Window Maker][1] is the recommended window manager for GNUstep, but a standard feature-set is needed. GNUstep-based applications have additional needs beyond traditional window managers, like handling the dock icon or the menus. Collecting the requirements here will lead to a specification, so any window manager can clearly state whether or not it is GNUstep-compliant.

<table>
<tr>
<td>
## Contents
* [1 WM Attributes][2]
* [2 Window Level][3]
* [3 Window Style][4]
* [4 Window Type][5]
* [5 App Icon][6]
* [6 Focus][7]
* [7 Menus][8]
* [8 Window Resizing and Moving][9]
</td>
</tr>
</table>

[[edit][10]]

<>

# WM Attributes

Headers/x11/XGServerWindow.h defines

	 unsigned long flags
	 unsigned long window_style
	 unsigned long window_level
	 unsigned long reserved
	 Pixmap miniaturize_pixmap;    // pixmap for miniaturize button
	 Pixmap close_pixmap;          // pixmap for close button.
	 Pixmap miniaturize_mask;      // miniaturize pixmap mask
	 Pixmap close_mask;            // close pixmap mask
	 unsigned long extra_flags;

	 #define GSWindowStyleAttr                   (1&lt;&lt;0)
	 #define GSWindowLevelAttr                   (1&lt;&lt;1)
	 #define GSMiniaturizePixmapAttr             (1&lt;&lt;3)
	 #define GSClosePixmapAttr                   (1&lt;&lt;4)
	 #define GSMiniaturizeMaskAttr               (1&lt;&lt;5)
	 #define GSCloseMaskAttr                     (1&lt;&lt;6)
	 #define GSExtraFlagsAttr                    (1&lt;&lt;7)
	 #define GSDocumentEditedFlag                (1&lt;&lt;0)
	 #define GSWindowWillResizeNotificationsFlag (1&lt;&lt;1)
	 #define GSWindowWillMoveNotificationsFlag   (1&lt;&lt;2)
	 #define GSNoApplicationIconFlag             (1&lt;&lt;5)
	 #define WMFHideOtherApplications            10
	 #define WMFHideApplication                  12

[Interface WM][11] defines the following, but they might not be necessary:

	 Atom gnustep_wm_attr;
	 Atom gnustep_titlebar_state;
	 Atom gnustep_wm_miniaturizable_window;

[[edit][12]]

<>

# Window Level

GNUstep needs arbitrary window levels. [Extended Window Manager Hints][13] defines these two:

	 _NET_WM_STATE_ABOVE, ATOM
	 _NET_WM_STATE_BELOW, ATOM

The rest depends on the function of a window. To obtain good interoperability between different Desktop Environments, the following layered stacking order is recommended, from the bottom to the top:

1. windows of type \_NET\_WM\_TYPE\_DESKTOP
2. windows having state \_NET\_WM\_STATE\_BELOW
3. windows not belonging in any other layer
4. windows of type \_NET\_WM\_TYPE\_DOCK (unless they have state \_NET\_WM\_TYPE\_BELOW) and windows having state \_NET\_WM\_STATE\_ABOVE
5. focused windows having state \_NET\_WM\_STATE\_FULLSCREEN

Windows that are transient for another window should be kept above this window.

The window manager may choose to put some windows in different stacking positions, for example to allow the user to bring currently active window to the top and return it back when the window loses focus.

[[edit][14]]

<>

# Window Style

Window style is more or less unchanged, except GNUstep want to display edited document: GSDocumentEditedFlag

[[edit][15]]

<>

# Window Type

EWMH defines:

	 _NET_WM_WINDOW_TYPE_DESKTOP, ATOM
	 _NET_WM_WINDOW_TYPE_DOCK, ATOM
	 _NET_WM_WINDOW_TYPE_TOOLBAR, ATOM
	 _NET_WM_WINDOW_TYPE_MENU, ATOM
	 _NET_WM_WINDOW_TYPE_UTILITY, ATOM
	 _NET_WM_WINDOW_TYPE_SPLASH, ATOM
	 _NET_WM_WINDOW_TYPE_DIALOG, ATOM
	 _NET_WM_WINDOW_TYPE_DROPDOWN_MENU, ATOM
	 _NET_WM_WINDOW_TYPE_POPUP_MENU, ATOM
	 _NET_WM_WINDOW_TYPE_TOOLTIP, ATOM
	 _NET_WM_WINDOW_TYPE_NOTIFICATION, ATOM
	 _NET_WM_WINDOW_TYPE_COMBO, ATOM
	 _NET_WM_WINDOW_TYPE_DND, ATOM
	 _NET_WM_WINDOW_TYPE_NORMAL, ATOM

Comments from Yen-Ju Chen: "GNUstep has no such definition and use window level for this purpose. Personally, I wish GNUstep had a better way to tell which window is for which functions, like app icon, floating panel, menu, key window, main window. The window level is not that reliable when people want to do some tricks. It may not match EWMH one-to-one, but it will be useful for various reasons."

[[edit][16]]

<>

# App Icon

GNUstep used to have NSDockWindowLevel, but it is deprecated. So to know which window is the app icon, you have to first find a GNUstep window, check its group\_leader, (See XWMHints in X protocols), then check its icon\_window which points to app icon. Again, it will be easier if there is hint (see above).

EWMH defines \_NET\_WM\_ICON for app icon image. GNUstep supports it, but I am not sure if it is updated when the app icon image is changed. And if people use app icon as a NSWindow and draw directly on it, there is no way the window manager will know. The solution is that if there is a notification that the icon is redrawn, the window manager or GNUstep can copy (or take a screenshot of) the image from that NSWindow and put it into \_NET\_WM\_ICON. It requires something like XCopyArea().

[[edit][17]]

<>

# Focus

X has focused and unfocused window, GNUstep has key window and main window, plus menu and app icon. I don't know how the chain of focus should go when the window and menu are up and down. But again, if there is a hint for the main window, key window, main menu, etc, it will be easy for the window manager to know where the focus should go. A documentation of how the focus should shift from which to which may help.

[[edit][18]]

<>

# Menus

Again, because there are no real hints about which one is the main menu and submenu besides window level, it is hard to find the correct one. So menus are treated as regular windows in most cases.

Besides the focus issue, there is also a boundary issue. Say the user puts the mouse on the right edge of the screen and clicks the right button (bringing up a menu): the main menu will be off of the right boundary. GNUstep tries to move it back, and some window managers also try to move it back. When a window is moved, the mouse tracking may be offset. After the main menu is open, a user clicks on a submenu, which will also be off of the right boundary. Then should the window manager move both the main menu and submenu to the left? Does GNUstep do that? It is not clear which one should do what.

And now, some people like to have a horizontal menu (like Mac OS X) instead of a vertical menu (like NEXTSTEP). They behave differently for submenus. For a horizontal menu, the submenu will close on an action fire. For a vertical menu, the submenu will stay open after an action fire. So I guess only GNUstep can handle it.

[[edit][19]]

<>

# Window Resizing and Moving

GNUstep defines:

	 #define GSWindowWillResizeNotificationsFlag  (1&lt;&lt;1)
	 #define GSWindowWillMoveNotificationsFlag    (1&lt;&lt;2)

I didn't see it in Window Maker, therefore, I don't know whether it is really supported. But it may be key for some windows turning black when resizing.

 Retrieved from "[http://wiki.gnustep.org/index.php/Window\_manager][20]"

##### Views

* [Article][21]
* [Discussion][22]
* [Edit][23]
* [History][24]

##### Personal tools

* [Create an account or log in][25]

[][26]

##### users

* [Applications][27]
* [Guides][28]
* [FAQ][29]
* [Get Help][30]
* [Report Bugs][31]
* [Donations][32]
* [Screenshots][33]

##### developers

* [Guides][34]
* [FAQ][35]
* [Base API (Foundation)][36]
* [GUI API (AppKit)][37]
* [Frameworks][38]

##### Navigation

* [Main Page][39]
* [Community portal][40]
* [Current events][41]
* [Recent changes][42]
* [Random page][43]
* [Help][44]

##### Search

##### Toolbox

* [What links here][45]
* [Related changes][46]
* [Upload file][47]
* [Special pages][48]
* [Printable version][49]

[![MediaWiki][50]][51]

* This page was last modified 20:06, 4 April 2007.
* This page has been accessed 33,250 times.
* Content is available under [GNU General Public License][52].
* [About GNUstepWiki][53]
* [Disclaimers][54]

  [1]: /index.php/Window_Maker "Window Maker"
  [2]: #WM_Attributes
  [3]: #Window_Level
  [4]: #Window_Style
  [5]: #Window_Type
  [6]: #App_Icon
  [7]: #Focus
  [8]: #Menus
  [9]: #Window_Resizing_and_Moving
  [10]: /index.php?title=Window_manager&action=edit&section=1 "Window manager"
  [11]: http://interfacewm.sourceforge.net/ "http://interfacewm.sourceforge.net/"
  [12]: /index.php?title=Window_manager&action=edit&section=2 "Window manager"
  [13]: http://standards.freedesktop.org/wm-spec/wm-spec-latest.html "http://standards.freedesktop.org/wm-spec/wm-spec-latest.html"
  [14]: /index.php?title=Window_manager&action=edit&section=3 "Window manager"
  [15]: /index.php?title=Window_manager&action=edit&section=4 "Window manager"
  [16]: /index.php?title=Window_manager&action=edit&section=5 "Window manager"
  [17]: /index.php?title=Window_manager&action=edit&section=6 "Window manager"
  [18]: /index.php?title=Window_manager&action=edit&section=7 "Window manager"
  [19]: /index.php?title=Window_manager&action=edit&section=8 "Window manager"
  [20]: http://wiki.gnustep.org/index.php/Window_manager
  [21]: /index.php/Window_manager
  [22]: /index.php?title=Talk:Window_manager&action=edit
  [23]: /index.php?title=Window_manager&action=edit
  [24]: /index.php?title=Window_manager&action=history
  [25]: /index.php?title=Special:Userlogin&returnto=Window_manager
  [26]: /index.php/Main_Page "Main Page"
  [27]: /index.php/Category:Applications
  [28]: /index.php/User_Guides
  [29]: /index.php/User_FAQ
  [30]: /index.php/Get_Help
  [31]: /index.php/Report_Bugs
  [32]: /index.php/GNUstepWiki:Site_support
  [33]: /index.php/Screenshots
  [34]: /index.php/Developer_Guides
  [35]: /index.php/Developer_FAQ
  [36]: /index.php/Foundation
  [37]: /index.php/AppKit
  [38]: /index.php/Category:Frameworks
  [39]: /index.php/Main_Page
  [40]: /index.php/GNUstepWiki:Community_Portal
  [41]: /index.php/Current_events
  [42]: /index.php/Special:Recentchanges
  [43]: /index.php/Special:Random
  [44]: /index.php/Help:Contents
  [45]: /index.php/Special:Whatlinkshere/Window_manager
  [46]: /index.php/Special:Recentchangeslinked/Window_manager
  [47]: /index.php/Special:Upload
  [48]: /index.php/Special:Specialpages
  [49]: /index.php?title=Window_manager&printable=yes&printable=yes
  [50]: /skins/common/images/poweredby_mediawiki_88x31.png
  [51]: http://www.mediawiki.org/
  [52]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [53]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [54]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"