<>

# Writing documentation

### From GNUstepWiki	{#siteSub}

GNUstep documentation is produced by a variety of methods, but the main class reference documentation (i.e. the stuff you are concerned with if you are implementing new library code) is generated automatically from the Objective-C header files.

The gnustep-make system supports automatic generation of documentation, and the gnustep-base library includes the autogsdoc tool used to produce the documentation. Autogsdoc is similar tools like Doxygen or Javadoc, but was written before these tools were generally available and was designed specifically for Objective-C documentation. it has the advantages of (relative) simplicity and no external dependencies ... if you have gnustep-base installed then you have the ability to generate GNUstep documentation.

Basically, to provide documentation for a class, you place a comment immediately before the class in the header file, and start the comment with an extra asterisk ('/\*\*' rather than '/\*') to tell autogsdoc that the comment is part of the documentation.

To provide documentation for an individual method, you place a comment immediately before the declaration of that method in the header.

The autogsdoc tool takes the content of the comments an produces an intermediate XML representation which is then converted to HTML. You can thereof use familiar markup like <br />
 to force a line break in the documentation, but you must also be careful to escape &lt; and &amp; characters using 'lt' and 'amp' in your comments if you do not want them to be treated as markup.

Autogsdoc also handles automatic cross referencing and formatting to a large extent, but the full details are beyond the scope of a small wikipedia article ... you should look at the autogsdoc documentation and the gsdoc markup language documentation for full information.

What do you need to document? Well, for each class or protocol you should provide an overview of what that class or protocol is intended to be used for, and should ideally provide example use cases and simple example code. For each method in the class you should provide a description of what the method does, what effect different arguments have, what possible return values are, and what exceptions might be raised (if any).

What you _don't_ need to do is provide information about API versioning in the comments ... there are macros you should use in the header to define visibility of methods in different versions of the API, and autogsdoc should detect those automatically and insert information into the documentation to tell the reader which versions of the API the method is present in.

----

See also

* [autogsdoc documentation][1]
* [autogsdoc man page][2]

 Retrieved from "[http://wiki.gnustep.org/index.php/Writing\_documentation][3]"

##### Views

* [Article][4]
* [Discussion][5]
* [Edit][6]
* [History][7]

##### Personal tools

* [Create an account or log in][8]

[][9]

##### users

* [Applications][10]
* [Guides][11]
* [FAQ][12]
* [Get Help][13]
* [Report Bugs][14]
* [Donations][15]
* [Screenshots][16]

##### developers

* [Guides][17]
* [FAQ][18]
* [Base API (Foundation)][19]
* [GUI API (AppKit)][20]
* [Frameworks][21]

##### Navigation

* [Main Page][22]
* [Community portal][23]
* [Current events][24]
* [Recent changes][25]
* [Random page][26]
* [Help][27]

##### Search

##### Toolbox

* [What links here][28]
* [Related changes][29]
* [Upload file][30]
* [Special pages][31]
* [Printable version][32]

[![MediaWiki][33]][34]

* This page was last modified 21:49, 19 February 2015.
* This page has been accessed 3,164 times.
* Content is available under [GNU General Public License][35].
* [About GNUstepWiki][36]
* [Disclaimers][37]

  [1]: http://www.gnustep.org/resources/documentation/Developer/Tools/Reference/autogsdoc.html "http://www.gnustep.org/resources/documentation/Developer/Tools/Reference/autogsdoc.html"
  [2]: http://linux.die.net/man/1/autogsdoc "http://linux.die.net/man/1/autogsdoc"
  [3]: http://wiki.gnustep.org/index.php/Writing_documentation
  [4]: /index.php/Writing_documentation
  [5]: /index.php?title=Talk:Writing_documentation&action=edit
  [6]: /index.php?title=Writing_documentation&action=edit
  [7]: /index.php?title=Writing_documentation&action=history
  [8]: /index.php?title=Special:Userlogin&returnto=Writing_documentation
  [9]: /index.php/Main_Page "Main Page"
  [10]: /index.php/Category:Applications
  [11]: /index.php/User_Guides
  [12]: /index.php/User_FAQ
  [13]: /index.php/Get_Help
  [14]: /index.php/Report_Bugs
  [15]: /index.php/GNUstepWiki:Site_support
  [16]: /index.php/Screenshots
  [17]: /index.php/Developer_Guides
  [18]: /index.php/Developer_FAQ
  [19]: /index.php/Foundation
  [20]: /index.php/AppKit
  [21]: /index.php/Category:Frameworks
  [22]: /index.php/Main_Page
  [23]: /index.php/GNUstepWiki:Community_Portal
  [24]: /index.php/Current_events
  [25]: /index.php/Special:Recentchanges
  [26]: /index.php/Special:Random
  [27]: /index.php/Help:Contents
  [28]: /index.php/Special:Whatlinkshere/Writing_documentation
  [29]: /index.php/Special:Recentchangeslinked/Writing_documentation
  [30]: /index.php/Special:Upload
  [31]: /index.php/Special:Specialpages
  [32]: /index.php?title=Writing_documentation&printable=yes&printable=yes
  [33]: /skins/common/images/poweredby_mediawiki_88x31.png
  [34]: http://www.mediawiki.org/
  [35]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [36]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [37]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"