<>

# Writing portable code

### From GNUstepWiki	{#siteSub}

GNUstep opens up some fairly interesting opportunities to target a number of platforms with the same source code, for example porting Mac OS X Cocoa applications to Linux, the BSDs, other Unices and (ultimately) Windows without significant re-engineering effort or degraded end-user functionality.

Some portability gotchas are listed below (please update when you run into a new one!):

<table>
<tr>
<td>
## Contents
* [1 Porting Applications][1]
  * [1\.1 Porting from NeXTSTEP (NX\*) to GNUstep][2]
  * [1\.2 Porting from Cocoa or OPENSTEP (NS\*) to GNUstep][3]
  * [1\.3 Porting from GNUstep to Cocoa][4]
* [2 Stumbling Blocks][5]
  * [2\.1 Apple's Cocoa.h][6]
  * [2\.2 Distinguishing Between Cocoa and GNUstep][7]
  * [2\.3 Porting .nib files from OPENSTEP or Mac OS X 10.1 and earlier][8]
    * [2\.3.1 Gmodel to .gorm conversion][9]
    * [2\.3.2 .nib to .gorm conversion][10]
  * [2\.4 Xcode conversion][11]
* [3 Notes][12]
  * [3\.1 Do not rely on tools available in development environment][13]
  * [3\.2 When platform-specific code cannot be avoided][14]
  * [3\.3 Cross Compiling][15]
</td>
</tr>
</table>

[[edit][16]]

<>

## Porting Applications

[[edit][17]]

<>

### Porting from NeXTSTEP (NX\*) to GNUstep

For this you should have access to an old OPENSTEP installation, or find a friend who has one, otherwise you're simply better off just rewriting the application from scratch. There are some scripts which can be used to convert an application from NeXTSTEP to OPENSTEP located in /NextDeveloper/OpenStepConversion/ConversionScripts. They use a scripting language called "tops". I haven't been able, as yet, to locate a version of tops for Linux or any other operating system other than Mac OS X or OPENSTEP/Mach or NeXTSTEP. There are a few conversion applications which basically just use the tops scripts to do the conversion. They are actually two versions of the same program, but the second one doesn't run on NeXT, so here's both. These are:

* <ftp://next-ftp.peak.org/openstep/mach/apps/devtools/Conversion.0.5.NI.tar.gz>
* <ftp://next-ftp.peak.org/openstep/mach/apps/devtools/ConversionII.1.0.I.tar.gz>

You should be able to point it at the project directory you wish to convert and start the conversion. The GUI is very straightforward. You can also run the tops scripts on a Mac simply by saying:

	  tops -verbose -scriptfile {scriptfilename} {filestoconvert}

All of the files are converted in place. You must run all of the tops scripts in the ConversionScripts directory against the application code. It is considerably simply to use the existing applications. Unfortunately these scripts do not exist on Mac OS X, otherwise porting the Conversion application might be useful.

When you start the scripts, if you're running them on black hardware you should go get a cup of coffee and watch a movie with your wife or go code something else for a while. The conversion will take a good long while on an older machine. I haven't timed it on the Mac, though. Once this is done, there is still a long way to go. Read on.

OPENSTEP4.2/Mach had a class called NSCStringText. This class was primarily for apps which were converted from NeXTSTEP to use as a stop-gap measure in OpenStep. This is one of the main reasons why it isn't in GNUstep. You will need to make sure that any classes modified by the scripts to use NSCStringText will use NSText and it's related classes as appropriate. OPENSTEP4.2/Mac also had some other extensions on the OpenStep standard such as NXStreams. You will also need to convert any and all instances of NXStream to use NSData instead in order to make your app work with GNUstep.

If your app is fairly small, you shouldn't be in for a great shock, but if your app is heavily reliant on the old Text object from NeXTSTEP, you have a lot of work ahead. Other gaps which the scripts might leave are problems with NSUserDefaults which it can't fix on it's own.

[[edit][18]]

<>

### Porting from Cocoa or OPENSTEP (NS\*) to GNUstep

Porting from Cocoa or OPENSTEP to GNUstep has different aspects. First there is the compatibility of the basic Foundation Kit and Application Kit. We support a lot of classes, but not all of them and the same is true for specific methods, specifically newly introduced classes and methods in Cocoa may still be missing as GNUstep started out aiming at OpenStep compatibility.

Second you have all the additional frameworks and libraries programmers on Mac OS X take for granted, for some of them free replacements exists, for most they are still missing. Mac OS X developers should try and avoid CoreFoundation as this will complicate your dependency situation on non-Mac hosts, even if that part of CoreFoundation has actually been ported. GNUstep Base and the FoundationKit offer many parts of the CoreFoundation functionality in a natural [Objective-C][19] manner. To be a bit more specific:

* don't use Core\* (CoreFoundation, CoreSound, CoreAnimation, ...)
* don't use KeyChain
* don't use Carbon
* don't use Quartz
* don't use QuickTime
* don't use WebKit (GCC 4.1 and up support ObjC++, but currently, there exists no WebKit port for GNUstep)
* don't use altivec features or the vecLib.framework (a collection of functions for vector manipulation, an Apple specific extension)
* don't use anything else we do not provide

If you committed none of these portability evils, the rest is relatively straightforward:

1. [Write a new GNUstep make file][20] for the project (very easy, still there is currently no automatic way to do so).
2. Make sure the Nib files are readable by GNUstep.
  1. When saving a NIB file in project builder, ensure that "10.2 or later" format is selected. Also, ensure that "Use text archive format" is NOT checked, as this created problems.
  2. Another option is to load them into Gorm and convert them into .gorm files. If they're from OPENSTEP or Mac OS X 10.1 or earlier, see [below][21].
3. Provide an Info.plist.

[[edit][22]]

<>

### Porting from GNUstep to Cocoa

This should be an easy transition since GNUstep implements most of Cocoa, except for the very Apple specific classes such as the scripting extensions. Since Gorm does not yet save .nib files, you will need to create the interfaces using IB. Also there is a gorm reading/parsing framework for Cocoa in the works as well, so please stay tuned.

Will need to:

* Make a Project Builder project for your app or
* an Xcode project for your app

Do the following:

* Open Xcode
* Choose Application (if your project is an application)
* Enter the name and location you wish the Project to reside at
* Copy your files from your GNUstep application into the new project
* Using the "Add Existing Files" option to add these files to your project

You should preserve your original directory structure if you want to distribute one package for both GNUstep and Cocoa.

[[edit][23]]

<>

## Stumbling Blocks

[[edit][24]]

<>

### Apple's Cocoa.h

It is there to enable pre-compiled headers and speed up compile time thusly. Anyway, it contains just two lines:

	#import &lt;Foundation/Foundation.h&gt;
	#import &lt;AppKit/AppKit.h&gt;

On older GNUstep systems, you may have to work around this by providing your own or replace your include of &lt;Cocoa/Cocoa.h&gt; with just the above, which will also work on OS-X.

[[edit][25]]

<>

### Distinguishing Between Cocoa and GNUstep

	#ifdef GNUSTEP
	    _/* GNUstep code goes here ... */_
	#else
	    _/* OS-X Cocoa native code goes here ... */_
	#endif

[[edit][26]]

<>

### Porting .nib files from OPENSTEP or Mac OS X 10.1 and earlier

GNUstep can handle nibs from 10.2 or later of Mac OS X, but it can't read nibs made with NeXTSTEP, OpenStep or Mac OS 10.1 or earlier. On the latest version of Mac OS X, this is a simple matter of loading the .nibs into Interface Builder.app and saving them in the 10.2 format. Another possibility is using nib2gmodel, the only one when porting from OPENSTEP, and, mind you, you need to do the converting _there_. First, get [nib2gmodel][27], follow the included instructions to build and install it. Once that's done you're ready to begin:

Run the nib2gmodel program on your nib:

	  nib2gmodel mygui.nib mygui.gmodel

This should create the .gmodel as a plist. I recommend that you convert the gmodel to a "normal" plist instead of an XML plist. You can do that by doing this on OS X:

	  pl &lt; mygui.gmodel -output mygui.ser
	  pl &gt; mygui.gmodel -input mygui.ser
	  rm mygui.ser

Now you can either use the gmodel as it is, or you can convert it to a .gorm file.

[[edit][28]]

<>

#### Gmodel to .gorm conversion

NOTE: Conversion from gmodel to .gorm is experimental and will probably remain so for a while. It currently works in the majority of cases, but there are still improvements which need to be made.

Conversion to a .gorm file is relatively straightforward:

* Start Gorm.app.
* Choose Gorm-&gt;Document-&gt;Open and find the gmodel you wish to load.
* Gorm will prompt you to either define the superclass for classes it doesn't know about or to parse the headers.

After you've defined all of the unknown classes, Gorm should complete the conversion. Once this is done you should save the result to make sure you don't loose your work.

[[edit][29]]

<>

#### .nib to .gorm conversion

Since it's possible to load nibs into GNUstep application now, it should be easy to convert 10.2 or later nibs by simply loading them into Gorm and saving them as .gorm files. This is not strictly necessary since GNUstep can handle them natively.

NOTE: Our recommendation for this is not to use the nib2gmodel conversion and simply to use the nibs directly, if you can or to convert them as described above by loading them into Interface Builder and saving them as the newer nib format.

[[edit][30]]

<>

### Xcode conversion

* how to convert Xcode project to GNUstep project (creating a GNUstep [Makefile][31] or [ProjectCenter][32])

* [pbxbuild][33] - this program converts an Xcode project into a set of targets and directories in which you can build by simply using make.

* PBTOMAKE. [xcodetounix][34] (download at [[1]][35]) is a tool for converting Xcode and Project Builder files to generic Unix Makefiles. It would probably be a good start for converting to a GNUstep makefile.

[[edit][36]]

<>

## Notes

[[edit][37]]

<>

### Do not rely on tools available in development environment

All the world is not Linux or FreeBSD or Windows. System constants may be different on different platforms. Paths to command-line tools, the parameters they accept and locations of temporary directories may be different to what you are used to on your platform.

* [GNUstep Base][38] and the [FoundationKit][39] offer some of this functionality "for free".
* Try not to hard code paths and so on into your code, use macros (not recommended), or even better an abstraction mechanism.
* Avoid hard-coding system constants, or platform-specific ones where POSIX or commonly-accepted ones exist (and we're not talking about glibc hereÃÂ :-)
* Try to avoid advanced features of the linker, such as weak symbols, which may not be present on non-ELF systems. While this will work perfectly on most systems, it is not portable to all systems, most notably Windows.

[[edit][40]]

<>

### When platform-specific code cannot be avoided

There are cases where you may need to write platform-specific code, especially in the case of desktop applications and services which make use of facilities not standardised by POSIX or by the FoundationKit and AppKit specifications, at least use [standard platform macros][41].

These platform-specific, or even desktop-specific requirements could be re-used by other projects - and even enhance desktop-integration efforts for GNUstep applications - by abstracting out common code into currently hypothetical [PlatformKit][42] and [DesktopServicesKit][43] frameworks.

[[edit][44]]

<>

### Cross Compiling

See [Cross\_Compiling][45]

 Retrieved from "[http://wiki.gnustep.org/index.php/Writing\_portable\_code][46]"

[Categories][47]: [Project procedures][48]

##### Views

* [Article][49]
* [Discussion][50]
* [Edit][51]
* [History][52]

##### Personal tools

* [Create an account or log in][53]

[][54]

##### users

* [Applications][55]
* [Guides][56]
* [FAQ][57]
* [Get Help][58]
* [Report Bugs][59]
* [Donations][60]
* [Screenshots][61]

##### developers

* [Guides][62]
* [FAQ][63]
* [Base API (Foundation)][64]
* [GUI API (AppKit)][65]
* [Frameworks][66]

##### Navigation

* [Main Page][67]
* [Community portal][68]
* [Current events][69]
* [Recent changes][70]
* [Random page][71]
* [Help][72]

##### Search

##### Toolbox

* [What links here][73]
* [Related changes][74]
* [Upload file][75]
* [Special pages][76]
* [Printable version][77]

[![MediaWiki][78]][79]

* This page was last modified 12:12, 30 January 2009.
* This page has been accessed 207,093 times.
* Content is available under [GNU General Public License][80].
* [About GNUstepWiki][81]
* [Disclaimers][82]

  [1]: #Porting_Applications
  [2]: #Porting_from_NeXTSTEP_.28NX.2A.29_to_GNUstep
  [3]: #Porting_from_Cocoa_or_OPENSTEP_.28NS.2A.29_to_GNUstep
  [4]: #Porting_from_GNUstep_to_Cocoa
  [5]: #Stumbling_Blocks
  [6]: #Apple.27s_Cocoa.h
  [7]: #Distinguishing_Between_Cocoa_and_GNUstep
  [8]: #Porting_.nib_files_from_OPENSTEP_or_Mac_OS_X_10.1_and_earlier
  [9]: #Gmodel_to_.gorm_conversion
  [10]: #.nib_to_.gorm_conversion
  [11]: #Xcode_conversion
  [12]: #Notes
  [13]: #Do_not_rely_on_tools_available_in_development_environment
  [14]: #When_platform-specific_code_cannot_be_avoided
  [15]: #Cross_Compiling
  [16]: /index.php?title=Writing_portable_code&action=edit&section=1 "Writing portable code"
  [17]: /index.php?title=Writing_portable_code&action=edit&section=2 "Writing portable code"
  [18]: /index.php?title=Writing_portable_code&action=edit&section=3 "Writing portable code"
  [19]: /index.php/Objective-C "Objective-C"
  [20]: /index.php/Writing_Makefiles "Writing Makefiles"
  [21]: #Porting_.nib_files_from_OPENSTEP_or_Mac_OS_X_10.1_and_earlier
  [22]: /index.php?title=Writing_portable_code&action=edit&section=4 "Writing portable code"
  [23]: /index.php?title=Writing_portable_code&action=edit&section=5 "Writing portable code"
  [24]: /index.php?title=Writing_portable_code&action=edit&section=6 "Writing portable code"
  [25]: /index.php?title=Writing_portable_code&action=edit&section=7 "Writing portable code"
  [26]: /index.php?title=Writing_portable_code&action=edit&section=8 "Writing portable code"
  [27]: http://freshmeat.net/projects/nib2gmodel/ "http://freshmeat.net/projects/nib2gmodel/"
  [28]: /index.php?title=Writing_portable_code&action=edit&section=9 "Writing portable code"
  [29]: /index.php?title=Writing_portable_code&action=edit&section=10 "Writing portable code"
  [30]: /index.php?title=Writing_portable_code&action=edit&section=11 "Writing portable code"
  [31]: http://www.gnustep.it/nicola/Tutorials/WritingMakefiles/index.html "http://www.gnustep.it/nicola/Tutorials/WritingMakefiles/index.html"
  [32]: /index.php/ProjectCenter "ProjectCenter"
  [33]: /index.php/Pbxbuild "Pbxbuild"
  [34]: http://www.macdevcenter.com/pub/a/mac/2004/04/20/xcodetounix.html "http://www.macdevcenter.com/pub/a/mac/2004/04/20/xcodetounix.html"
  [35]: http://members.bellatlantic.net/%7Evze35xda/software.html "http://members.bellatlantic.net/~vze35xda/software.html"
  [36]: /index.php?title=Writing_portable_code&action=edit&section=12 "Writing portable code"
  [37]: /index.php?title=Writing_portable_code&action=edit&section=13 "Writing portable code"
  [38]: /index.php/Foundation "Foundation"
  [39]: /index.php/Foundation "Foundation"
  [40]: /index.php?title=Writing_portable_code&action=edit&section=14 "Writing portable code"
  [41]: /index.php/Identifying_the_target_platform "Identifying the target platform"
  [42]: /index.php?title=PlatformKit&action=edit "PlatformKit"
  [43]: /index.php/DesktopServicesKit "DesktopServicesKit"
  [44]: /index.php?title=Writing_portable_code&action=edit&section=15 "Writing portable code"
  [45]: /index.php/Cross_Compiling "Cross Compiling"
  [46]: http://wiki.gnustep.org/index.php/Writing_portable_code
  [47]: /index.php?title=Special:Categories&article=Writing_portable_code "Special:Categories"
  [48]: /index.php/Category:Project_procedures "Category:Project procedures"
  [49]: /index.php/Writing_portable_code
  [50]: /index.php?title=Talk:Writing_portable_code&action=edit
  [51]: /index.php?title=Writing_portable_code&action=edit
  [52]: /index.php?title=Writing_portable_code&action=history
  [53]: /index.php?title=Special:Userlogin&returnto=Writing_portable_code
  [54]: /index.php/Main_Page "Main Page"
  [55]: /index.php/Category:Applications
  [56]: /index.php/User_Guides
  [57]: /index.php/User_FAQ
  [58]: /index.php/Get_Help
  [59]: /index.php/Report_Bugs
  [60]: /index.php/GNUstepWiki:Site_support
  [61]: /index.php/Screenshots
  [62]: /index.php/Developer_Guides
  [63]: /index.php/Developer_FAQ
  [64]: /index.php/Foundation
  [65]: /index.php/AppKit
  [66]: /index.php/Category:Frameworks
  [67]: /index.php/Main_Page
  [68]: /index.php/GNUstepWiki:Community_Portal
  [69]: /index.php/Current_events
  [70]: /index.php/Special:Recentchanges
  [71]: /index.php/Special:Random
  [72]: /index.php/Help:Contents
  [73]: /index.php/Special:Whatlinkshere/Writing_portable_code
  [74]: /index.php/Special:Recentchangeslinked/Writing_portable_code
  [75]: /index.php/Special:Upload
  [76]: /index.php/Special:Specialpages
  [77]: /index.php?title=Writing_portable_code&printable=yes&printable=yes
  [78]: /skins/common/images/poweredby_mediawiki_88x31.png
  [79]: http://www.mediawiki.org/
  [80]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [81]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [82]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"