<>

# Fuzzy

### From GNUstepWiki	{#siteSub}

**This is a proposal for an approach that is not yet part of GNUstep though there is source code**

This page is for GNUstep developers. It explains the Fuzzy Logic system from the gnustep-fuzzy library for e.g. updating the GNUstep System such as drawing to screen. See the references immediately if you do not know anything about fuzzy logic systems. You should concur that you understand fuzzy logic before reading anything else on this page. Source code is provided at the bottom of the page.

<table>
<tr>
<td>
## Contents
* [1 What is Fuzzy LogicÃÂ ?][1]
* [2 Fuzzy Networks][2]
* [3 Distributed fuzzy networks][3]
* [4 Inference engines][4]
* [5 prolog][5]
* [6 progol][6]
* [7 How does it apply to GNUstepÃÂ ?][7]
  * [7\.1 gnustep-fuzzy][8]
* [8 rule system code example][9]
* [9 gnustep-fuzzy API][10]
* [10 references][11]
  * [10\.1 external links][12]
  * [10\.2 source code][13]
  * [10\.3 author][14]
</td>
</tr>
</table>

[[edit][15]]

<>

## What is Fuzzy LogicÃÂ ?

A fuzzy system is a rule-based systems with inputs and outputs. Each fuzzy rule is associated with a mathematical function. The system is a greedy decision tree algorithm. The rules of a fuzzy system are more random than a decision tree so that it is faster. A decision tree traverses at O(log(n)), the depth of the tree and O(n\*log(n)) for a n-ary tree approximately.

[<img src="/images/e/e5/300px-Fuzzy_logic_temperature_en.svg.png" width="300" height="122" alt=" Figure 1.1" />][16]

The image displays the fuzzy logic function value increasing with temperature which is a linear algebraic function system. Values overlap here and there (see the color of the lines), this is where the name fuzzy comes from A function for cold would be f(x), for warm f(x\*x) and for hot f(x\*x\*x). as f(X) increases the return value increases as does the temperature. Another solution would be to have the return value of a temperature fuzzy logic function increasing with temperature.

As the name fuzzy suggests it uses more general information systems. The functions of the fuzzy logic are most important. For example "extremely" associates with the value x \* x \* x where x is a floating point number. "a little bit" is associated with sqrt(x) / 1.3 and so on. The fuzzy rules are parsed in succession and yield a value for each natural language word. Thus you can reason as a human what the fuzzy logic should do after a fuzzy function is successful e.g. against some threshold, if x=0 then the "extremely" function i 0 \* 0 \* 0 = 0 and is smaller than threshold 0.001. The threshold is from Artificial Neural Networks for calculating success of the extremum sought by the network.

[[edit][17]]

<>

## Fuzzy Networks

If you implement all rules in a seperate graph node you can reason your way around a graph.

[[edit][18]]

<>

## Distributed fuzzy networks

The same as a fuzzy network but with a node for each fuzzy logic set or system of nodes of a fuzzy network.

[[edit][19]]

<>

## Inference engines

Inference engines infere rules based on logic such as reasoning with not, and, or and combinations of these logical comparators. You can negate rules and infere less rules this way.

[[edit][20]]

<>

## prolog

Prolog is a formal logic rule system which induces rules based on the logical input clauses and then reasons about them by parsing logic rules. You can ask the prolog interpreter questions about what he induced logically.

[[edit][21]]

<>

## progol

Progol inferes the most specicic clause by using a graph searching algorithm. It parses e.g. by negation so that input clauses can be ruled out. Progol deduces i.e. makes the most general logical assumptions.

[[edit][22]]

<>

## How does it apply to GNUstepÃÂ ?

You can reason about what or how to draw to an X11/Xquartz window or GS subelement in the window such as a view, a button or a bitmap. You would use a fuzzy paint node which is in a distributed node system. If you switch nodes you either paint or wait (for example with an idle node) or reason (e.g. with an interrupt you must redraw your app screen) and so on. e.g. a mouse node would reason if you are about to click a button and access the region the mouse is in to reason further about what the painting algorithm of the window or rootwindow should do.

[[edit][23]]

<>

### gnustep-fuzzy

gnustep-fuzzy uses a paint node which reasons about when it should paint. It can idle for seconds (or milliseconds) if you like and inferes the rules of the paint node this way. There is a fuzzy function associated with each rule string and a rule associated with a drawing function e.g. paintOn: or paintIdle1Second:. This system can be further distributed from a fuzzy set to a fuzzy node for each rule.

[[edit][24]]

<>

## rule system code example

This is portable C and Objective-CÃÂ :

	void makePaintRules(OpalFuzzyPaintRuleSystem* sys)
	// sys is a node with a fuzzy set (or network in it)
	{
	        /*
	          sys contains a canvas called _painter and adds here a rule
	          which redraws the screen, this method is paintOn: with the
	          canvas as an argument. There are 3 adapters inside sysÃÂ : self,   painter  and parser
	        */
	        [sys addRule:"paint extremely fast"ÃÂ : paintOn:];

	        /*
	           f is a functor object which contains the "extremely" reasoning fuzzy function, implemented as
	           return (x*x*x); where x is initialized to 0.0 thereunder. You change the x not the threshold
	           in sys, so if you have a threshold of 0.001, f(x)==0 &lt; threshold, and the rule gets matched
	           by sys. The fuzzy parser of rules is now still simple. I mean the non-fuzzy function part.
	        */
	        OpalFuzzyFunction *f = [OpalFuzzyFunctionExtremely new];
	        [f x:.0];
	        [sys addFunction:"paint extremely"ÃÂ : f];
	        /* here's the same thing the paint thread of e.g. Xquartz event handling sleeps for 1 second */
	        [sys addRule:"paint not for 1 second"ÃÂ : paintIdle1SecondOn:];
	        f = [OpalFuzzyFunctionIdle new];
	        [f x:.0];
	        [sys addFunction:"paint not for 1 second"ÃÂ : f];
	}

You can change the fuzzy function parameter so that the threshold should not change.

The threading model of this code is multi-threaded so e.g. drawing to screen happens with interrupts and is managed by a threadpool object which alters the state of your GS windows. Threads can be used to let the fuzzy set parse and change nodes when doing other stuff.

[[edit][25]]

<>

## gnustep-fuzzy API

There are three adapters (manipulators) for a rulesystem as used in the above C function. A rulesystem, painter and parser instance wrapper. These can combine the full features with rulesystem parse methods such as the PaintRuleSystem class:

OpalFuzzyRuleSystem APIÃÂ :

----

	@interface OpalFuzzyRuleSystemÃÂ : NSObject
	{
	        CGFloat _threshold;

	        // this is a dictionary with rule-paint method key-value pairs
	        OpalFuzzyDB *_rules;
	        // this is a dictionary with rule-fuzzy logic function key-value pairs
	        OpalFuzzyDB *_functions;
	}

	// parseFor:On: calls match:On:
	-(void) parseFor:(OpalFuzzyPredicate*)predicate On:(id)o;
	// On: is the painting system i.e. where you draw on. preficate gets matched against the rules.
	- (id) match:(OpalFuzzyPredicate*)predicate On:(id)o;

	// These are base class adaptersÃÂ :
	- (id) createManipulator;
	- (id) createArgumentManipulator;
	- (id) createParserManipulator;

----

OpalFuzzyPaintRuleSystem APIÃÂ :

private \_painter and \_parser variables where the painter is something to paint or draw on, the parser is the paint rulesystem parser and belongs in a OpalFuzzyNode, which itself is a distributed node for painting or paint node.

Here is the interfaceÃÂ :

----

	// painter and parser private variable get/set
	- (id) new:(id)painter withParser:(id)parser;
	- (void)setPaintSystem:(id)paintsystem;
	- (id)painter;
	- (void)setParser:(id)parser;
	- (id)parser;

	// this is for painting on itself, it is not used
	- (void)paintOn;

	// this paints on the painter adapter
	- (void)paintOn:(id)painter;

	// this idles updating with painting/drawing
	- (void)paintIdle1SecondOn:(id)painter;

	// this is the general predicate variable mathching then drawing on id oÃÂ :
	- (id) match:(OpalFuzzyPredicate*)predicate On:(id)o;

	/* The following is from the code itselfÃÂ :
	 * NOTEÃÂ :
	 * Call the createManipulator method and you can paint on this
	 * painter system with rules from the super class.

	 * The PaintManipulator then hashes the method paintOn: in the dictionary
	 * and paints on the _painter of the dispatched class due to a call
	 * of e.g. parseFor:"paint extremely". parseFor is in the super class and has On: for the
	 * the painter/canvas system to draw on. It gets passed to the match:On: method above.
	 *
	 * The super class parseFor:On: method can also be used as a rule (rules have
	 * a NSString key and a SEL in the form of performSelector:withObject:, so
	 * only a single argument in e.g. parseForOn: implemented with the API.
	 * Manipulator stands for adapter or wrapper design patterns.
	 */
	- (id) createManipulator;
	- (id) createArgumentManipulator;
	- (id) createParserManipulator;

----

[[edit][26]]

<>

## references

[[edit][27]]

<>

#### external links

* [wikipedia page on Fuzzy Networks][28]
* [wikipedia page on Fuzzy Logic][29]

[[edit][30]]

<>

#### source code

[![gnustep-fuzzy tarball version 0.2+][31]][32]

[[edit][33]]

<>

#### author

\`Enry the \`Ermit &lt;goon at yellowcouch dot org&gt;

 Retrieved from "<http://wiki.gnustep.org/index.php/Fuzzy>"

##### Views

* [Article][34]
* [Discussion][35]
* [Edit][36]
* [History][37]

##### Personal tools

* [Create an account or log in][38]

[][39]

##### users

* [Applications][40]
* [Guides][41]
* [FAQ][42]
* [Get Help][43]
* [Report Bugs][44]
* [Donations][45]
* [Screenshots][46]

##### developers

* [Guides][47]
* [FAQ][48]
* [Base API (Foundation)][49]
* [GUI API (AppKit)][50]
* [Frameworks][51]

##### Navigation

* [Main Page][52]
* [Community portal][53]
* [Current events][54]
* [Recent changes][55]
* [Random page][56]
* [Help][57]

##### Search

##### Toolbox

* [What links here][58]
* [Related changes][59]
* [Upload file][60]
* [Special pages][61]
* [Printable version][62]

[![MediaWiki][63]][64]

* This page was last modified 07:52, 12 March 2015.
* This page has been accessed 17,797 times.
* Content is available under [GNU General Public License][65].
* [About GNUstepWiki][66]
* [Disclaimers][67]

  [1]: #What_is_Fuzzy_Logic_.3F
  [2]: #Fuzzy_Networks
  [3]: #Distributed_fuzzy_networks
  [4]: #Inference_engines
  [5]: #prolog
  [6]: #progol
  [7]: #How_does_it_apply_to_GNUstep_.3F
  [8]: #gnustep-fuzzy
  [9]: #rule_system_code_example
  [10]: #gnustep-fuzzy_API
  [11]: #references
  [12]: #external_links
  [13]: #source_code
  [14]: #author
  [15]: /index.php?title=Fuzzy&action=edit&section=1 "Fuzzy"
  [16]: /index.php/Image:300px-Fuzzy_logic_temperature_en.svg.png " Figure 1.1"
  [17]: /index.php?title=Fuzzy&action=edit&section=2 "Fuzzy"
  [18]: /index.php?title=Fuzzy&action=edit&section=3 "Fuzzy"
  [19]: /index.php?title=Fuzzy&action=edit&section=4 "Fuzzy"
  [20]: /index.php?title=Fuzzy&action=edit&section=5 "Fuzzy"
  [21]: /index.php?title=Fuzzy&action=edit&section=6 "Fuzzy"
  [22]: /index.php?title=Fuzzy&action=edit&section=7 "Fuzzy"
  [23]: /index.php?title=Fuzzy&action=edit&section=8 "Fuzzy"
  [24]: /index.php?title=Fuzzy&action=edit&section=9 "Fuzzy"
  [25]: /index.php?title=Fuzzy&action=edit&section=10 "Fuzzy"
  [26]: /index.php?title=Fuzzy&action=edit&section=11 "Fuzzy"
  [27]: /index.php?title=Fuzzy&action=edit&section=12 "Fuzzy"
  [28]: http://en.wikipedia.org/wiki/Information_Fuzzy_Networks "http://en.wikipedia.org/wiki/Information Fuzzy Networks"
  [29]: http://en.wikipedia.org/wiki/Fuzzy_logic "http://en.wikipedia.org/wiki/Fuzzy logic"
  [30]: /index.php?title=Fuzzy&action=edit&section=13 "Fuzzy"
  [31]: /images/c/c8/Gnustep-fuzzy-0.2.tar.gz
  [32]: /index.php/Image:Gnustep-fuzzy-0.2.tar.gz "gnustep-fuzzy tarball version 0.2+"
  [33]: /index.php?title=Fuzzy&action=edit&section=14 "Fuzzy"
  [34]: /index.php/Fuzzy
  [35]: /index.php?title=Talk:Fuzzy&action=edit
  [36]: /index.php?title=Fuzzy&action=edit
  [37]: /index.php?title=Fuzzy&action=history
  [38]: /index.php?title=Special:Userlogin&returnto=Fuzzy
  [39]: /index.php/Main_Page "Main Page"
  [40]: /index.php/Category:Applications
  [41]: /index.php/User_Guides
  [42]: /index.php/User_FAQ
  [43]: /index.php/Get_Help
  [44]: /index.php/Report_Bugs
  [45]: /index.php/GNUstepWiki:Site_support
  [46]: /index.php/Screenshots
  [47]: /index.php/Developer_Guides
  [48]: /index.php/Developer_FAQ
  [49]: /index.php/Foundation
  [50]: /index.php/AppKit
  [51]: /index.php/Category:Frameworks
  [52]: /index.php/Main_Page
  [53]: /index.php/GNUstepWiki:Community_Portal
  [54]: /index.php/Current_events
  [55]: /index.php/Special:Recentchanges
  [56]: /index.php/Special:Random
  [57]: /index.php/Help:Contents
  [58]: /index.php/Special:Whatlinkshere/Fuzzy
  [59]: /index.php/Special:Recentchangeslinked/Fuzzy
  [60]: /index.php/Special:Upload
  [61]: /index.php/Special:Specialpages
  [62]: /index.php?title=Fuzzy&printable=yes&printable=yes
  [63]: /skins/common/images/poweredby_mediawiki_88x31.png
  [64]: http://www.mediawiki.org/
  [65]: http://www.gnu.org/copyleft/gpl.html "http://www.gnu.org/copyleft/gpl.html"
  [66]: /index.php/GNUstepWiki:About "GNUstepWiki:About"
  [67]: /index.php/GNUstepWiki:General_disclaimer "GNUstepWiki:General disclaimer"